
SORT_ORDER = {
    "ER": 1,
    "SR": 2,
    "MR": 3,
    "DR": 4,
    "UR": 5
};

var array_unique = function(a) {
    return a.reduce(function(p, c) {
        if (p.indexOf(c) < 0) p.push(c);
        return p;
    }, []);
};

function sort_tips (filtered) {
    return filtered.sort(function (ela, elb) {
        var ela_style = SORT_ORDER[ela["tip"].substring(0,2)];
        var ela_size = ela["tip"].substring(2);

        var elb_style = SORT_ORDER[elb["tip"].substring(0,2)];
        var elb_size = elb["tip"].substring(2);

        // Sort by tip
        if (ela_size < elb_size) {
            return -1;
        } else if (ela_size > elb_size) {
            return 1;
        } else {

            // If tip is the same sort by style
            if (ela_style < elb_style) {
                return -1;
            } else if (ela_style < elb_style) {
                return 1;
            } else {
                return 0;
            }

        }
    });

}

function sort_fertilizer_tips (filtered) {
    return filtered.sort(function (ela, elb) {
        var tip_rate_a = 0.0;
        if ("tip_rate_30" in ela) {
          var tip_rate = ela["tip_rate"];
          tip_rate_a = eval(ela["tip_rate_30"]) * 1.155;  // sqrt(40)/30
        } else {
          tip_rate_a = parseFloat(ela["tip_rate"]);
        }

        var tip_rate_b = 0.0;
        if ("tip_rate_30" in elb) {
          var tip_rate = elb["tip_rate"];
          tip_rate_b = eval(elb["tip_rate_30"]) * 1.155;  // sqrt(40)/30
        } else {
          tip_rate_b = parseFloat(elb["tip_rate"]);
        }
    
        // Sort by tip
        if (tip_rate_a < tip_rate_b) {
            return -1;
        } else if (tip_rate_a > tip_rate_b) {
            return 1;
        }
    });
}

function format_number (n) {

    if (n >= 100.0) {
        return n.toFixed(0);
    } else if (n >= 10.0) {
        return n.toFixed(1);
    } else {
        return n.toFixed(2);
    }

}

var tips_table = [
    {
        "ang": "110",
        "tip": "UR110-04",
        "part_no": "40292-04",
        "color": "Red", 
        "csscolor": "tip-red",
        "tip_rate": "0.4",
        "pre_orf": "R04 DUAL",
        "pre-orf_no": "40292-24",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "Not Required",
        "cv_tip": "0.063",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.316",
        "r_max": "0.566",
        "vmd_s": "-152.2*Math.log(pt)+1162.5",
        "141_s": "1.7057*Math.log(pt)-0.5258",
        "200_s": "7.0508*Math.log(pt)-17.323",
        "600_s": "100-17.221*Math.pow(pt,(0.2537))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.061",
        "orf_eff": "0.39",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.067",
        "p_max": "61",
        "r_min_b": "0.068",
        "r_max_b": "0.494",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "-152.2*Math.log(pt_b)+1162.5",
        "141_b": "1.7057*Math.log(pt_b)-0.5258",
        "200_b": "7.0508*Math.log(pt_b)-17.323",
        "600_b": "100-17.221*Math.pow(pt_b,(0.2537))",
        "Dv01_s": "-81.8*Math.log(pt)+518.63",
        "Dv01_b": "-81.8*Math.log(pt_b)+518.63",
    },
    {
        "ang": "110",
        "tip": "UR110-05",
        "part_no": "40292-05",
        "color": "Brown", 
        "csscolor": "tip-brown",
        "tip_rate": "0.5",
        "pre_orf": "R05 DUAL",
        "pre-orf_no": "40292-25",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "Not Required",
        "cv_tip": "0.079",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.395",
        "r_max": "0.707",
        "vmd_s": "1351.4*Math.pow(pt,(-0.211))",
        "141_s": "2.6278*Math.log(pt)-4.1635",
        "200_s": "4.9901*Math.log(pt)-10.527",
        "600_s": "100-18.133*Math.pow(pt,(0.2243))",
        "cat_s": "UC",
        "pg": "40",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "1351.4*Math.pow(pt_b,(-0.211))",
        "141_b": "2.6278*Math.log(pt_b)-4.1635",
        "200_b": "4.9901*Math.log(pt_b)-10.527",
        "600_b": "100-18.133*Math.pow(pt_b,(0.2243))",
        "Dv01_s": "-56.46*Math.log(pt)+434.48",
        "Dv01_b": "-56.46*Math.log(pt_b)+434.48",
    },
    {
        "ang": "110",
        "tip": "UR110-06",
        "part_no": "40292-06",
        "color": "Grey", 
        "csscolor": "tip-grey",
        "tip_rate": "0.6",
        "pre_orf": "R06 DUAL",
        "pre-orf_no": "40292-06",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.095",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.474",
        "r_max": "0.849",
        "vmd_s": "1414.9*Math.pow(pt,(-0.218))",
        "141_s": "1.9826*Math.log(pt)-2.4691",
        "200_s": "4.5986*Math.log(pt)-10.123",
        "600_s": "100-16.732*Math.pow(pt,(0.2385))",
        "cat_s": "UC",
        "pg": "40",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "1414.9*Math.pow(pt_b,(-0.218))",
        "141_b": "1.9826*Math.log(pt_b)-2.4691",
        "200_b": "4.5986*Math.log(pt_b)-10.123",
        "600_b": "100-16.732*Math.pow(pt_b,(0.2385))",
        "Dv01_s": "-51.23*Math.log(pt)+425.98",
        "Dv01_b": "-51.23*Math.log(pt_b)+425.98",        
    },
    {
        "ang": "110",
        "tip": "UR110-08",
        "part_no": "40292-08",
        "color": "White", 
        "csscolor": "tip-white",
        "tip_rate": "0.8",
        "pre_orf": "R08 DUAL",
        "pre-orf_no": "40292-27",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.126",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.632",
        "r_max": "1.131",
        "vmd_s": "1718.6*Math.pow(pt,(-0.263))",
        "141_s": "1.5637*Math.log(pt)-1.8632",
        "200_s": "5.729*Math.log(pt)-15.339",
        "600_s": "100-13.475*Math.pow(pt,(0.2912))",
        "cat_s": "UC",
        "pg": "40",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "1718.6*Math.pow(pt_b,(-0.263))",
        "141_b": "1.5637*Math.log(pt_b)-1.8632",
        "200_b": "5.729*Math.log(pt_b)-15.339",
        "600_b": "100-13.475*Math.pow(pt_b,(0.2912))",
        "Dv01_s": "-67.35*Math.log(pt)+496.42",
        "Dv01_b": "-67.35*Math.log(pt_b)+496.42",
    },
    {
        "ang": "110",
        "tip": "UR110-10",
        "part_no": "40292-10",
        "color": "Lt Blue", 
        "csscolor": "tip-lt_blue",
        "tip_rate": "1",
        "pre_orf": "R010 DUAL",
        "pre-orf_no": "40292-28",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.158",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.791",
        "r_max": "1.414",
        "vmd_s": "-127.97*Math.log(pt)+1107",
        "141_s": "2.3349*Math.log(pt)-5.3296",
        "200_s": "3.837*Math.log(pt)-8.9716",
        "600_s": "100-155.28*Math.pow(pt,(-0.2433))",
        "cat_s": "UC",
        "pg": "40",
        "pt_b": "pg/pwm_fac",
        "vmd_b":  "1774.5*Math.pow(pt_b,(-0.269))",
        "141_b": "1.1989*Math.log(pt_b)-0.9029",
        "200_b": "4.2563*Math.log(pt_b)-10.0529",
        "600_b": "100-17.594*Math.pow(pt_b,(0.2314))",
        "Dv01_s": "-40.33*Math.log(pt)+403.04",
        "Dv01_b": "-40.33*Math.log(pt_b)+403.04",
    },
    
    
    {
        "classification": 0,
        "ang": "80",
        "600_b": "100.0",
        "pre-orf_no": "N/A",
        "part_no": "40270-005",
        "200_b": "Math.min(24.528*Math.log(pt_b)-5.887,100)",
        "csscolor": "tip-black",
        "cv_tip": "0.008",
        "141_s": "31.95*Math.log(pt)-62.469",
        "600_s": "100.0",
        "r_min": "0.035",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "-23.87*Math.log(pt)+170.56",
        "vmd_b": "403.43*Math.pow(pt_b,-0.2936)",
        "tip": "ER80-005",
        "Dv01_b": "-23.87*Math.log(pt_b)+170.56",
        "141_b": "31.95*Math.log(pt_b)-62.469",
        "200_s": "Math.min(24.528*Math.log(pt)-5.887,100)",
        "color": "Black",
        "tip_rate": "0.05",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.071",
        "vmd_s": "403.43*Math.pow(pt,-0.2936)",
        "screen_no": "100 Mesh (#40251-00)",
        "screen": "100/Green",
        "pre_orf": "N/A",
    },
    {
        "classification": 0,
        "ang": "80",
        "600_b": "100",
        "pre-orf_no": "N/A",
        "part_no": "40270-007",
        "200_b": "Math.min(34.074*Math.log(pt_b)-50.894,100)",
        "csscolor": "tip-pink",
        "cv_tip": "0.011",
        "141_s": "33.413*Math.log(pt)-78.661",
        "600_s": "100",
        "r_min": "0.047",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "-29.53*Math.log(pt)+201.01",
        "vmd_b": "619.31*Math.pow(pt_b,-0.3785)",
        "tip": "ER80-0067",
        "Dv01_b": "-29.53*Math.log(pt_b)+201.01",
        "141_b": "33.413*Math.log(pt_b)-78.661",
        "200_s": "Math.min(34.074*Math.log(pt)-50.894,100)",
        "color": "Pink",
        "tip_rate": "0.067",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.095",
        "vmd_s": "619.31*Math.pow(pt,-0.3785)",
        "screen_no": "100 Mesh (#40251-00)",
        "screen": "100/Green",
        "pre_orf": "N/A",
    },
    {
        "classification": 0,
        "ang": "80",
        "600_b": "100",
        "pre-orf_no": "N/A",
        "part_no": "40270-01",
        "200_b": "Math.min(24.521*Math.log(pt_b)-9.3599,100)",
        "csscolor": "tip-orange",
        "cv_tip": "0.016",
        "141_s": "30.096*Math.log(pt)-61.612",
        "600_s": "100",
        "r_min": "0.071",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "-26.1*Math.log(pt)+181.21",
        "vmd_b": "418.37*Math.pow(pt_b,-0.2901)",
        "tip": "ER80-01",
        "Dv01_b": "-26.1*Math.log(pt_b)+181.21",
        "141_b": "30.096*Math.log(pt_b)-61.612",
        "200_s": "Math.min(24.521*Math.log(pt)-9.3599,100)",
        "color": "Orange",
        "tip_rate": "0.1",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.141",
        "vmd_s": "418.37*Math.pow(pt,-0.2901)",
        "screen_no": "100 Mesh (#40251-00)",
        "screen": "100/Green",
        "pre_orf": "N/A",
    },
    {
        "classification": 0,
        "ang": "80",
        "600_b": "100.0",
        "pre-orf_no": "N/A",
        "part_no": "40270-015",
        "200_b": "21.165*Math.log(pt_b)-13.022",
        "csscolor": "tip-green",
        "cv_tip": "0.024",
        "141_s": "19.82*Math.log(pt)-38.678",
        "600_s": "100.0",
        "r_min": "0.106",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "-25.01*Math.log(pt)+188.92",
        "vmd_b": "425.96*Math.pow(pt_b,-0.2539)",
        "tip": "ER80-015",
        "Dv01_b": "-25.01*Math.log(pt_b)+188.92",
        "141_b": "19.82*Math.log(pt_b)-38.678",
        "200_s": "21.165*Math.log(pt)-13.022",
        "color": "Green",
        "tip_rate": "0.15",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.212",
        "vmd_s": "425.96*Math.pow(pt,-0.2539)",
        "screen_no": "100 Mesh (#40251-00)",
        "screen": "100/Green",
        "pre_orf": "N/A",
    },
    {
        "classification": 0,
        "ang": "80",
        "600_b": "100-0.0106*pt_b-0.179",
        "pre-orf_no": "N/A",
        "part_no": "40270-02",
        "200_b": "14.01*Math.log(pt_b)+14.74",
        "csscolor": "tip-yellow",
        "cv_tip": "0.032",
        "141_s": "15.111*Math.log(pt)-17.348",
        "600_s": "100-0.0106*pt-0.179",
        "r_min": "0.141",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "-18.6*Math.log(pt)+156.15",
        "vmd_b": "324.48*Math.pow(pt_b,-0.1892)",
        "tip": "ER80-02",
        "Dv01_b": "-18.6*Math.log(pt_b)+156.15",
        "141_b": "15.111*Math.log(pt_b)-17.348",
        "200_s": "14.01*Math.log(pt)+14.74",
        "color": "Yellow",
        "tip_rate": "0.2",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.283",
        "vmd_s": "324.48*Math.pow(pt,-0.1892)",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "pre_orf": "N/A",
    },
    {
        "classification": 0,
        "ang": "80",
        "600_b": "100-0.1413*Math.pow(pt_b,(0.2945))",
        "pre-orf_no": "N/A",
        "part_no": "40270-025",
        "200_b": "19.419*Math.log(pt_b)-20.349",
        "csscolor": "tip-purple",
        "cv_tip": "0.040",
        "141_s": "15.706*Math.log(pt)-29.943",
        "600_s": "100-0.1413*Math.pow(pt,(0.2945))",
        "r_min": "0.177",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "-24.19*Math.log(pt)+191.21",
        "vmd_b": "510.39*Math.pow(pt_b,-0.2629)",
        "tip": "ER80-025",
        "Dv01_b": "-24.19*Math.log(pt_b)+191.21",
        "141_b": "15.706*Math.log(pt_b)-29.943",
        "200_s": "19.419*Math.log(pt)-20.349",
        "color": "Purple",
        "tip_rate": "0.25",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.354",
        "vmd_s": "510.39*Math.pow(pt,-0.2629)",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "pre_orf": "N/A",
    },
    {
        "classification": 0,
        "ang": "80",
        "600_b": "100-0.4372*Math.pow(pt_b,(0.1589))",
        "pre-orf_no": "N/A",
        "part_no": "40270-03",
        "200_b": "15.694*Math.log(pt_b)-8.7893",
        "csscolor": "tip-blue",
        "cv_tip": "0.047",
        "141_s": "13.002*Math.log(pt)-21.67",
        "600_s": "100-0.4372*Math.pow(pt,(0.1589))",
        "r_min": "0.212",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "-24.19*Math.log(pt)+191.21",
        "vmd_b": "439.46*Math.pow(pt_b,-0.212)",
        "tip": "ER80-03",
        "Dv01_b": "-24.19*Math.log(pt_b)+191.21",
        "141_b": "13.002*Math.log(pt_b)-21.67",
        "200_s": "15.694*Math.log(pt)-8.7893",
        "color": "Blue",
        "tip_rate": "0.3",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.424",
        "vmd_s": "439.46*Math.pow(pt,-0.212)",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "pre_orf": "N/A",
    },
    {
        "classification": 0,
        "ang": "80",
        "600_b": "100-1.9313*Math.pow(pt_b,(-0.2355))",
        "pre-orf_no": "N/A",
        "part_no": "40270-04",
        "200_b": "14.859*Math.log(pt_b)-10.326",
        "csscolor": "tip-red",
        "cv_tip": "0.063",
        "141_s": "10.409*Math.log(pt)-14.732",
        "600_s": "100-1.9313*Math.pow(pt,(-0.2355))",
        "r_min": "0.283",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "-19.94*Math.log(pt)+177.05",
        "vmd_b": "476.16*Math.pow(pt_b,-0.214)",
        "tip": "ER80-04",
        "Dv01_b": "-19.94*Math.log(pt_b)+177.05",
        "141_b": "10.409*Math.log(pt_b)-14.732",
        "200_s": "14.859*Math.log(pt)-10.326",
        "color": "Red",
        "tip_rate": "0.4",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.566",
        "vmd_s": "476.16*Math.pow(pt,-0.214)",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "pre_orf": "N/A",
    },
    {
        "classification": 0,
        "ang": "80",
        "600_b": "100-5.9766*Math.pow(pt_b,(-0.0345))",
        "pre-orf_no": "N/A",
        "part_no": "40270-05",
        "200_b": "17.263*Math.log(pt_b)-27.575",
        "csscolor": "tip-brown",
        "cv_tip": "0.079",
        "141_s": "11.986*Math.log(pt)-24.472",
        "600_s": "100-5.9766*Math.pow(pt,(-0.0345))",
        "r_min": "0.354",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "-30.86*Math.log(pt)+227.45",
        "vmd_b": "631.49*Math.pow(pt_b,-0.2531)",
        "tip": "ER80-05",
        "Dv01_b": "-30.86*Math.log(pt_b)+227.45",
        "141_b": "11.986*Math.log(pt_b)-24.472",
        "200_s": "17.263*Math.log(pt)-27.575",
        "color": "Brown",
        "tip_rate": "0.5",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.707",
        "vmd_s": "631.49*Math.pow(pt,-0.2531)",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "pre_orf": "N/A",
    },
    {
        "classification": 1,
        "ang": "80",
        "600_b": "100-5.0974*Math.pow(pt_b,(0.1625))",
        "pre-orf_no": "N/A",
        "part_no": "40270-06",
        "200_b": "13.154*Math.log(pt_b)-19.34",
        "csscolor": "tip-grey",
        "cv_tip": "0.095",
        "141_s": "10.829*Math.log(pt)-20.313",
        "600_s": "100-5.0974*Math.pow(pt,(0.1625))",
        "r_min": "0.424",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "-27.31*Math.log(pt)+224.83",
        "vmd_b": "594.42*Math.pow(pt_b,-0.2047)",
        "tip": "ER80-06",
        "Dv01_b": "-27.31*Math.log(pt_b)+224.83",
        "141_b": "10.829*Math.log(pt_b)-20.313",
        "200_s": "13.154*Math.log(pt)-19.34",
        "color": "Grey",
        "tip_rate": "0.6",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.849",
        "vmd_s": "594.42*Math.pow(pt,-0.2047)",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "N/A",
    },
    {
        "classification": 1,
        "ang": "80",
        "600_b": "100-186.04*Math.pow(pt_b,(-0.8714))",
        "pre-orf_no": "N/A",
        "part_no": "40270-08",
        "200_b": "16.004*Math.log(pt_b)-25.116",
        "csscolor": "tip-white",
        "cv_tip": "0.126",
        "141_s": "12.475*Math.log(pt)-25.383",
        "600_s": "100-186.04*Math.pow(pt,(-0.8714))",
        "r_min": "0.566",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "-40.76*Math.log(pt)+230.86",
        "vmd_b": "1078.6*Math.pow(pt_b,-0.3602)",
        "tip": "ER80-08",
        "Dv01_b": "-40.76*Math.log(pt_b)+230.86",
        "141_b": "12.475*Math.log(pt_b)-25.383",
        "200_s": "16.004*Math.log(pt)-25.116",
        "color": "White",
        "tip_rate": "0.8",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "1.131",
        "vmd_s": "1078.6*Math.pow(pt,-0.3602)",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "N/A",
    },
    {
        "classification": 1,
        "ang": "80",
        "600_b": "100-97.141*Math.pow(pt_b,(-0.4911))",
        "pre-orf_no": "N/A",
        "part_no": "40270-10",
        "200_b": "12.151*Math.log(pt_b)-20.728",
        "csscolor": "tip-lt_blue",
        "cv_tip": "0.158",
        "141_s": "8.229*Math.log(pt)-16.079",
        "600_s": "100-97.141*Math.pow(pt,(-0.4911))",
        "r_min": "0.707",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "-45.62*Math.log(pt)+268.47",
        "vmd_b": "1140.1*Math.pow(pt_b,-0.3045)",
        "tip": "ER80-10",
        "Dv01_b": "-45.62*Math.log(pt_b)+268.47",
        "141_b": "8.229*Math.log(pt_b)-16.079",
        "200_s": "12.151*Math.log(pt)-20.728",
        "color": "Lt Blue",
        "tip_rate": "1",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "1.414",
        "vmd_s": "1140.1*Math.pow(pt,-0.3045)",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "N/A",
    },
    {
        "classification": 1,
        "ang": "80",
        "600_b": "100-113.1*Math.pow(pt_b,(-0.5196))",
        "pre-orf_no": "N/A",
        "part_no": "40270-125",
        "200_b": "8.8095*Math.log(pt_b)-9.1844",
        "csscolor": "tip-teal",
        "cv_tip": "0.198",
        "141_s": "5.5198*Math.log(pt)-7.4765",
        "600_s": "100-113.1*Math.pow(pt,(-0.5196))",
        "r_min": "0.884",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "-31.24*Math.log(pt)+221.48",
        "vmd_b": "995.77*Math.pow(pt_b,-0.259)",
        "tip": "ER80-125",
        "Dv01_b": "-31.24*Math.log(pt_b)+221.48",
        "141_b": "5.5198*Math.log(pt_b)-7.4765",
        "200_s": "8.8095*Math.log(pt)-9.1844",
        "color": "Teal",
        "tip_rate": "1.25",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "1.768",
        "vmd_s": "995.77*Math.pow(pt,-0.259)",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "N/A",
    },
    {
        "classification": 1,
        "ang": "80",
        "600_b": "100-64.393*Math.pow(pt_b,(-0.3303))",
        "pre-orf_no": "N/A",
        "part_no": "40270-15",
        "200_b": "12.011*Math.log(pt_b)-22.216",
        "csscolor": "tip-lt_green",
        "cv_tip": "0.237",
        "141_s": "7.6316*Math.log(pt)-15.788",
        "600_s": "100-64.393*Math.pow(pt,(-0.3303))",
        "r_min": "1.061",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "563.95*Math.pow(pt,-0.448)",
        "vmd_b": "1107.3*Math.pow(pt_b,-0.2907)",
        "tip": "ER80-15",
        "Dv01_b": "563.95*Math.pow(pt_b,-0.448)",
        "141_b": "7.6316*Math.log(pt_b)-15.788",
        "200_s": "12.011*Math.log(pt)-22.216",
        "color": "Lt Green",
        "tip_rate": "1.5",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "2.121",
        "vmd_s": "1107.3*Math.pow(pt,-0.2907)",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "N/A",
    },
    {
        "classification": 1,
        "ang": "80",
        "600_b": "100-137.6*Math.pow(pt_b,(-0.4785))",
        "pre-orf_no": "N/A",
        "part_no": "40270-20",
        "200_b": "9.5861*Math.log(pt_b)-16.846",
        "csscolor": "tip-tan",
        "cv_tip": "0.316",
        "141_s": "5.9039*Math.log(pt)-11.252",
        "600_s": "100-137.6*Math.pow(pt,(-0.4785))",
        "r_min": "1.414",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "624.08*Math.pow(pt,-0.444)",
        "vmd_b": "1111.5*Math.pow(pt_b,-0.2591)",
        "tip": "ER80-20",
        "Dv01_b": "624.08*Math.pow(pt_b,-0.444)",
        "141_b": "5.9039*Math.log(pt_b)-11.252",
        "200_s": "9.5861*Math.log(pt)-16.846",
        "color": "Tan",
        "tip_rate": "2",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "2.828",
        "vmd_s": "1111.5*Math.pow(pt,-0.2591)",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "N/A",
    },
    {
        "classification": 1,
        "ang": "80",
        "600_b": "100-96.14*Math.pow(pt_b,(-0.366))",
        "pre-orf_no": "N/A",
        "part_no": "40270-25",
        "200_b": "9.8963*Math.log(pt_b)-17.337",
        "csscolor": "tip-black",
        "cv_tip": "0.395",
        "141_s": "5.5917*Math.log(pt)-9.4402",
        "600_s": "100-96.14*Math.pow(pt,(-0.366))",
        "r_min": "1.768",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "505.77*Math.pow(pt,-0.397)",
        "vmd_b": "1155.7*Math.pow(pt_b,-0.2697)",
        "tip": "ER80-25",
        "Dv01_b": "505.77*Math.pow(pt_b,-0.397)",
        "141_b": "5.5917*Math.log(pt_b)-9.4402",
        "200_s": "9.8963*Math.log(pt)-17.337",
        "color": "Black",
        "tip_rate": "2.5",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "3.536",
        "vmd_s": "1155.7*Math.pow(pt,-0.2697)",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "N/A",
    },
    {
        "classification": 1,
        "ang": "80",
        "600_b": "100-117.2*Math.pow(pt_b,(-0.3932))",
        "pre-orf_no": "N/A",
        "part_no": "40270-30",
        "200_b": "8.3306*Math.log(pt_b)-14.241",
        "csscolor": "tip-black",
        "cv_tip": "0.474",
        "141_s": "4.588*Math.log(pt)-8.8927",
        "600_s": "100-117.2*Math.pow(pt,(-0.3932))",
        "r_min": "2.121",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "543.8*Math.pow(pt,-0.374)",
        "vmd_b": "1234*Math.pow(pt_b,-0.2771)",
        "tip": "ER80-30",
        "Dv01_b": "543.8*Math.pow(pt_b,-0.374)",
        "141_b": "4.588*Math.log(pt_b)-8.8927",
        "200_s": "8.3306*Math.log(pt)-14.241",
        "color": "Black",
        "tip_rate": "3",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "4.243",
        "vmd_s": "1234*Math.pow(pt,-0.2771)",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "N/A",
    },
    {
        "classification": 1,
        "ang": "80",
        "600_b": "100-113.97*Math.pow(pt_b,(-0.386))",
        "pre-orf_no": "N/A",
        "part_no": "40270-40",
        "200_b": "8.8396*Math.log(pt_b)-16.931",
        "csscolor": "tip-black",
        "cv_tip": "0.632",
        "141_s": "4.588*Math.log(pt)-8.8927",
        "600_s": "100-113.97*Math.pow(pt,(-0.386))",
        "r_min": "2.828",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "615.49*Math.pow(pt,-0.391)",
        "vmd_b": "1191.1*Math.pow(pt_b,-0.2677)",
        "tip": "ER80-40",
        "Dv01_b": "615.49*Math.pow(pt_b,-0.391)",
        "141_b": "4.588*Math.log(pt_b)-8.8927",
        "200_s": "8.8396*Math.log(pt)-16.931",
        "color": "Black",
        "tip_rate": "4",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "5.657",
        "vmd_s": "1191.1*Math.pow(pt,-0.2677)",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "N/A",
    },
    {
        "classification": 1,
        "ang": "80",
        "600_b": "100-115.33*Math.pow(pt_b,(-0.3794))",
        "pre-orf_no": "N/A",
        "part_no": "40270-50",
        "200_b": "7.4426*Math.log(pt_b)-12.685",
        "csscolor": "tip-black",
        "cv_tip": "0.791",
        "141_s": "3.4627*Math.log(pt)-5.399",
        "600_s": "100-115.33*Math.pow(pt,(-0.3794))",
        "r_min": "3.536",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "518.79*Math.pow(pt,-0.335)",
        "vmd_b": "1184.9*Math.pow(pt_b,-0.2623)",
        "tip": "ER80-50",
        "Dv01_b": "518.79*Math.pow(pt_b,-0.335)",
        "141_b": "3.4627*Math.log(pt_b)-5.399",
        "200_s": "7.4426*Math.log(pt)-12.685",
        "color": "Black",
        "tip_rate": "5",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "7.071",
        "vmd_s": "1184.9*Math.pow(pt,-0.2623)",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "N/A",
    },
    {
        "classification": 1,
        "ang": "80",
        "600_b": "100-39.361*Math.exp((-0.007*pt_b))",
        "pre-orf_no": "N/A",
        "part_no": "40270-60",
        "200_b": "7.7614*Math.log(pt_b)-12.884",
        "csscolor": "tip-black",
        "cv_tip": "0.949",
        "141_s": "4.1517*Math.log(pt)-6.859",
        "600_s": "100-39.361*Math.exp((-0.007*pt))",
        "r_min": "4.243",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "503.45*Math.pow(pt,-0.344)",
        "vmd_b": "1037.8*Math.pow(pt_b,-0.2299)",
        "tip": "ER80-60",
        "Dv01_b": "503.45*Math.pow(pt_b,-0.344)",
        "141_b": "4.1517*Math.log(pt_b)-6.859",
        "200_s": "7.7614*Math.log(pt)-12.884",
        "color": "Black",
        "tip_rate": "6",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "8.485",
        "vmd_s": "1037.8*Math.pow(pt,-0.2299)",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "N/A",
    },
    {
        "classification": 0,
        "ang": "80",
        "600_b": "100-8.1464*Math.pow(pt_b,(-0.3059))",
        "pre-orf_no": "40285-015",
        "part_no": "40288-01",
        "200_b": "42.509*Math.log(pt_b)-105.66",
        "csscolor": "tip-orange",
        "cv_tip": "0.016",
        "141_s": "30.057*Math.log(pt)-81.727",
        "600_s": "100-8.1464*Math.pow(pt,(-0.3059))",
        "r_min": "0.079",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "645.63*Math.pow(pt,-0.503)",
        "vmd_b": "1549.7*Math.pow(pt_b,(-0.5567))",
        "tip": "SR80-01",
        "Dv01_b": "645.63*Math.pow(pt_b,-0.503)",
        "141_b": "30.057*Math.log(pt_b)-81.727",
        "200_s": "42.509*Math.log(pt)-105.66",
        "color": "Orange",
        "tip_rate": "0.1",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.141",
        "vmd_s": "1549.7*Math.pow(pt,(-0.5567))",
        "screen_no": "100 Mesh (#40251-00)",
        "screen": "100/Green",
        "pre_orf": "R015",
    },
    {
        "classification": 0,
        "ang": "80",
        "600_b": "100-84.433*Math.pow(pt_b,(-0.8425))",
        "pre-orf_no": "40285-02",
        "part_no": "40288-015",
        "200_b": "31.652*Math.log(pt_b)-76.006",
        "csscolor": "tip-green",
        "cv_tip": "0.024",
        "141_s": "19.774*Math.log(pt)-51.001",
        "600_s": "100-84.433*Math.pow(pt,(-0.8425))",
        "r_min": "0.119",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "534.29*Math.pow(pt,-0.43)",
        "vmd_b": "1264.3*Math.pow(pt_b,(-0.4622))",
        "tip": "SR80-015",
        "Dv01_b": "534.29*Math.pow(pt_b,-0.43)",
        "141_b": "19.774*Math.log(pt_b)-51.001",
        "200_s": "31.652*Math.log(pt)-76.006",
        "color": "Green",
        "tip_rate": "0.15",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.212",
        "vmd_s": "1264.3*Math.pow(pt,(-0.4622))",
        "screen_no": "100 Mesh (#40251-00)",
        "screen": "100/Green",
        "pre_orf": "R02",
    },
    {
        "classification": 0,
        "ang": "80",
        "600_b": "100-149.39*Math.pow(pt_b,(-1.0057))",
        "pre-orf_no": "40285-025",
        "part_no": "40288-02",
        "200_b": "24.697*Math.log(pt_b)-52.727",
        "csscolor": "tip-yellow",
        "cv_tip": "0.032",
        "141_s": "16.638*Math.log(pt)-40.918",
        "600_s": "100-149.39*Math.pow(pt,(-1.0057))",
        "r_min": "0.158",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "456.25*Math.pow(pt,-0.384)",
        "vmd_b": "811.97*Math.pow(pt_b,(-0.3382))",
        "tip": "SR80-02",
        "Dv01_b": "456.25*Math.pow(pt_b,-0.384)",
        "141_b": "16.638*Math.log(pt_b)-40.918",
        "200_s": "24.697*Math.log(pt)-52.727",
        "color": "Yellow",
        "tip_rate": "0.2",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.283",
        "vmd_s": "811.97*Math.pow(pt,(-0.3382))",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "pre_orf": "R025",
    },
    {
        "classification": 0,
        "ang": "80",
        "600_b": "100-175.53*Math.pow(pt_b,(-0.9326))",
        "pre-orf_no": "40285-03",
        "part_no": "40288-025",
        "200_b": "21.9*Math.log(pt_b)-50.887",
        "csscolor": "tip-purple",
        "cv_tip": "0.040",
        "141_s": "12.847*Math.log(pt)-32.298",
        "600_s": "100-175.53*Math.pow(pt,(-0.9326))",
        "r_min": "0.198",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "560.97*Math.pow(pt,-0.406)",
        "vmd_b": "961.23*Math.pow(pt_b,(-0.3463))",
        "tip": "SR80-025",
        "Dv01_b": "560.97*Math.pow(pt_b,-0.406)",
        "141_b": "12.847*Math.log(pt_b)-32.298",
        "200_s": "21.9*Math.log(pt)-50.887",
        "color": "Purple",
        "tip_rate": "0.25",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.354",
        "vmd_s": "961.23*Math.pow(pt,(-0.3463))",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "pre_orf": "R03",
    },
    {
        "classification": 0,
        "ang": "80",
        "600_b": "100-74.911*Math.pow(pt_b,(-0.5694))",
        "pre-orf_no": "40285-03",
        "part_no": "40288-03",
        "200_b": "19.447*Math.log(pt_b)-48.844",
        "csscolor": "tip-blue",
        "cv_tip": "0.047",
        "141_s": "10.794*Math.log(pt)-27.454",
        "600_s": "100-74.911*Math.pow(pt,(-0.5694))",
        "r_min": "0.237",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "775.96*Math.pow(pt,-0.458)",
        "vmd_b": "1219.7*Math.pow(pt_b,(-0.3719))",
        "tip": "SR80-03",
        "Dv01_b": "775.96*Math.pow(pt_b,-0.458)",
        "141_b": "10.794*Math.log(pt_b)-27.454",
        "200_s": "19.447*Math.log(pt)-48.844",
        "color": "Blue",
        "tip_rate": "0.3",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.424",
        "vmd_s": "1219.7*Math.pow(pt,(-0.3719))",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "pre_orf": "R03",
    },
    {
        "classification": 0,
        "ang": "80",
        "600_b": "100-110.7*Math.pow(pt_b,(-0.63))",
        "pre-orf_no": "40285-06",
        "part_no": "40288-04",
        "200_b": "18.455*Math.log(pt_b)-43.926",
        "csscolor": "tip-red",
        "cv_tip": "0.063",
        "141_s": "9.4906*Math.log(pt)-25.212",
        "600_s": "100-110.7*Math.pow(pt,(-0.63))",
        "r_min": "0.316",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "633.4*Math.pow(pt,-0.417)",
        "vmd_b": "1190.9*Math.pow(pt_b,(-0.365))",
        "tip": "SR80-04",
        "Dv01_b": "633.4*Math.pow(pt_b,-0.417)",
        "141_b": "9.4906*Math.log(pt_b)-25.212",
        "200_s": "18.455*Math.log(pt)-43.926",
        "color": "Red",
        "tip_rate": "0.4",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.566",
        "vmd_s": "1190.9*Math.pow(pt,(-0.365))",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "pre_orf": "R06",
    },
    {
        "classification": 0,
        "ang": "80",
        "600_b": "100-141.06*Math.pow(pt_b,(-0.6192))",
        "pre-orf_no": "40285-06",
        "part_no": "40288-05",
        "200_b": "17.31*Math.log(pt_b)-43.958",
        "csscolor": "tip-brown",
        "cv_tip": "0.079",
        "141_s": "9.4906*Math.log(pt)-25.212",
        "600_s": "100-141.06*Math.pow(pt,(-0.6192))",
        "r_min": "0.395",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "823.18*Math.pow(pt,-0.457)",
        "vmd_b": "1382.8*Math.pow(pt_b,(-0.3787))",
        "tip": "SR80-05",
        "Dv01_b": "823.18*Math.pow(pt_b,-0.457)",
        "141_b": "9.4906*Math.log(pt_b)-25.212",
        "200_s": "17.31*Math.log(pt)-43.958",
        "color": "Brown",
        "tip_rate": "0.5",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.707",
        "vmd_s": "1382.8*Math.pow(pt,(-0.3787))",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "pre_orf": "R06",
    },
    {
        "classification": 0,
        "ang": "80",
        "600_b": "100-199.26*Math.pow(pt_b,(-0.685))",
        "pre-orf_no": "40285-08",
        "part_no": "40288-06",
        "200_b": "10.378*Math.log(pt_b)-24.082",
        "csscolor": "tip-grey",
        "cv_tip": "0.095",
        "141_s": "5.3155*Math.log(pt)-12.878",
        "600_s": "100-199.26*Math.pow(pt,(-0.685))",
        "r_min": "0.474",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "712.29*Math.pow(pt,-0.38)",
        "vmd_b": "1007.8*Math.pow(pt_b,(-0.2575))",
        "tip": "SR80-06",
        "Dv01_b": "712.29*Math.pow(pt_b,-0.38)",
        "141_b": "5.3155*Math.log(pt_b)-12.878",
        "200_s": "10.378*Math.log(pt)-24.082",
        "color": "Grey",
        "tip_rate": "0.6",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.849",
        "vmd_s": "1007.8*Math.pow(pt,(-0.2575))",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "R08",
    },
    {
        "classification": 1,
        "ang": "80",
        "600_b": "100-391.04*Math.pow(pt_b,(-0.6617))",
        "pre-orf_no": "40285-10",
        "part_no": "40288-08",
        "200_b": "8.0275*Math.log(pt_b)-15.006",
        "csscolor": "tip-white",
        "cv_tip": "0.126",
        "141_s": "5.2051*Math.log(pt)-10.089",
        "600_s": "100-391.04*Math.pow(pt,(-0.6617))",
        "r_min": "0.632",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "508.17*Math.pow(pt,-0.363)",
        "vmd_b": "-143.51*Math.log(pt_b)+977.97",
        "tip": "SR80-08",
        "Dv01_b": "508.17*Math.pow(pt_b,-0.363)",
        "141_b": "5.2051*Math.log(pt_b)-10.089",
        "200_s": "8.0275*Math.log(pt)-15.006",
        "color": "White",
        "tip_rate": "0.8",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "1.131",
        "vmd_s": "-143.51*Math.log(pt)+977.97",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "R10",
    },
    {
        "classification": 1,
        "ang": "80",
        "600_b": "100-373.88*Math.pow(pt_b,(-0.6241))",
        "pre-orf_no": "40285-125",
        "part_no": "40288-10",
        "200_b": "7.9357*Math.log(pt_b)-16.38",
        "csscolor": "tip-lt_blue",
        "cv_tip": "0.158",
        "141_s": "4.3822*Math.log(pt)-8.3043",
        "600_s": "100-373.88*Math.pow(pt,(-0.6241))",
        "r_min": "0.791",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "673.98*Math.pow(pt,-0.41)",
        "vmd_b": "-138.79*Math.log(pt_b)+983.67",
        "tip": "SR80-10",
        "Dv01_b": "673.98*Math.pow(pt_b,-0.41)",
        "141_b": "4.3822*Math.log(pt_b)-8.3043",
        "200_s": "7.9357*Math.log(pt)-16.38",
        "color": "Lt Blue",
        "tip_rate": "1",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "1.414",
        "vmd_s": "-138.79*Math.log(pt)+983.67",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "R12.5",
    },
    {
        "classification": 1,
        "ang": "80",
        "600_b": "100-231.91*Math.pow(pt_b,(-0.4828))",
        "pre-orf_no": "40285-20",
        "part_no": "40288-125",
        "200_b": "7.0187*Math.log(pt_b)-12.75",
        "csscolor": "tip-teal",
        "cv_tip": "0.198",
        "141_s": "4.3649*Math.log(pt)-7.9745",
        "600_s": "100-231.91*Math.pow(pt,(-0.4828))",
        "r_min": "0.988",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "554.42*Math.pow(pt,-0.367)",
        "vmd_b": "-120.58*Math.log(pt_b)+919.07",
        "tip": "SR80-125",
        "Dv01_b": "554.42*Math.pow(pt_b,-0.367)",
        "141_b": "4.3649*Math.log(pt_b)-7.9745",
        "200_s": "7.0187*Math.log(pt)-12.75",
        "color": "Teal",
        "tip_rate": "1.25",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "1.768",
        "vmd_s": "-120.58*Math.log(pt)+919.07",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "R20",
    },
    {
        "classification": 1,
        "ang": "80",
        "600_b": "100-222.4*Math.pow(pt_b,(-0.424))",
        "pre-orf_no": "40285-20",
        "part_no": "40288-15",
        "200_b": "5.0026*Math.log(pt_b)-8.0897",
        "csscolor": "tip-lt_green",
        "cv_tip": "0.237",
        "141_s": "2.1862*Math.log(pt)-1.7508",
        "600_s": "100-222.4*Math.pow(pt,(-0.424))",
        "r_min": "1.186",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "646.52*Math.pow(pt,-0.361)",
        "vmd_b": "-120.03*Math.log(pt_b)+961.95",
        "tip": "SR80-15",
        "Dv01_b": "646.52*Math.pow(pt_b,-0.361)",
        "141_b": "2.1862*Math.log(pt_b)-1.7508",
        "200_s": "5.0026*Math.log(pt)-8.0897",
        "color": "Lt Green",
        "tip_rate": "1.5",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "2.121",
        "vmd_s": "-120.03*Math.log(pt)+961.95",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "R20",
    },
    {
        "classification": 1,
        "ang": "80",
        "600_b": "100-227.97*Math.pow(pt_b,(-0.435))",
        "pre-orf_no": "40285-25",
        "part_no": "40288-20",
        "200_b": "4.9803*Math.log(pt_b)-8.4879",
        "csscolor": "tip-tan",
        "cv_tip": "0.316",
        "141_s": "2.2654*Math.log(pt)-2.2416",
        "600_s": "100-227.97*Math.pow(pt,(-0.435))",
        "r_min": "1.581",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "679.82*Math.pow(pt,-0.368)",
        "vmd_b": "-126.05*Math.log(pt_b)+979.75",
        "tip": "SR80-20",
        "Dv01_b": "679.82*Math.pow(pt_b,-0.368)",
        "141_b": "2.2654*Math.log(pt_b)-2.2416",
        "200_s": "4.9803*Math.log(pt)-8.4879",
        "color": "Tan",
        "tip_rate": "2",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "2.828",
        "vmd_s": "-126.05*Math.log(pt)+979.75",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "R25",
    },
    {
        "classification": 1,
        "ang": "80",
        "600_b": "100-170.42*Math.pow(pt_b,(-0.3849))",
        "pre-orf_no": "40285-40",
        "part_no": "40288-25",
        "200_b": "4.5657*Math.log(pt_b)-6.6208",
        "csscolor": "tip-black",
        "cv_tip": "0.395",
        "141_s": "2.7885*Math.log(pt)-3.993",
        "600_s": "100-170.42*Math.pow(pt,(-0.3849))",
        "r_min": "1.976",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "578.07*Math.pow(pt,-0.332)",
        "vmd_b": "-111.42*Math.log(pt_b)+890.25",
        "tip": "SR80-25",
        "Dv01_b": "578.07*Math.pow(pt_b,-0.332)",
        "141_b": "2.7885*Math.log(pt_b)-3.993",
        "200_s": "4.5657*Math.log(pt)-6.6208",
        "color": "Black",
        "tip_rate": "2.5",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "3.536",
        "vmd_s": "-111.42*Math.log(pt)+890.25",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "R40",
    },
    {
        "classification": 1,
        "ang": "80",
        "600_b": "100-177.52*Math.pow(pt_b,(-0.3958))",
        "pre-orf_no": "40285-40",
        "part_no": "40288-30",
        "200_b": "4.9746*Math.log(pt_b)-8.5738",
        "csscolor": "tip-black",
        "cv_tip": "0.474",
        "141_s": "2.4093*Math.log(pt)-3.369",
        "600_s": "100-177.52*Math.pow(pt,(-0.3958))",
        "r_min": "2.372",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "679.82*Math.pow(pt,-0.368)",
        "vmd_b": "1164.6*Math.pow(pt_b,(-0.2437))",
        "tip": "SR80-30",
        "Dv01_b": "679.82*Math.pow(pt_b,-0.368)",
        "141_b": "2.4093*Math.log(pt_b)-3.369",
        "200_s": "4.9746*Math.log(pt)-8.5738",
        "color": "Black",
        "tip_rate": "3",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "4.243",
        "vmd_s": "1164.6*Math.pow(pt,(-0.2437))",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "R40",
    },
    {
        "classification": 1,
        "ang": "80",
        "600_b": "100-148.42*Math.pow(pt_b,(-0.3571))",
        "pre-orf_no": "40285-50",
        "part_no": "40288-40",
        "200_b": "4.5815*Math.log(pt_b)-7.3353",
        "csscolor": "tip-black",
        "cv_tip": "0.632",
        "141_s": "2.097*Math.log(pt)-2.6572",
        "600_s": "100-148.42*Math.pow(pt,(-0.3571))",
        "r_min": "3.162",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "578.07*Math.pow(pt,-0.332)",
        "vmd_b": "1038.4*Math.pow(pt_b,(-0.2166))",
        "tip": "SR80-40",
        "Dv01_b": "578.07*Math.pow(pt_b,-0.332)",
        "141_b": "2.097*Math.log(pt_b)-2.6572",
        "200_s": "4.5815*Math.log(pt)-7.3353",
        "color": "Black",
        "tip_rate": "4",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "5.657",
        "vmd_s": "1038.4*Math.pow(pt,(-0.2166))",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "R50",
    },
    {
        "classification": 1,
        "ang": "80",
        "600_b": "100-55.271*Math.pow(pt_b,(-0.0092)*pt_b)",
        "pre-orf_no": "40285-50",
        "part_no": "40288-50",
        "200_b": "7.4838*Math.log(pt_b)-14.869",
        "csscolor": "tip-black",
        "cv_tip": "0.791",
        "141_s": "2.097*Math.log(pt)-2.6572",
        "600_s": "100-55.271*Math.pow(pt,(-0.0092)*pt)",
        "r_min": "3.953",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "",
        "vmd_b": "1200*Math.pow(pt_b,-0.2495)",
        "tip": "SR80-50",
        "Dv01_b": "",
        "141_b": "2.097*Math.log(pt_b)-2.6572",
        "200_s": "7.4838*Math.log(pt)-14.869",
        "color": "Black",
        "tip_rate": "5",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "7.071",
        "vmd_s": "1200*Math.pow(pt,-0.2495)",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "R50",
    },
    {
        "classification": 0,
        "ang": "80",
        "600_b": "100.0",
        "pre-orf_no": "40285-005",
        "part_no": "40290-005",
        "200_b": "51.123*Math.log(pt_b)-137.55",
        "csscolor": "tip-black",
        "cv_tip": "0.008",
        "141_s": "31.908*Math.log(pt)-91.892",
        "600_s": "100.0",
        "r_min": "0.040",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "874.74*Math.pow(pt,-0.55)",
        "vmd_b": "1524*Math.pow(pt_b,-0.5487)",
        "tip": "MR80-005",
        "Dv01_b": "874.74*Math.pow(pt_b,-0.55)",
        "141_b": "31.908*Math.log(pt_b)-91.892",
        "200_s": "51.123*Math.log(pt)-137.55",
        "color": "Black",
        "tip_rate": "0.05",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.071",
        "vmd_s": "1524*Math.pow(pt,-0.5487)",
        "screen_no": "100 Mesh (#40251-00)",
        "screen": "100/Green",
        "pre_orf": "R005",
    },
    {
        "classification": 0,
        "ang": "80",
        "600_b": "100",
        "pre-orf_no": "40285-007",
        "part_no": "40290-007",
        "200_b": "Math.min(45.197*Math.log(pt_b)-106.29,100)",
        "csscolor": "tip-pink",
        "cv_tip": "0.011",
        "141_s": "32.349*Math.log(pt)-86.353",
        "600_s": "100",
        "r_min": "0.053",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "516.49*Math.pow(pt,-0.444)",
        "vmd_b": "1210.2*Math.pow(pt_b,-0.5139)",
        "tip": "MR80-0067",
        "Dv01_b": "516.49*Math.pow(pt_b,-0.444)",
        "141_b": "32.349*Math.log(pt_b)-86.353",
        "200_s": "Math.min(45.197*Math.log(pt)-106.29,100)",
        "color": "Pink",
        "tip_rate": "0.067",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.095",
        "vmd_s": "1210.2*Math.pow(pt,-0.5139)",
        "screen_no": "100 Mesh (#40251-00)",
        "screen": "100/Green",
        "pre_orf": "R0067",
    },
    {
        "classification": 0,
        "ang": "80",
        "600_b": "100-0.016888*pt_b+2.0882",
        "pre-orf_no": "40285-01",
        "part_no": "40290-01",
        "200_b": "34.542*Math.log(pt_b)-73.88",
        "csscolor": "tip-orange",
        "cv_tip": "0.016",
        "141_s": "25.497*Math.log(pt)-64.02",
        "600_s": "100-0.016888*pt+2.0882",
        "r_min": "0.079",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "460.56*Math.pow(pt,-0.418)",
        "vmd_b": "1044*Math.pow(pt_b,-0.4599)",
        "tip": "MR80-01",
        "Dv01_b": "460.56*Math.pow(pt_b,-0.418)",
        "141_b": "25.497*Math.log(pt_b)-64.02",
        "200_s": "34.542*Math.log(pt)-73.88",
        "color": "Orange",
        "tip_rate": "0.1",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.141",
        "vmd_s": "1044*Math.pow(pt,-0.4599)",
        "screen_no": "100 Mesh (#40251-00)",
        "screen": "100/Green",
        "pre_orf": "RO1",
    },
    {
        "classification": 0,
        "ang": "80",
        "600_b": "100-1620.2*Math.pow(pt_b,(-1.6499))",
        "pre-orf_no": "40285-015",
        "part_no": "40290-015",
        "200_b": "24.418*Math.log(pt_b)-61.818",
        "csscolor": "tip-green",
        "cv_tip": "0.024",
        "141_s": "13.6*Math.log(pt)-36.141",
        "600_s": "100-1620.2*Math.pow(pt,(-1.6499))",
        "r_min": "0.119",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "733.23*Math.pow(pt,-0.455)",
        "vmd_b": "1512.8*Math.pow(pt_b,-0.454)",
        "tip": "MR80-015",
        "Dv01_b": "733.23*Math.pow(pt_b,-0.455)",
        "141_b": "13.6*Math.log(pt_b)-36.141",
        "200_s": "24.418*Math.log(pt)-61.818",
        "color": "Green",
        "tip_rate": "0.15",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.212",
        "vmd_s": "1512.8*Math.pow(pt,-0.454)",
        "screen_no": "100 Mesh (#40251-00)",
        "screen": "100/Green",
        "pre_orf": "R015",
    },
    {
        "classification": 0,
        "ang": "80",
        "600_b": "100-20.177*Math.pow(pt_b,(-0.3367))",
        "pre-orf_no": "40285-02",
        "part_no": "40290-02",
        "200_b": "19.187*Math.log(pt_b)-47.265",
        "csscolor": "tip-yellow",
        "cv_tip": "0.032",
        "141_s": "10.824*Math.log(pt)-28.67",
        "600_s": "100-20.177*Math.pow(pt,(-0.3367))",
        "r_min": "0.158",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "660.64*Math.pow(pt,-0.412)",
        "vmd_b": "952.77*Math.pow(pt_b,-0.3155)",
        "tip": "MR80-02",
        "Dv01_b": "660.64*Math.pow(pt_b,-0.412)",
        "141_b": "10.824*Math.log(pt_b)-28.67",
        "200_s": "19.187*Math.log(pt)-47.265",
        "color": "Yellow",
        "tip_rate": "0.2",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.283",
        "vmd_s": "952.77*Math.pow(pt,-0.3155)",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "pre_orf": "R02",
    },
    {
        "classification": 0,
        "ang": "80",
        "600_b": "100-246.52*Math.pow(pt_b,(-0.7514))",
        "pre-orf_no": "40285-025",
        "part_no": "40290-025",
        "200_b": "13.114*Math.log(pt_b)-34.429",
        "csscolor": "tip-purple",
        "cv_tip": "0.040",
        "141_s": "6.5235*Math.log(pt)-17.569",
        "600_s": "100-246.52*Math.pow(pt,(-0.7514))",
        "r_min": "0.198",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "948.37*Math.pow(pt,-0.45)",
        "vmd_b": "1457.8*Math.pow(pt_b,-0.3627)",
        "tip": "MR80-025",
        "Dv01_b": "948.37*Math.pow(pt_b,-0.45)",
        "141_b": "6.5235*Math.log(pt_b)-17.569",
        "200_s": "13.114*Math.log(pt)-34.429",
        "color": "Purple",
        "tip_rate": "0.25",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.354",
        "vmd_s": "1457.8*Math.pow(pt,-0.3627)",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "pre_orf": "R025",
    },
    {
        "classification": 0,
        "ang": "80",
        "600_b": "100-360.66*Math.pow(pt_b,(-0.8618))",
        "pre-orf_no": "40285-03",
        "part_no": "40290-03",
        "200_b": "12.505*Math.log(pt_b)-32.26",
        "csscolor": "tip-blue",
        "cv_tip": "0.047",
        "141_s": "6.5781*Math.log(pt)-17.705",
        "600_s": "100-360.66*Math.pow(pt,(-0.8618))",
        "r_min": "0.237",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "947.44*Math.pow(pt,-0.45)",
        "vmd_b": "1457.7*Math.pow(pt_b,-0.3577)",
        "tip": "MR80-03",
        "Dv01_b": "947.44*Math.pow(pt_b,-0.45)",
        "141_b": "6.5781*Math.log(pt_b)-17.705",
        "200_s": "12.505*Math.log(pt)-32.26",
        "color": "Blue",
        "tip_rate": "0.3",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.424",
        "vmd_s": "1457.7*Math.pow(pt,-0.3577)",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "pre_orf": "R03",
    },
    {
        "classification": 0,
        "ang": "80",
        "600_b": "100-206.56*Math.pow(pt_b,(-0.6906))",
        "pre-orf_no": "40285-04",
        "part_no": "40290-04",
        "200_b": "12.349*Math.log(pt_b)-30.654",
        "csscolor": "tip-red",
        "cv_tip": "0.063",
        "141_s": "6.8117*Math.log(pt)-17.868",
        "600_s": "100-206.56*Math.pow(pt,(-0.6906))",
        "r_min": "0.316",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "837.65*Math.pow(pt,-0.428)",
        "vmd_b": "1168.9*Math.pow(pt_b,-0.3008)",
        "tip": "MR80-04",
        "Dv01_b": "837.65*Math.pow(pt_b,-0.428)",
        "141_b": "6.8117*Math.log(pt_b)-17.868",
        "200_s": "12.349*Math.log(pt)-30.654",
        "color": "Red",
        "tip_rate": "0.4",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.566",
        "vmd_s": "1168.9*Math.pow(pt,-0.3008)",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "pre_orf": "R04",
    },
    {
        "classification": 0,
        "ang": "80",
        "600_b": "100-303.27*Math.pow(pt_b,(-0.6579))",
        "pre-orf_no": "40285-05",
        "part_no": "40290-05",
        "200_b": "8.13*Math.log(pt_b)-20.882",
        "csscolor": "tip-brown",
        "cv_tip": "0.079",
        "141_s": "4.0751*Math.log(pt)-10.85",
        "600_s": "100-303.27*Math.pow(pt,(-0.6579))",
        "r_min": "0.395",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "999.24*Math.pow(pt,-0.416)",
        "vmd_b": "1275.3*Math.pow(pt_b,-0.2732)",
        "tip": "MR80-05",
        "Dv01_b": "999.24*Math.pow(pt_b,-0.416)",
        "141_b": "4.0751*Math.log(pt_b)-10.85",
        "200_s": "8.13*Math.log(pt)-20.882",
        "color": "Brown",
        "tip_rate": "0.5",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.707",
        "vmd_s": "1275.3*Math.pow(pt,-0.2732)",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "pre_orf": "R05",
    },
    {
        "classification": 0,
        "ang": "80",
        "600_b": "100-263.61*Math.pow(pt_b,(-0.5864))",
        "pre-orf_no": "40285-06",
        "part_no": "40290-06",
        "200_b": "6.6949*Math.log(pt_b)-17.153",
        "csscolor": "tip-grey",
        "cv_tip": "0.095",
        "141_s": "3.3781*Math.log(pt)-9.0044",
        "600_s": "100-263.61*Math.pow(pt,(-0.5864))",
        "r_min": "0.474",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "986.07*Math.pow(pt,-0.39)",
        "vmd_b": "1156.1*Math.pow(pt_b,-0.2314)",
        "tip": "MR80-06",
        "Dv01_b": "986.07*Math.pow(pt_b,-0.39)",
        "141_b": "3.3781*Math.log(pt_b)-9.0044",
        "200_s": "6.6949*Math.log(pt)-17.153",
        "color": "Grey",
        "tip_rate": "0.6",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.849",
        "vmd_s": "1156.1*Math.pow(pt,-0.2314)",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "R06",
    },
    {
        "classification": 1,
        "ang": "80",
        "600_b": "100-282.3*Math.pow(pt_b,(-0.6013))",
        "pre-orf_no": "40285-08",
        "part_no": "40290-08",
        "200_b": "10.71*Math.log(pt_b)-25.621",
        "csscolor": "tip-white",
        "cv_tip": "0.126",
        "141_s": "5.4257*Math.log(pt)-12.132",
        "600_s": "100-282.3*Math.pow(pt,(-0.6013))",
        "r_min": "0.632",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "1259.1*Math.pow(pt,-0.566)",
        "vmd_b": "1347.4*Math.pow(pt_b,-0.269)",
        "tip": "MR80-08",
        "Dv01_b": "1259.1*Math.pow(pt_b,-0.566)",
        "141_b": "5.4257*Math.log(pt_b)-12.132",
        "200_s": "10.71*Math.log(pt)-25.621",
        "color": "White",
        "tip_rate": "0.8",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "1.131",
        "vmd_s": "1347.4*Math.pow(pt,-0.269)",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "R08",
    },
    {
        "classification": 1,
        "ang": "80",
        "600_b": "100-172.03*Math.pow(pt_b,(-0.4475))",
        "pre-orf_no": "40285-10",
        "part_no": "40290-10",
        "200_b": "8.7734*Math.log(pt_b)-21.189",
        "csscolor": "tip-lt_blue",
        "cv_tip": "0.158",
        "141_s": "3.6932*Math.log(pt)-7.5442",
        "600_s": "100-172.03*Math.pow(pt,(-0.4475))",
        "r_min": "0.791",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "1059.9*Math.pow(pt,-0.486)",
        "vmd_b": "1145.9*Math.pow(pt_b,-0.2179)",
        "tip": "MR80-10",
        "Dv01_b": "1059.9*Math.pow(pt_b,-0.486)",
        "141_b": "3.6932*Math.log(pt_b)-7.5442",
        "200_s": "8.7734*Math.log(pt)-21.189",
        "color": "Lt Blue",
        "tip_rate": "1",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "1.414",
        "vmd_s": "1145.9*Math.pow(pt,-0.2179)",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "R010",
    },
    {
        "classification": 1,
        "ang": "80",
        "600_b": "100-151.91*Math.pow(pt_b,(-0.3629))",
        "pre-orf_no": "40285-125",
        "part_no": "40290-125",
        "200_b": "7.0738*Math.log(pt_b)-15.066",
        "csscolor": "tip-teal",
        "cv_tip": "0.198",
        "141_s": "3.5494*Math.log(pt)-6.8168",
        "600_s": "100-151.91*Math.pow(pt,(-0.3629))",
        "r_min": "0.988",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "906.89*Math.pow(pt,-0.4423)",
        "vmd_b": "1057.2*Math.pow(pt_b,-0.174)",
        "tip": "MR80-125",
        "Dv01_b": "906.89*Math.pow(pt_b,-0.4423)",
        "141_b": "3.5494*Math.log(pt_b)-6.8168",
        "200_s": "7.0738*Math.log(pt)-15.066",
        "color": "Teal",
        "tip_rate": "1.25",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "1.768",
        "vmd_s": "1057.2*Math.pow(pt,-0.174)",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "R12.5",
    },
    {
        "classification": 1,
        "ang": "80",
        "600_b": "100-143.91*Math.pow(pt_b,(-0.4282))",
        "pre-orf_no": "40285-15",
        "part_no": "40290-15",
        "200_b": "7.986*Math.log(pt_b)-14.463",
        "csscolor": "tip-lt_green",
        "cv_tip": "0.237",
        "141_s": "4.5457*Math.log(pt)-8.3372",
        "600_s": "100-143.91*Math.pow(pt,(-0.4282))",
        "r_min": "1.186",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "677.39*Math.pow(pt,-0.421)",
        "vmd_b": "1114.6*Math.pow(pt_b,-0.2284)",
        "tip": "MR80-15",
        "Dv01_b": "677.39*Math.pow(pt_b,-0.421)",
        "141_b": "4.5457*Math.log(pt_b)-8.3372",
        "200_s": "7.986*Math.log(pt)-14.463",
        "color": "Lt Green",
        "tip_rate": "1.5",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "2.121",
        "vmd_s": "1114.6*Math.pow(pt,-0.2284)",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "R15",
    },
    {
        "classification": 1,
        "ang": "80",
        "600_b": "100-222.5*Math.pow(pt_b,(-0.4936))",
        "pre-orf_no": "40285-20",
        "part_no": "40290-20",
        "200_b": "8.6163*Math.log(pt_b)-20.923",
        "csscolor": "tip-tan",
        "cv_tip": "0.316",
        "141_s": "4.0699*Math.log(pt)-8.9926",
        "600_s": "100-222.5*Math.pow(pt,(-0.4936))",
        "r_min": "1.581",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "-91.09*Math.log(pt)+523.16",
        "vmd_b": "1355.4*Math.pow(pt_b,-0.2579)",
        "tip": "MR80-20",
        "Dv01_b": "-91.09*Math.log(pt_b)+523.16",
        "141_b": "4.0699*Math.log(pt_b)-8.9926",
        "200_s": "8.6163*Math.log(pt)-20.923",
        "color": "Tan",
        "tip_rate": "2",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "2.828",
        "vmd_s": "1355.4*Math.pow(pt,-0.2579)",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "R20",
    },
    {
        "classification": 1,
        "ang": "80",
        "600_b": "100-170.38*Math.pow(pt_b,(-0.3918))",
        "pre-orf_no": "40285-25",
        "part_no": "40290-25",
        "200_b": "5.9324*Math.log(pt_b)-13.923",
        "csscolor": "tip-black",
        "cv_tip": "0.395",
        "141_s": "2.3423*Math.log(pt)-4.2566",
        "600_s": "100-170.38*Math.pow(pt,(-0.3918))",
        "r_min": "1.976",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "-77.89*Math.log(pt)+506.71",
        "vmd_b": "1284.3*Math.pow(pt_b,-0.222)",
        "tip": "MR80-25",
        "Dv01_b": "-77.89*Math.log(pt_b)+506.71",
        "141_b": "2.3423*Math.log(pt_b)-4.2566",
        "200_s": "5.9324*Math.log(pt)-13.923",
        "color": "Black",
        "tip_rate": "2.5",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "3.536",
        "vmd_s": "1284.3*Math.pow(pt,-0.222)",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "R25",
    },
    {
        "classification": 1,
        "ang": "80",
        "600_b": "100-196.48*Math.pow(pt_b,(-0.4334))",
        "pre-orf_no": "40285-30",
        "part_no": "40290-30",
        "200_b": "6.0114*Math.log(pt_b)-13.846",
        "csscolor": "tip-black",
        "cv_tip": "0.474",
        "141_s": "2.3374*Math.log(pt)-4.3053",
        "600_s": "100-196.48*Math.pow(pt,(-0.4334))",
        "r_min": "2.372",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "-77.79*Math.log(pt)+502.17",
        "vmd_b": "1218*Math.pow(pt_b,-0.2127)",
        "tip": "MR80-30",
        "Dv01_b": "-77.79*Math.log(pt_b)+502.17",
        "141_b": "2.3374*Math.log(pt_b)-4.3053",
        "200_s": "6.0114*Math.log(pt)-13.846",
        "color": "Black",
        "tip_rate": "3",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "4.243",
        "vmd_s": "1218*Math.pow(pt,-0.2127)",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "R30",
    },
    {
        "classification": 1,
        "ang": "80",
        "600_b": "100-157.42*Math.pow(pt_b,(-0.3914))",
        "pre-orf_no": "40285-40",
        "part_no": "40290-40",
        "200_b": "5.9363*Math.log(pt_b)-12.147",
        "csscolor": "tip-black",
        "cv_tip": "0.632",
        "141_s": "1.9631*Math.log(pt)-2.6326",
        "600_s": "100-157.42*Math.pow(pt,(-0.3914))",
        "r_min": "3.162",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "-69.66*Math.log(pt)+456.46",
        "vmd_b": "1239.8*Math.pow(pt_b,-0.2334)",
        "tip": "MR80-40",
        "Dv01_b": "-69.66*Math.log(pt_b)+456.46",
        "141_b": "1.9631*Math.log(pt_b)-2.6326",
        "200_s": "5.9363*Math.log(pt)-12.147",
        "color": "Black",
        "tip_rate": "4",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "5.657",
        "vmd_s": "1239.8*Math.pow(pt,-0.2334)",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "R40",
    },
    {
        "classification": 0,
        "ang": "80",
        "600_b": "100.0",
        "pre-orf_no": "40285-005",
        "part_no": "40280-005",
        "200_b": "51.037*Math.log(pt_b)-146.97",
        "csscolor": "tip-black",
        "cv_tip": "0.008",
        "141_s": "27.554*Math.log(pt)-82.319",
        "600_s": "100.0",
        "r_min": "0.040",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "1614*Math.pow(pt,-0.677)",
        "vmd_b": "2422.3*Math.pow(pt_b,-0.6382)",
        "tip": "DR80-005",
        "Dv01_b": "1614*Math.pow(pt_b,-0.677)",
        "141_b": "27.554*Math.log(pt_b)-82.319",
        "200_s": "51.037*Math.log(pt)-146.97",
        "color": "Black",
        "tip_rate": "0.05",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.071",
        "vmd_s": "2422.3*Math.pow(pt,-0.6382)",
        "screen_no": "100 Mesh (#40251-00)",
        "screen": "100/Green",
        "pre_orf": "R005",
    },
    {
        "classification": 0,
        "ang": "80",
        "600_b": "100",
        "pre-orf_no": "40285-007",
        "part_no": "40280-007",
        "200_b": "32.458*Math.log(pt_b)-89.169",
        "csscolor": "tip-pink",
        "cv_tip": "0.011",
        "141_s": "15.83*Math.log(pt)-45.109",
        "600_s": "100",
        "r_min": "0.053",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "875.08*Math.pow(pt,-0.495)",
        "vmd_b": "1650.6*Math.pow(pt_b,-0.494)",
        "tip": "DR80-0067",
        "Dv01_b": "875.08*Math.pow(pt_b,-0.495)",
        "141_b": "15.83*Math.log(pt_b)-45.109",
        "200_s": "32.458*Math.log(pt)-89.169",
        "color": "Pink",
        "tip_rate": "0.067",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.095",
        "vmd_s": "1650.6*Math.pow(pt,-0.494)",
        "screen_no": "100 Mesh (#40251-00)",
        "screen": "100/Green",
        "pre_orf": "R0067",
    },
    {
        "classification": 0,
        "ang": "80",
        "600_b": "100-Math.max(-8.0349*pt_b*pt_b+33.4,0)",
        "pre-orf_no": "40285-01",
        "part_no": "40280-01",
        "200_b": "25.799*Math.log(pt_b)-66.483",
        "csscolor": "tip-orange",
        "cv_tip": "0.016",
        "141_s": "13.739*Math.log(pt)-36.95",
        "600_s": "100 - Math.max(-8.0349*pt*pt+33.4,0)",
        "r_min": "0.079",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "746.01*Math.pow(pt,-0.459)",
        "vmd_b": "1409.8*Math.pow(pt_b,-0.4438)",
        "tip": "DR80-01",
        "Dv01_b": "746.01*Math.pow(pt_b,-0.459)",
        "141_b": "13.739*Math.log(pt_b)-36.95",
        "200_s": "25.799*Math.log(pt)-66.483",
        "color": "Orange",
        "tip_rate": "0.1",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.141",
        "vmd_s": "1409.8*Math.pow(pt,-0.4438)",
        "screen_no": "100 Mesh (#40251-00)",
        "screen": "100/Green",
        "pre_orf": "RO1",
    },
    {
        "classification": 0,
        "ang": "80",
        "600_b": "100-461.17*Math.pow(pt_b,(-1.0451))",
        "pre-orf_no": "40285-015",
        "part_no": "40280-015",
        "200_b": "11.907*Math.log(pt_b)-31.46",
        "csscolor": "tip-green",
        "cv_tip": "0.024",
        "141_s": "5.8813*Math.log(pt)-16.094",
        "600_s": "100-461.17*Math.pow(pt,(-1.0451))",
        "r_min": "0.119",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "1003.9*Math.pow(pt,-0.452)",
        "vmd_b": "1282.4*Math.pow(pt_b,-0.3298)",
        "tip": "DR80-015",
        "Dv01_b": "1003.9*Math.pow(pt_b,-0.452)",
        "141_b": "5.8813*Math.log(pt_b)-16.094",
        "200_s": "11.907*Math.log(pt)-31.46",
        "color": "Green",
        "tip_rate": "0.15",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.212",
        "vmd_s": "1282.4*Math.pow(pt,-0.3298)",
        "screen_no": "100 Mesh (#40251-00)",
        "screen": "100/Green",
        "pre_orf": "R015",
    },
    {
        "classification": 0,
        "ang": "80",
        "600_b": "100-243.76*Math.pow(pt_b,(-0.7418))",
        "pre-orf_no": "40285-02",
        "part_no": "40280-02",
        "200_b": "8.9278*Math.log(pt_b)-23.042",
        "csscolor": "tip-yellow",
        "cv_tip": "0.032",
        "141_s": "4.2837*Math.log(pt)-11.451",
        "600_s": "100-243.76*Math.pow(pt,(-0.7418))",
        "r_min": "0.158",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "968.3*Math.pow(pt,-0.418)",
        "vmd_b": "1169.7*Math.pow(pt_b,-0.2781)",
        "tip": "DR80-02",
        "Dv01_b": "968.3*Math.pow(pt_b,-0.418)",
        "141_b": "4.2837*Math.log(pt_b)-11.451",
        "200_s": "8.9278*Math.log(pt)-23.042",
        "color": "Yellow",
        "tip_rate": "0.2",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.283",
        "vmd_s": "1169.7*Math.pow(pt,-0.2781)",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "pre_orf": "R02",
    },
    {
        "classification": 0,
        "ang": "80",
        "600_b": "100-157.84*Math.pow(pt_b,(-0.5697))",
        "pre-orf_no": "40285-025",
        "part_no": "40280-025",
        "200_b": "8.2093*Math.log(pt_b)-20.373",
        "csscolor": "tip-purple",
        "cv_tip": "0.040",
        "141_s": "4.0993*Math.log(pt)-10.631",
        "600_s": "100-157.84*Math.pow(pt,(-0.5697))",
        "r_min": "0.198",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "850.13*Math.pow(pt,-0.383)",
        "vmd_b": "1024.6*Math.pow(pt_b,-0.2356)",
        "tip": "DR80-025",
        "Dv01_b": "850.13*Math.pow(pt_b,-0.383)",
        "141_b": "4.0993*Math.log(pt_b)-10.631",
        "200_s": "8.2093*Math.log(pt)-20.373",
        "color": "Purple",
        "tip_rate": "0.25",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.354",
        "vmd_s": "1024.6*Math.pow(pt,-0.2356)",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "pre_orf": "R025",
    },
    {
        "classification": 0,
        "ang": "80",
        "600_b": "100-307.16*Math.pow(pt_b,(-0.7018))",
        "pre-orf_no": "40285-03",
        "part_no": "40280-03",
        "200_b": "8.6604*Math.log(pt_b)-22.561",
        "csscolor": "tip-blue",
        "cv_tip": "0.047",
        "141_s": "4.4861*Math.log(pt)-12.369",
        "600_s": "100-307.16*Math.pow(pt,(-0.7018))",
        "r_min": "0.237",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "1016*Math.pow(pt,-0.424)",
        "vmd_b": "1146.3*Math.pow(pt_b,-0.2555)",
        "tip": "DR80-03",
        "Dv01_b": "1016*Math.pow(pt_b,-0.424)",
        "141_b": "4.4861*Math.log(pt_b)-12.369",
        "200_s": "8.6604*Math.log(pt)-22.561",
        "color": "Blue",
        "tip_rate": "0.3",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.424",
        "vmd_s": "1146.3*Math.pow(pt,-0.2555)",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "pre_orf": "R03",
    },
    {
        "classification": 0,
        "ang": "80",
        "600_b": "100-311.61*Math.pow(pt_b,(-0.6168))",
        "pre-orf_no": "40285-04",
        "part_no": "40280-04",
        "200_b": "6.3827*Math.log(pt_b)-17.041",
        "csscolor": "tip-red",
        "cv_tip": "0.063",
        "141_s": "3.1976*Math.log(pt)-8.8143",
        "600_s": "100-311.61*Math.pow(pt,(-0.6168))",
        "r_min": "0.316",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "-2.3506*pt+362.92",
        "vmd_b": "1226.7*Math.pow(pt_b,-0.2397)",
        "tip": "DR80-04",
        "Dv01_b": "-2.3506*pt_b+362.92",
        "141_b": "3.1976*Math.log(pt_b)-8.8143",
        "200_s": "6.3827*Math.log(pt)-17.041",
        "color": "Red",
        "tip_rate": "0.4",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.566",
        "vmd_s": "1226.7*Math.pow(pt,-0.2397)",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "pre_orf": "R04",
    },
    {
        "classification": 0,
        "ang": "80",
        "600_b": "100-296.92*Math.pow(pt_b,(-0.5583))",
        "pre-orf_no": "40285-05",
        "part_no": "40280-05",
        "200_b": "5.411*Math.log(pt_b)-14.577",
        "csscolor": "tip-brown",
        "cv_tip": "0.079",
        "141_s": "2.5744*Math.log(pt)-7.1423",
        "600_s": "100-296.92*Math.pow(pt,(-0.5583))",
        "r_min": "0.395",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "-107.8*Math.log(pt)+673.71",
        "vmd_b": "1234*Math.pow(pt_b,-0.2248)",
        "tip": "DR80-05",
        "Dv01_b": "-107.8*Math.log(pt_b)+673.71",
        "141_b": "2.5744*Math.log(pt_b)-7.1423",
        "200_s": "5.411*Math.log(pt)-14.577",
        "color": "Brown",
        "tip_rate": "0.5",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.707",
        "vmd_s": "1234*Math.pow(pt,-0.2248)",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "pre_orf": "R05",
    },
    {
        "classification": 0,
        "ang": "80",
        "600_b": "100-205.85*Math.pow(pt_b,(-0.4235))",
        "pre-orf_no": "40285-06",
        "part_no": "40280-06",
        "200_b": "5.7607*Math.log(pt_b)-15.893",
        "csscolor": "tip-grey",
        "cv_tip": "0.095",
        "141_s": "1.971*Math.log(pt)-5.2908",
        "600_s": "100-205.85*Math.pow(pt,(-0.4235))",
        "r_min": "0.474",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "416.25*Math.exp(-0.008*pt)",
        "vmd_b": "1161.2*Math.pow(pt_b,-0.1959)",
        "tip": "DR80-06",
        "Dv01_b": "416.25*Math.exp(-0.008*pt_b)",
        "141_b": "1.971*Math.log(pt_b)-5.2908",
        "200_s": "5.7607*Math.log(pt)-15.893",
        "color": "Grey",
        "tip_rate": "0.6",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.849",
        "vmd_s": "1161.2*Math.pow(pt,-0.1959)",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "R06",
    },
    {
        "classification": 1,
        "ang": "80",
        "600_b": "100-225.8*Math.pow(pt_b,(-0.4536))",
        "pre-orf_no": "40285-08",
        "part_no": "40280-08",
        "200_b": "6.1172*Math.log(pt_b)-15.897",
        "csscolor": "tip-white",
        "cv_tip": "0.126",
        "141_s": "3.0933*Math.log(pt)-7.477",
        "600_s": "100-225.8*Math.pow(pt,(-0.4536))",
        "r_min": "0.632",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "-80.56*Math.log(pt)+530.7",
        "vmd_b": "1222.7*Math.pow(pt_b,-0.2)",
        "tip": "DR80-08",
        "Dv01_b": "-80.56*Math.log(pt_b)+530.7",
        "141_b": "3.0933*Math.log(pt_b)-7.477",
        "200_s": "6.1172*Math.log(pt)-15.897",
        "color": "White",
        "tip_rate": "0.8",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "1.131",
        "vmd_s": "1222.7*Math.pow(pt,-0.2)",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "R08",
    },
    {
        "classification": 1,
        "ang": "80",
        "600_b": "100-164.7*Math.pow(pt_b,(-0.3646))",
        "pre-orf_no": "40285-10",
        "part_no": "40280-10",
        "200_b": "5.7744*Math.log(pt_b)-13.443",
        "csscolor": "tip-lt_blue",
        "cv_tip": "0.158",
        "141_s": "2.8702*Math.log(pt)-5.38595",
        "600_s": "100-164.7*Math.pow(pt,(-0.3646))",
        "r_min": "0.791",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "-74.22*Math.log(pt)+492.46",
        "vmd_b": "1083.2*Math.pow(pt_b,-0.1682)",
        "tip": "DR80-10",
        "Dv01_b": "-74.22*Math.log(pt_b)+492.46",
        "141_b": "2.8702*Math.log(pt_b)-5.38595",
        "200_s": "5.7744*Math.log(pt)-13.443",
        "color": "Lt Blue",
        "tip_rate": "1",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "1.414",
        "vmd_s": "1083.2*Math.pow(pt,-0.1682)",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "R010",
    },
    {
        "classification": 1,
        "ang": "80",
        "600_b": "100-141.9*Math.pow(pt_b,(-0.3062))",
        "pre-orf_no": "40285-125",
        "part_no": "40280-125",
        "200_b": "5.3588*Math.log(pt_b)-11.849",
        "csscolor": "tip-teal",
        "cv_tip": "0.198",
        "141_s": "2.5082*Math.log(pt)-4.5653",
        "600_s": "100-141.9*Math.pow(pt,(-0.3062))",
        "r_min": "0.988",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "-69.02*Math.log(pt)+474.08",
        "vmd_b": "1096*Math.pow(pt_b,-0.1655)",
        "tip": "DR80-125",
        "Dv01_b": "-69.02*Math.log(pt_b)+474.08",
        "141_b": "2.5082*Math.log(pt_b)-4.5653",
        "200_s": "5.3588*Math.log(pt)-11.849",
        "color": "Teal",
        "tip_rate": "1.25",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "1.768",
        "vmd_s": "1096*Math.pow(pt,-0.1655)",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "R12.5",
    },
    {
        "classification": 1,
        "ang": "80",
        "600_b": "100-173.83*Math.pow(pt_b,(-0.3551))",
        "pre-orf_no": "40285-15",
        "part_no": "40280-15",
        "200_b": "5.1061*Math.log(pt_b)-13.293",
        "csscolor": "tip-lt_green",
        "cv_tip": "0.237",
        "141_s": "2.0423*Math.log(pt)-4.2234",
        "600_s": "100-173.83*Math.pow(pt,(-0.3551))",
        "r_min": "1.186",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "-70.54*Math.log(pt)+508.31",
        "vmd_b": "1175.8*Math.pow(pt_b,-0.1801)",
        "tip": "DR80-15",
        "Dv01_b": "-70.54*Math.log(pt_b)+508.31",
        "141_b": "2.0423*Math.log(pt_b)-4.2234",
        "200_s": "5.1061*Math.log(pt)-13.293",
        "color": "Lt Green",
        "tip_rate": "1.5",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "2.121",
        "vmd_s": "1175.8*Math.pow(pt,-0.1801)",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "R15",
    },
    {
        "classification": 1,
        "ang": "80",
        "600_b": "100-230.43*Math.pow(pt_b,(-0.4511))",
        "pre-orf_no": "40285-20",
        "part_no": "40280-20",
        "200_b": "6.1613*Math.log(pt_b)-15.976",
        "csscolor": "tip-tan",
        "cv_tip": "0.316",
        "141_s": "2.6422*Math.log(pt)-6.0899",
        "600_s": "100-230.43*Math.pow(pt,(-0.4511))",
        "r_min": "1.581",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "-94.85*Math.log(pt)+587.79",
        "vmd_b": "1409.1*Math.pow(pt_b,-0.2375)",
        "tip": "DR80-20",
        "Dv01_b": "-94.85*Math.log(pt_b)+587.79",
        "141_b": "2.6422*Math.log(pt_b)-6.0899",
        "200_s": "6.1613*Math.log(pt)-15.976",
        "color": "Tan",
        "tip_rate": "2",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "2.828",
        "vmd_s": "1409.1*Math.pow(pt,-0.2375)",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "R20",
    },
    {
        "classification": 1,
        "ang": "80",
        "600_b": "100-227.7*Math.pow(pt_b,(-0.4232))",
        "pre-orf_no": "40285-25",
        "part_no": "40280-25",
        "200_b": "4.7972*Math.log(pt_b)-12.126",
        "csscolor": "tip-black",
        "cv_tip": "0.395",
        "141_s": "1.7473*Math.log(pt)-3.4415",
        "600_s": "100-227.7*Math.pow(pt,(-0.4232))",
        "r_min": "1.976",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "-83.25*Math.log(pt)+563.82",
        "vmd_b": "1405.6*Math.pow(pt_b,-0.2234)",
        "tip": "DR80-25",
        "Dv01_b": "-83.25*Math.log(pt_b)+563.82",
        "141_b": "1.7473*Math.log(pt_b)-3.4415",
        "200_s": "4.7972*Math.log(pt)-12.126",
        "color": "Black",
        "tip_rate": "2.5",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "3.536",
        "vmd_s": "1405.6*Math.pow(pt,-0.2234)",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "R25",
    },
    {
        "classification": 1,
        "ang": "80",
        "600_b": "100-326.69*Math.pow(pt_b,(-0.533))",
        "pre-orf_no": "40285-30",
        "part_no": "40280-30",
        "200_b": "5.501*Math.log(pt_b)-14.654",
        "csscolor": "tip-black",
        "cv_tip": "0.474",
        "141_s": "1.6681*Math.log(pt)-3.5507",
        "600_s": "100-326.69*Math.pow(pt,(-0.533))",
        "r_min": "2.372",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "-114.6*Math.log(pt)+687.01",
        "vmd_b": "1929.2*Math.pow(pt_b,-0.318)",
        "tip": "DR80-30",
        "Dv01_b": "-114.6*Math.log(pt_b)+687.01",
        "141_b": "1.6681*Math.log(pt_b)-3.5507",
        "200_s": "5.501*Math.log(pt)-14.654",
        "color": "Black",
        "tip_rate": "3",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "4.243",
        "vmd_s": "1929.2*Math.pow(pt,-0.318)",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "R30",
    },
    {
        "classification": 0,
        "ang": "110",
        "600_b": "100.0",
        "pre-orf_no": "N/A",
        "part_no": "40281-01",
        "200_b": "7.5739*Math.log(pt_b)+61.59",
        "csscolor": "tip-orange",
        "cv_tip": "0.016",
        "141_s": "15.984*Math.log(pt)-3.2784",
        "600_s": "100.0",
        "r_min": "0.071",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "210.71*Math.pow(pt,-0.258)",
        "vmd_b": "-22.058*Math.log(pt_b)+214.56",
        "tip": "ER110-01",
        "Dv01_b": "210.71*Math.pow(pt_b,-0.258)",
        "141_b": "15.984*Math.log(pt_b)-3.2784",
        "200_s": "7.5739*Math.log(pt)+61.59",
        "color": "Orange",
        "tip_rate": "0.1",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.141",
        "vmd_s": "-22.058*Math.log(pt)+214.56",
        "screen_no": "100 Mesh (#40251-00)",
        "screen": "100/Green",
        "pre_orf": "N/A",
    },
    {
        "classification": 0,
        "ang": "110",
        "600_b": "100.0",
        "pre-orf_no": "N/A",
        "part_no": "40281-015",
        "200_b": "9.5419*Math.log(pt_b)+48.306",
        "csscolor": "tip-green",
        "cv_tip": "0.024",
        "141_s": "16.246*Math.log(pt)-8.3676",
        "600_s": "100.0",
        "r_min": "0.106",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "-12.34*Math.log(pt)+126.02",
        "vmd_b": "-19.778*Math.log(pt_b)+211.87",
        "tip": "ER110-015",
        "Dv01_b": "-12.34*Math.log(pt_b)+126.02",
        "141_b": "16.246*Math.log(pt_b)-8.3676",
        "200_s": "9.5419*Math.log(pt)+48.306",
        "color": "Green",
        "tip_rate": "0.15",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.212",
        "vmd_s": "-19.778*Math.log(pt)+211.87",
        "screen_no": "100 Mesh (#40251-00)",
        "screen": "100/Green",
        "pre_orf": "N/A",
    },
    {
        "classification": 0,
        "ang": "110",
        "600_b": "100-10.304*Math.pow(pt_b,(-1.038))",
        "pre-orf_no": "N/A",
        "part_no": "40281-02",
        "200_b": "15.989*Math.log(pt_b)+14.598",
        "csscolor": "tip-yellow",
        "cv_tip": "0.032",
        "141_s": "18.75*Math.log(pt)-24.294",
        "600_s": "100-10.304*Math.pow(pt,(-1.038))",
        "r_min": "0.141",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "-19.77*Math.log(pt)+155.95",
        "vmd_b": "-32.021*Math.log(pt_b)+268.77",
        "tip": "ER110-02",
        "Dv01_b": "-19.77*Math.log(pt_b)+155.95",
        "141_b": "18.75*Math.log(pt_b)-24.294",
        "200_s": "15.989*Math.log(pt)+14.598",
        "color": "Yellow",
        "tip_rate": "0.2",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.283",
        "vmd_s": "-32.021*Math.log(pt)+268.77",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "pre_orf": "N/A",
    },
    {
        "classification": 0,
        "ang": "110",
        "600_b": "100-0.0026*pt_b+0.0839",
        "pre-orf_no": "N/A",
        "part_no": "40281-025",
        "200_b": "5.4173*Math.log(pt_b)+37.533",
        "csscolor": "tip-purple",
        "cv_tip": "0.040",
        "141_s": "2.122*Math.log(pt)+21.986",
        "600_s": "100-0.0026*pt+0.0839",
        "r_min": "0.177",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "204.26*Math.pow(pt,-0.219)",
        "vmd_b": "-19.01*Math.log(pt_b)+250.72",
        "tip": "ER110-025",
        "Dv01_b": "204.26*Math.pow(pt_b,-0.219)",
        "141_b": "2.122*Math.log(pt_b)+21.986",
        "200_s": "5.4173*Math.log(pt)+37.533",
        "color": "Purple",
        "tip_rate": "0.25",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.354",
        "vmd_s": "-19.01*Math.log(pt)+250.72",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "pre_orf": "N/A",
    },
    {
        "classification": 0,
        "ang": "110",
        "600_b": "100-0.0679*Math.pow(pt_b,(0.9049))",
        "pre-orf_no": "N/A",
        "part_no": "40281-03",
        "200_b": "12.864*Math.log(pt_b)+12.491",
        "csscolor": "tip-blue",
        "cv_tip": "0.047",
        "141_s": "11.719*Math.log(pt)-8.5399",
        "600_s": "100-0.0679*Math.pow(pt,(0.9049))",
        "r_min": "0.212",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "-17.43*Math.log(pt)+149.35",
        "vmd_b": "-35.567*Math.log(pt_b)+304.44",
        "tip": "ER110-03",
        "Dv01_b": "-17.43*Math.log(pt_b)+149.35",
        "141_b": "11.719*Math.log(pt_b)-8.5399",
        "200_s": "12.864*Math.log(pt)+12.491",
        "color": "Blue",
        "tip_rate": "0.3",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.424",
        "vmd_s": "-35.567*Math.log(pt)+304.44",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "pre_orf": "N/A",
    },
    {
        "classification": 0,
        "ang": "110",
        "600_b": "100-0.7668*Math.pow(pt_b,(0.4173))",
        "pre-orf_no": "N/A",
        "part_no": "40281-04",
        "200_b": "12.962*Math.log(pt_b)-2.5372",
        "csscolor": "tip-red",
        "cv_tip": "0.063",
        "141_s": "8.64*Math.log(pt)-7.5468",
        "600_s": "100-0.7668*Math.pow(pt,(0.4173))",
        "r_min": "0.283",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "189.33*Math.pow(pt,-0.174)",
        "vmd_b": "-37.35*Math.log(pt_b)+352.31",
        "tip": "ER110-04",
        "Dv01_b": "189.33*Math.pow(pt_b,-0.174)",
        "141_b": "8.64*Math.log(pt_b)-7.5468",
        "200_s": "12.962*Math.log(pt)-2.5372",
        "color": "Red",
        "tip_rate": "0.4",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.566",
        "vmd_s": "-37.35*Math.log(pt)+352.31",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "pre_orf": "N/A",
    },
    {
        "classification": 0,
        "ang": "110",
        "600_b": "100-5.1219*Math.pow(pt_b,(-0.0273))",
        "pre-orf_no": "N/A",
        "part_no": "40281-05",
        "200_b": "14.499*Math.log(pt_b)-7.8389",
        "csscolor": "tip-brown",
        "cv_tip": "0.079",
        "141_s": "11.275*Math.log(pt)-15.896",
        "600_s": "100-5.1219*Math.pow(pt,(-0.0273))",
        "r_min": "0.354",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "218.15*Math.pow(pt,-0.219)",
        "vmd_b": "482.05*Math.pow(pt_b,(-0.2223))",
        "tip": "ER110-05",
        "Dv01_b": "218.15*Math.pow(pt_b,-0.219)",
        "141_b": "11.275*Math.log(pt_b)-15.896",
        "200_s": "14.499*Math.log(pt)-7.8389",
        "color": "Brown",
        "tip_rate": "0.5",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.707",
        "vmd_s": "482.05*Math.pow(pt,(-0.2223))",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "pre_orf": "N/A",
    },
    {
        "classification": 0,
        "ang": "110",
        "600_b": "100-7.1048*Math.pow(pt_b,(-0.0683))",
        "pre-orf_no": "N/A",
        "part_no": "40281-06",
        "200_b": "13.632*Math.log(pt_b)-12.66",
        "csscolor": "tip-grey",
        "cv_tip": "0.095",
        "141_s": "9.1727*Math.log(pt)-13.564",
        "600_s": "100-7.1048*Math.pow(pt,(-0.0683))",
        "r_min": "0.424",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "-21.38*Math.log(pt)+187.26",
        "vmd_b": "-51.529*Math.log(pt_b)+436.31",
        "tip": "ER110-06",
        "Dv01_b": "-21.38*Math.log(pt_b)+187.26",
        "141_b": "9.1727*Math.log(pt_b)-13.564",
        "200_s": "13.632*Math.log(pt)-12.66",
        "color": "Grey",
        "tip_rate": "0.6",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.849",
        "vmd_s": "-51.529*Math.log(pt)+436.31",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "N/A",
    },
    {
        "classification": 1,
        "ang": "110",
        "600_b": "100-101.11*Math.pow(pt_b,(-0.7922))",
        "pre-orf_no": "N/A",
        "part_no": "40281-08",
        "200_b": "14.879*Math.log(pt_b)-19.045",
        "csscolor": "tip-white",
        "cv_tip": "0.126",
        "141_s": "8.7318*Math.log(pt)-12.356",
        "600_s": "100-101.11*Math.pow(pt,(-0.7922))",
        "r_min": "0.566",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "-30.13*Math.log(pt)+194",
        "vmd_b": "-90.342*Math.log(pt_b)+597.65",
        "tip": "ER110-08",
        "Dv01_b": "-30.13*Math.log(pt_b)+194",
        "141_b": "8.7318*Math.log(pt_b)-12.356",
        "200_s": "14.879*Math.log(pt)-19.045",
        "color": "White",
        "tip_rate": "0.8",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "1.131",
        "vmd_s": "-90.342*Math.log(pt)+597.65",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "N/A",
    },
    {
        "classification": 1,
        "ang": "110",
        "600_b": "100-64.95*Math.pow(pt_b,(-0.5631))",
        "pre-orf_no": "N/A",
        "part_no": "40281-10",
        "200_b": "12.443*Math.log(pt_b)-13.276",
        "csscolor": "tip-lt_blue",
        "cv_tip": "0.158",
        "141_s": "9.4459*Math.log(pt)-18.142",
        "600_s": "100-64.95*Math.pow(pt,(-0.5631))",
        "r_min": "0.707",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "-37.01*Math.log(pt)+231.45",
        "vmd_b": "-92.523*Math.log(pt_b)+639.32",
        "tip": "ER110-10",
        "Dv01_b": "-37.01*Math.log(pt_b)+231.45",
        "141_b": "9.4459*Math.log(pt_b)-18.142",
        "200_s": "12.443*Math.log(pt)-13.276",
        "color": "Lt Blue",
        "tip_rate": "1",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "1.414",
        "vmd_s": "-92.523*Math.log(pt)+639.32",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "N/A",
    },
    {
        "classification": 1,
        "ang": "110",
        "600_b": "100-198.6*Math.pow(pt_b,(-0.6268))",
        "pre-orf_no": "N/A",
        "part_no": "40281-125",
        "200_b": "4.7088*Math.log(pt_b)+2.2079",
        "csscolor": "tip-teal",
        "cv_tip": "0.198",
        "141_s": "3.9753*Math.log(pt)-3.279",
        "600_s": "100-198.6*Math.pow(pt,(-0.6268))",
        "r_min": "0.884",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "242.89*Math.pow(pt,-0.205)",
        "vmd_b": "-92.412*Math.log(pt_b)+697.78",
        "tip": "ER110-125",
        "Dv01_b": "242.89*Math.pow(pt_b,-0.205)",
        "141_b": "3.9753*Math.log(pt_b)-3.279",
        "200_s": "4.7088*Math.log(pt)+2.2079",
        "color": "Teal",
        "tip_rate": "1.25",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "1.768",
        "vmd_s": "-92.412*Math.log(pt)+697.78",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "N/A",
    },
    {
        "classification": 1,
        "ang": "110",
        "600_b": "100-197.64*Math.pow(pt_b,(-0.5694))",
        "pre-orf_no": "N/A",
        "part_no": "40281-15",
        "200_b": "5.906*Math.log(pt_b)-2.3276",
        "csscolor": "tip-lt_green",
        "cv_tip": "0.237",
        "141_s": "4.8929*Math.log(pt)-6.1773",
        "600_s": "100-197.64*Math.pow(pt,(-0.5694))",
        "r_min": "1.061",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "-26.6*Math.log(pt)+210.88",
        "vmd_b": "-97.899*Math.log(pt_b)+730.78",
        "tip": "ER110-15",
        "Dv01_b": "-26.6*Math.log(pt_b)+210.88",
        "141_b": "4.8929*Math.log(pt_b)-6.1773",
        "200_s": "5.906*Math.log(pt)-2.3276",
        "color": "Lt Green",
        "tip_rate": "1.5",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "2.121",
        "vmd_s": "-97.899*Math.log(pt)+730.78",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "N/A",
    },
    {
        "classification": 1,
        "ang": "110",
        "600_b": "100-193.73*Math.pow(pt_b,(-0.4923))",
        "pre-orf_no": "N/A",
        "part_no": "40281-20",
        "200_b": "5.6703*Math.log(pt_b)-6.1382",
        "csscolor": "tip-tan",
        "cv_tip": "0.316",
        "141_s": "3.0239*Math.log(pt)-2.4897",
        "600_s": "100-193.73*Math.pow(pt,(-0.4923))",
        "r_min": "1.414",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "-27.81*Math.log(pt)+236.76",
        "vmd_b": "-107.26*Math.log(pt_b)+818.14",
        "tip": "ER110-20",
        "Dv01_b": "-27.81*Math.log(pt_b)+236.76",
        "141_b": "3.0239*Math.log(pt_b)-2.4897",
        "200_s": "5.6703*Math.log(pt)-6.1382",
        "color": "Tan",
        "tip_rate": "2",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "2.828",
        "vmd_s": "-107.26*Math.log(pt)+818.14",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "N/A",
    },
    {
        "classification": 1,
        "ang": "110",
        "600_b": "100-311.16*Math.pow(pt_b,(-0.6388))",
        "pre-orf_no": "N/A",
        "part_no": "40281-25",
        "200_b": "3.8459*Math.log(pt_b)-1.1911",
        "csscolor": "tip-black",
        "cv_tip": "0.395",
        "141_s": "1.5863*Math.log(pt)+1.5158",
        "600_s": "100-311.16*Math.pow(pt,(-0.6388))",
        "r_min": "1.768",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "-21.16*Math.log(pt)+223.86",
        "vmd_b": "-105.24*Math.log(pt_b)+810.69",
        "tip": "ER110-25",
        "Dv01_b": "-21.16*Math.log(pt_b)+223.86",
        "141_b": "1.5863*Math.log(pt_b)+1.5158",
        "200_s": "3.8459*Math.log(pt)-1.1911",
        "color": "Black",
        "tip_rate": "2.5",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "3.536",
        "vmd_s": "-105.24*Math.log(pt)+810.69",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "N/A",
    },
    {
        "classification": 1,
        "ang": "110",
        "600_b": "100-139.27*Math.pow(pt_b,(-0.3753))",
        "pre-orf_no": "N/A",
        "part_no": "40281-30",
        "200_b": "5.4969*Math.log(pt_b)-7.6025",
        "csscolor": "tip-black",
        "cv_tip": "0.474",
        "141_s": "3.2967*Math.log(pt)-4.9903",
        "600_s": "100-139.27*Math.pow(pt,(-0.3753))",
        "r_min": "2.121",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "-36.44*Math.log(pt)+283.013",
        "vmd_b": "-100.71*Math.log(pt_b)+808.61",
        "tip": "ER110-30",
        "Dv01_b": "-36.44*Math.log(pt_b)+283.013",
        "141_b": "3.2967*Math.log(pt_b)-4.9903",
        "200_s": "5.4969*Math.log(pt)-7.6025",
        "color": "Black",
        "tip_rate": "3",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "4.243",
        "vmd_s": "-100.71*Math.log(pt)+808.61",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "N/A",
    },
    {
        "classification": 0,
        "ang": "110",
        "600_b": "100-3.2595*Math.pow(pt_b,(-0.0958))",
        "pre-orf_no": "40285-02",
        "part_no": "40287-015",
        "200_b": "20.542*Math.log(pt_b)-25.167",
        "csscolor": "tip-green",
        "cv_tip": "0.024",
        "141_s": "15.162*Math.log(pt)-27.585",
        "600_s": "100-3.2595*Math.pow(pt,(-0.0958))",
        "r_min": "0.119",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "-26.48*Math.log(pt)+192.98",
        "vmd_b": "-54.823*Math.log(pt_b)+401.72",
        "tip": "SR110-015",
        "Dv01_b": "-26.48*Math.log(pt_b)+192.98",
        "141_b": "15.162*Math.log(pt_b)-27.585",
        "200_s": "20.542*Math.log(pt)-25.167",
        "color": "Green",
        "tip_rate": "0.15",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.212",
        "vmd_s": "-54.823*Math.log(pt)+401.72",
        "screen_no": "100 Mesh (#40251-00)",
        "screen": "100/Green",
        "pre_orf": "R02",
    },
    {
        "classification": 0,
        "ang": "110",
        "600_b": "100-1.1366*Math.pow(pt_b,(-0.0909))",
        "pre-orf_no": "40285-02",
        "part_no": "40287-02",
        "200_b": "16.71*Math.log(pt_b)-13.315",
        "csscolor": "tip-yellow",
        "cv_tip": "0.032",
        "141_s": "11.698*Math.log(pt)-17.099",
        "600_s": "100-1.1366*Math.pow(pt,(-0.0909))",
        "r_min": "0.158",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "-22.24*Math.log(pt)+180.19",
        "vmd_b": "-44.861*Math.log(pt_b)+371.52",
        "tip": "SR110-02",
        "Dv01_b": "-22.24*Math.log(pt_b)+180.19",
        "141_b": "11.698*Math.log(pt_b)-17.099",
        "200_s": "16.71*Math.log(pt)-13.315",
        "color": "Yellow",
        "tip_rate": "0.2",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.283",
        "vmd_s": "-44.861*Math.log(pt)+371.52",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "pre_orf": "R02",
    },
    {
        "classification": 0,
        "ang": "110",
        "600_b": "100-2.9027*Math.pow(pt_b,(-0.1444))",
        "pre-orf_no": "40285-025",
        "part_no": "40287-025",
        "200_b": "15.982*Math.log(pt_b)-16.044",
        "csscolor": "tip-purple",
        "cv_tip": "0.040",
        "141_s": "10.531*Math.log(pt)-16.166",
        "600_s": "100-2.9027*Math.pow(pt,(-0.1444))",
        "r_min": "0.198",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "-24.09*Math.log(pt)+192.61",
        "vmd_b": "-47.7371*Math.log(pt_b)+398.07",
        "tip": "SR110-025",
        "Dv01_b": "-24.09*Math.log(pt_b)+192.61",
        "141_b": "10.531*Math.log(pt_b)-16.166",
        "200_s": "15.982*Math.log(pt)-16.044",
        "color": "Purple",
        "tip_rate": "0.25",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.354",
        "vmd_s": "-47.7371*Math.log(pt)+398.07",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "pre_orf": "R025",
    },
    {
        "classification": 0,
        "ang": "110",
        "600_b": "100-123.39*Math.pow(pt_b,(-0.9246))",
        "pre-orf_no": "40285-03",
        "part_no": "40287-03",
        "200_b": "18.728*Math.log(pt_b)-40.05",
        "csscolor": "tip-blue",
        "cv_tip": "0.047",
        "141_s": "11.132*Math.log(pt)-26.392",
        "600_s": "100-123.39*Math.pow(pt,(-0.9246))",
        "r_min": "0.237",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "-44.32*Math.log(pt)+291.04",
        "vmd_b": "-85.56*Math.log(pt_b)+594.45",
        "tip": "SR110-03",
        "Dv01_b": "-44.32*Math.log(pt_b)+291.04",
        "141_b": "11.132*Math.log(pt_b)-26.392",
        "200_s": "18.728*Math.log(pt)-40.05",
        "color": "Blue",
        "tip_rate": "0.3",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.424",
        "vmd_s": "-85.56*Math.log(pt)+594.45",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "pre_orf": "R03",
    },
    {
        "classification": 0,
        "ang": "110",
        "600_b": "100-103.18*Math.pow(pt_b,(-0.8256))",
        "pre-orf_no": "40285-04",
        "part_no": "40287-04",
        "200_b": "16.644*Math.log(pt_b)-34.14",
        "csscolor": "tip-red",
        "cv_tip": "0.063",
        "141_s": "9.2354*Math.log(pt)-20.374",
        "600_s": "100-103.18*Math.pow(pt,(-0.8256))",
        "r_min": "0.316",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "-37.88*Math.log(pt)+269.23",
        "vmd_b": "-87.668*Math.log(pt_b)+611.84",
        "tip": "SR110-04",
        "Dv01_b": "-37.88*Math.log(pt_b)+269.23",
        "141_b": "9.2354*Math.log(pt_b)-20.374",
        "200_s": "16.644*Math.log(pt)-34.14",
        "color": "Red",
        "tip_rate": "0.4",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.566",
        "vmd_s": "-87.668*Math.log(pt)+611.84",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "pre_orf": "R04",
    },
    {
        "classification": 0,
        "ang": "110",
        "600_b": "100-332.29*Math.pow(pt_b,(-1.0665))",
        "pre-orf_no": "40285-05",
        "part_no": "40287-05",
        "200_b": "17.1*Math.log(pt_b)-40.879",
        "csscolor": "tip-brown",
        "cv_tip": "0.079",
        "141_s": "9.2994*Math.log(pt)-23.297",
        "600_s": "100-332.29*Math.pow(pt,(-1.0665))",
        "r_min": "0.395",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "612.64*Math.pow(pt,-0.395)",
        "vmd_b": "-115.8*Math.log(pt_b)+749.34",
        "tip": "SR110-05",
        "Dv01_b": "612.64*Math.pow(pt_b,-0.395)",
        "141_b": "9.2994*Math.log(pt_b)-23.297",
        "200_s": "17.1*Math.log(pt)-40.879",
        "color": "Brown",
        "tip_rate": "0.5",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.707",
        "vmd_s": "-115.8*Math.log(pt)+749.34",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "pre_orf": "R05",
    },
    {
        "classification": 0,
        "ang": "110",
        "600_b": "100-1228.9*Math.pow(pt_b,(-1.2723))",
        "pre-orf_no": "40285-06",
        "part_no": "40287-06",
        "200_b": "16.116*Math.log(pt_b)-42.137",
        "csscolor": "tip-grey",
        "cv_tip": "0.095",
        "141_s": "8.5565*Math.log(pt)-23.15",
        "600_s": "100-1228.9*Math.pow(pt,(-1.2723))",
        "r_min": "0.474",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "1018.5*Math.pow(pt,-0.494)",
        "vmd_b": "-155.26*Math.log(pt_b)+944.05",
        "tip": "SR110-06",
        "Dv01_b": "1018.5*Math.pow(pt_b,-0.494)",
        "141_b": "8.5565*Math.log(pt_b)-23.15",
        "200_s": "16.116*Math.log(pt)-42.137",
        "color": "Grey",
        "tip_rate": "0.6",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.849",
        "vmd_s": "-155.26*Math.log(pt)+944.05",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "R06",
    },
    {
        "classification": 1,
        "ang": "110",
        "600_b": "100-652.29*Math.pow(pt_b,(-0.8742))",
        "pre-orf_no": "40285-08",
        "part_no": "40287-08",
        "200_b": "8.1024*Math.log(pt_b)-15.081",
        "csscolor": "tip-white",
        "cv_tip": "0.126",
        "141_s": "5.738*Math.log(pt)-13.743",
        "600_s": "100-652.29*Math.pow(pt,(-0.8742))",
        "r_min": "0.632",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "399.43*Math.pow(pt,-0.282)",
        "vmd_b": "-153.89*Math.log(pt_b)+976.15",
        "tip": "SR110-08",
        "Dv01_b": "399.43*Math.pow(pt_b,-0.282)",
        "141_b": "5.738*Math.log(pt_b)-13.743",
        "200_s": "8.1024*Math.log(pt)-15.081",
        "color": "White",
        "tip_rate": "0.8",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "1.131",
        "vmd_s": "-153.89*Math.log(pt)+976.15",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "R08",
    },
    {
        "classification": 1,
        "ang": "110",
        "600_b": "100-615.32*Math.pow(pt_b,(-0.8211))",
        "pre-orf_no": "40285-10",
        "part_no": "40287-10",
        "200_b": "7.9985*Math.log(pt_b)-15.733",
        "csscolor": "tip-lt_blue",
        "cv_tip": "0.158",
        "141_s": "4.6649*Math.log(pt)-9.8077",
        "600_s": "100-615.32*Math.pow(pt,(-0.8211))",
        "r_min": "0.791",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "448.8*Math.pow(pt,-0.306)",
        "vmd_b": "-162.26*Math.log(pt_b)+1022.3",
        "tip": "SR110-10",
        "Dv01_b": "448.8*Math.pow(pt_b,-0.306)",
        "141_b": "4.6649*Math.log(pt_b)-9.8077",
        "200_s": "7.9985*Math.log(pt)-15.733",
        "color": "Lt Blue",
        "tip_rate": "1",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "1.414",
        "vmd_s": "-162.26*Math.log(pt)+1022.3",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "R010",
    },
    {
        "classification": 1,
        "ang": "110",
        "600_b": "100-520.02*Math.pow(pt_b,(-0.7691))",
        "pre-orf_no": "40285-125",
        "part_no": "40287-125",
        "200_b": "8.9653*Math.log(pt_b)-20.546",
        "csscolor": "tip-teal",
        "cv_tip": "0.198",
        "141_s": "3.3982*Math.log(pt)-6.6623",
        "600_s": "100-520.02*Math.pow(pt,(-0.7691))",
        "r_min": "0.988",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "595.62*Math.pow(pt,-0.365)",
        "vmd_b": "-166.94*Math.log(pt_b)+1038.6",
        "tip": "SR110-125",
        "Dv01_b": "595.62*Math.pow(pt_b,-0.365)",
        "141_b": "3.3982*Math.log(pt_b)-6.6623",
        "200_s": "8.9653*Math.log(pt)-20.546",
        "color": "Teal",
        "tip_rate": "1.25",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "1.768",
        "vmd_s": "-166.94*Math.log(pt)+1038.6",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "R12.5",
    },
    {
        "classification": 1,
        "ang": "110",
        "600_b": "100-375.19*Math.pow(pt_b,(-0.5963))",
        "pre-orf_no": "40285-15",
        "part_no": "40287-15",
        "200_b": "6.1866*Math.log(pt_b)-13.055",
        "csscolor": "tip-lt_green",
        "cv_tip": "0.237",
        "141_s": "2.9323*Math.log(pt)-5.2204",
        "600_s": "100-375.19*Math.pow(pt,(-0.5963))",
        "r_min": "1.186",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "746.47*Math.pow(pt,-0.394)",
        "vmd_b": "-148.22*Math.log(pt_b)+1042.4",
        "tip": "SR110-15",
        "Dv01_b": "746.47*Math.pow(pt_b,-0.394)",
        "141_b": "2.9323*Math.log(pt_b)-5.2204",
        "200_s": "6.1866*Math.log(pt)-13.055",
        "color": "Lt Green",
        "tip_rate": "1.5",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "2.121",
        "vmd_s": "-148.22*Math.log(pt)+1042.4",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "R15",
    },
    {
        "classification": 1,
        "ang": "110",
        "600_b": "100-376.75*Math.pow(pt_b,(-0.6217))",
        "pre-orf_no": "40285-25",
        "part_no": "40287-20",
        "200_b": "6.33848*Math.log(pt_b)-11.845",
        "csscolor": "tip-tan",
        "cv_tip": "0.316",
        "141_s": "2.8751*Math.log(pt)-4.1109",
        "600_s": "100-376.75*Math.pow(pt,(-0.6217))",
        "r_min": "1.581",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "618.76*Math.pow(pt,-0.365)",
        "vmd_b": "-166.94*Math.log(pt_b)+1038.6",
        "tip": "SR110-20",
        "Dv01_b": "618.76*Math.pow(pt_b,-0.365)",
        "141_b": "2.8751*Math.log(pt_b)-4.1109",
        "200_s": "6.33848*Math.log(pt)-11.845",
        "color": "Tan",
        "tip_rate": "2",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "2.828",
        "vmd_s": "-166.94*Math.log(pt)+1038.6",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "R25",
    },
    {
        "classification": 1,
        "ang": "110",
        "600_b": "100-243.64*Math.pow(pt_b,-0.5033)",
        "pre-orf_no": "40285-40",
        "part_no": "40287-25",
        "200_b": "5.4924*Math.log(pt_b)-8.9327",
        "csscolor": "tip-black",
        "cv_tip": "0.395",
        "141_s": "2.818*Math.log(pt)-3.9013",
        "600_s": "100-243.64*Math.pow(pt,-0.5033)",
        "r_min": "1.976",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "486.26*Math.pow(pt,-0.304)",
        "vmd_b": "-148.22*Math.log(pt_b)+1042.4",
        "tip": "SR110-25",
        "Dv01_b": "486.26*Math.pow(pt_b,-0.304)",
        "141_b": "2.818*Math.log(pt_b)-3.9013",
        "200_s": "5.4924*Math.log(pt)-8.9327",
        "color": "Black",
        "tip_rate": "2.5",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "3.536",
        "vmd_s": "-148.22*Math.log(pt)+1042.4",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "R40",
    },
    {
        "classification": 0,
        "ang": "110",
        "600_b": "100-35307*Math.pow(pt_b,(-2.5749))",
        "pre-orf_no": "40285-015",
        "part_no": "40291-015",
        "200_b": "28.01*Math.log(pt_b)-73.222",
        "csscolor": "tip-green",
        "cv_tip": "0.024",
        "141_s": "16.71*Math.log(pt)-45.577",
        "600_s": "100-35307*Math.pow(pt,(-2.5749))",
        "r_min": "0.119",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "1126.5*Math.pow(pt,-0.588)",
        "vmd_b": "1852.7*Math.pow(pt_b,(-0.5149))",
        "tip": "MR110-015",
        "Dv01_b": "1126.5*Math.pow(pt_b,-0.588)",
        "141_b": "16.71*Math.log(pt_b)-45.577",
        "200_s": "28.01*Math.log(pt)-73.222",
        "color": "Green",
        "tip_rate": "0.15",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.212",
        "vmd_s": "1852.7*Math.pow(pt,(-0.5149))",
        "screen_no": "100 Mesh (#40251-00)",
        "screen": "100/Green",
        "pre_orf": "R015",
    },
    {
        "classification": 0,
        "ang": "110",
        "600_b": "100-281.54*Math.pow(pt_b,(-1.2053))",
        "pre-orf_no": "40285-02",
        "part_no": "40291-02",
        "200_b": "22.555*Math.log(pt_b)-53.551",
        "csscolor": "tip-yellow",
        "cv_tip": "0.032",
        "141_s": "13.714*Math.log(pt)-35.104",
        "600_s": "100-281.54*Math.pow(pt,(-1.2053))",
        "r_min": "0.158",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "627.62*Math.pow(pt,-0.436)",
        "vmd_b": "1332.4*Math.pow(pt_b,(-0.4238))",
        "tip": "MR110-02",
        "Dv01_b": "627.62*Math.pow(pt_b,-0.436)",
        "141_b": "13.714*Math.log(pt_b)-35.104",
        "200_s": "22.555*Math.log(pt)-53.551",
        "color": "Yellow",
        "tip_rate": "0.2",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.283",
        "vmd_s": "1332.4*Math.pow(pt,(-0.4238))",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "pre_orf": "R02",
    },
    {
        "classification": 0,
        "ang": "110",
        "600_b": "100-475.87*Math.pow(pt_b,(-1.1541))",
        "pre-orf_no": "40285-025",
        "part_no": "40291-025",
        "200_b": "16.094*Math.log(pt_b)-37.187",
        "csscolor": "tip-purple",
        "cv_tip": "0.040",
        "141_s": "9.383*Math.log(pt)-23.244",
        "600_s": "100-475.87*Math.pow(pt,(-1.1541))",
        "r_min": "0.198",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "618.51*Math.pow(pt,-0.401)",
        "vmd_b": "-105.56*Math.log(pt_b)+709.13",
        "tip": "MR110-025",
        "Dv01_b": "618.51*Math.pow(pt_b,-0.401)",
        "141_b": "9.383*Math.log(pt_b)-23.244",
        "200_s": "16.094*Math.log(pt)-37.187",
        "color": "Purple",
        "tip_rate": "0.25",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.354",
        "vmd_s": "-105.56*Math.log(pt)+709.13",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "pre_orf": "R025",
    },
    {
        "classification": 0,
        "ang": "110",
        "600_b": "100-1014.4*Math.pow(pt_b,(-1.2675))",
        "pre-orf_no": "40285-03",
        "part_no": "40291-03",
        "200_b": "13.982*Math.log(pt_b)-34.376",
        "csscolor": "tip-blue",
        "cv_tip": "0.047",
        "141_s": "7.6662*Math.log(pt)-19.748",
        "600_s": "100-1014.4*Math.pow(pt,(-1.2675))",
        "r_min": "0.237",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "826.09*Math.pow(pt,-0.443)",
        "vmd_b": "-120.65*Math.log(pt_b)+804.82",
        "tip": "MR110-03",
        "Dv01_b": "826.09*Math.pow(pt_b,-0.443)",
        "141_b": "7.6662*Math.log(pt_b)-19.748",
        "200_s": "13.982*Math.log(pt)-34.376",
        "color": "Blue",
        "tip_rate": "0.3",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.424",
        "vmd_s": "-120.65*Math.log(pt)+804.82",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "pre_orf": "R03",
    },
    {
        "classification": 0,
        "ang": "110",
        "600_b": "100-1519.7*Math.pow(pt_b,(-1.345))",
        "pre-orf_no": "40285-04",
        "part_no": "40291-04",
        "200_b": "13.293*Math.log(pt_b)-34.116",
        "csscolor": "tip-red",
        "cv_tip": "0.063",
        "141_s": "6.4957*Math.log(pt)-17.209",
        "600_s": "100-1519.7*Math.pow(pt,(-1.345))",
        "r_min": "0.316",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "901.22*Math.pow(pt,-0.443)",
        "vmd_b": "-136.47*Math.log(pt_b)+880.15",
        "tip": "MR110-04",
        "Dv01_b": "901.22*Math.pow(pt_b,-0.443)",
        "141_b": "6.4957*Math.log(pt_b)-17.209",
        "200_s": "13.293*Math.log(pt)-34.116",
        "color": "Red",
        "tip_rate": "0.4",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.566",
        "vmd_s": "-136.47*Math.log(pt)+880.15",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "pre_orf": "R04",
    },
    {
        "classification": 0,
        "ang": "110",
        "600_b": "100-553.84*Math.pow(pt_b,(-0.8757))",
        "pre-orf_no": "40285-05",
        "part_no": "40291-05",
        "200_b": "9.4188*Math.log(pt_b)-24.409",
        "csscolor": "tip-brown",
        "cv_tip": "0.079",
        "141_s": "4.705*Math.log(pt)-12.677",
        "600_s": "100-553.84*Math.pow(pt,(-0.8757))",
        "r_min": "0.395",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "1049.5*Math.pow(pt,-0.441)",
        "vmd_b": "-144.67*Math.log(pt_b)+978.24",
        "tip": "MR110-05",
        "Dv01_b": "1049.5*Math.pow(pt_b,-0.441)",
        "141_b": "4.705*Math.log(pt_b)-12.677",
        "200_s": "9.4188*Math.log(pt)-24.409",
        "color": "Brown",
        "tip_rate": "0.5",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.707",
        "vmd_s": "-144.67*Math.log(pt)+978.24",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "pre_orf": "R05",
    },
    {
        "classification": 0,
        "ang": "110",
        "600_b": "100-449.96*Math.pow(pt_b,(-0.7727))",
        "pre-orf_no": "40285-06",
        "part_no": "40291-06",
        "200_b": "5.5671*Math.log(pt_b)-11.983",
        "csscolor": "tip-grey",
        "cv_tip": "0.095",
        "141_s": "2.5469*Math.log(pt)-5.5518",
        "600_s": "100-449.96*Math.pow(pt,(-0.7727))",
        "r_min": "0.474",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "-69.72*Math.log(pt)+481.91",
        "vmd_b": "-115.58*Math.log(pt_b)+900.53",
        "tip": "MR110-06",
        "Dv01_b": "-69.72*Math.log(pt_b)+481.91",
        "141_b": "2.5469*Math.log(pt_b)-5.5518",
        "200_s": "5.5671*Math.log(pt)-11.983",
        "color": "Grey",
        "tip_rate": "0.6",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.849",
        "vmd_s": "-115.58*Math.log(pt)+900.53",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "R06",
    },
    {
        "classification": 1,
        "ang": "110",
        "600_b": "100-468.08*Math.pow(pt_b,(-0.6744))",
        "pre-orf_no": "40285-08",
        "part_no": "40291-08",
        "200_b": "6.4122*Math.log(pt_b)-13.549",
        "csscolor": "tip-white",
        "cv_tip": "0.126",
        "141_s": "3.4006*Math.log(pt)-7.338",
        "600_s": "100-468.08*Math.pow(pt,(-0.6744))",
        "r_min": "0.632",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "665.86*Math.pow(pt,-0.364)",
        "vmd_b": "-165.74*Math.log(pt_b)+1094.8",
        "tip": "MR110-08",
        "Dv01_b": "665.86*Math.pow(pt_b,-0.364)",
        "141_b": "3.4006*Math.log(pt_b)-7.338",
        "200_s": "6.4122*Math.log(pt)-13.549",
        "color": "White",
        "tip_rate": "0.8",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "1.131",
        "vmd_s": "-165.74*Math.log(pt)+1094.8",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "R08",
    },
    {
        "classification": 1,
        "ang": "110",
        "600_b": "100-291.88*Math.pow(pt_b,(-0.5354))",
        "pre-orf_no": "40285-10",
        "part_no": "40291-10",
        "200_b": "5.7355*Math.log(pt_b)-11.968",
        "csscolor": "tip-lt_blue",
        "cv_tip": "0.158",
        "141_s": "2.9421*Math.log(pt)-5.9232",
        "600_s": "100-291.88*Math.pow(pt,(-0.5354))",
        "r_min": "0.791",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "679*Math.pow(pt,-0.362)",
        "vmd_b": "-159.2*Math.log(pt_b)+1064.8",
        "tip": "MR110-10",
        "Dv01_b": "679*Math.pow(pt_b,-0.362)",
        "141_b": "2.9421*Math.log(pt_b)-5.9232",
        "200_s": "5.7355*Math.log(pt)-11.968",
        "color": "Lt Blue",
        "tip_rate": "1",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "1.414",
        "vmd_s": "-159.2*Math.log(pt)+1064.8",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "R010",
    },
    {
        "classification": 1,
        "ang": "110",
        "600_b": "100-272.17*Math.pow(pt_b,(-0.4417))",
        "pre-orf_no": "40285-125",
        "part_no": "40291-125",
        "200_b": "5.2696*Math.log(pt_b)-12.326",
        "csscolor": "tip-teal",
        "cv_tip": "0.198",
        "141_s": "2.0325*Math.log(pt)-3.0206",
        "600_s": "100-272.17*Math.pow(pt,(-0.4417))",
        "r_min": "0.988",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "-75.06*Math.log(pt)+490.91",
        "vmd_b": "-161.51*Math.log(pt_b)+1167",
        "tip": "MR110-125",
        "Dv01_b": "-75.06*Math.log(pt_b)+490.91",
        "141_b": "2.0325*Math.log(pt_b)-3.0206",
        "200_s": "5.2696*Math.log(pt)-12.326",
        "color": "Teal",
        "tip_rate": "1.25",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "1.768",
        "vmd_s": "-161.51*Math.log(pt)+1167",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "R12.5",
    },
    {
        "classification": 1,
        "ang": "110",
        "600_b": "100-168.51*Math.pow(pt_b,(-0.3055))",
        "pre-orf_no": "40285-15",
        "part_no": "40291-15",
        "200_b": "3.0124*Math.log(pt_b)-3.3809",
        "csscolor": "tip-lt_green",
        "cv_tip": "0.237",
        "141_s": "0.6964*Math.log(pt)+1.9128",
        "600_s": "100-168.51*Math.pow(pt,(-0.3055))",
        "r_min": "1.186",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "-55.7*Math.log(pt)+404.52",
        "vmd_b": "-117.43*Math.log(pt_b)+1007.3",
        "tip": "MR110-15",
        "Dv01_b": "-55.7*Math.log(pt_b)+404.52",
        "141_b": "0.6964*Math.log(pt_b)+1.9128",
        "200_s": "3.0124*Math.log(pt)-3.3809",
        "color": "Lt Green",
        "tip_rate": "1.5",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "2.121",
        "vmd_s": "-117.43*Math.log(pt)+1007.3",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "R15",
    },
    {
        "classification": 1,
        "ang": "110",
        "600_b": "100-186.13*Math.pow(pt_b,(-0.3442))",
        "pre-orf_no": "40285-20",
        "part_no": "40291-20",
        "200_b": "4.4531*Math.log(pt_b)-8.1077",
        "csscolor": "tip-tan",
        "cv_tip": "0.316",
        "141_s": "2.1886*Math.log(pt)-3.0265",
        "600_s": "100-186.13*Math.pow(pt,(-0.3442))",
        "r_min": "1.581",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "-68.96*Math.log(pt)+447.32",
        "vmd_b": "-125.46*Math.log(pt_b)+1020",
        "tip": "MR110-20",
        "Dv01_b": "-68.96*Math.log(pt_b)+447.32",
        "141_b": "2.1886*Math.log(pt_b)-3.0265",
        "200_s": "4.4531*Math.log(pt)-8.1077",
        "color": "Tan",
        "tip_rate": "2",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "2.828",
        "vmd_s": "-125.46*Math.log(pt)+1020",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "R20",
    },
    {
        "classification": 0,
        "ang": "110",
        "600_b": "100-303.51*Math.pow(pt_b,(-1.0582))",
        "pre-orf_no": "40285-015",
        "part_no": "40286-015",
        "200_b": "17.93*Math.log(pt_b)-45.923",
        "csscolor": "tip-green",
        "cv_tip": "0.024",
        "141_s": "9.8853*Math.log(pt)-26.663",
        "600_s": "100-303.51*Math.pow(pt,(-1.0582))",
        "r_min": "0.119",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "934.55*Math.pow(pt,-0.49)",
        "vmd_b": "1351.7*Math.pow(pt_b,-(0.3839))",
        "tip": "DR110-015",
        "Dv01_b": "934.55*Math.pow(pt_b,-0.49)",
        "141_b": "9.8853*Math.log(pt_b)-26.663",
        "200_s": "17.93*Math.log(pt)-45.923",
        "color": "Green",
        "tip_rate": "0.15",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.212",
        "vmd_s": "1351.7*Math.pow(pt,-(0.3839))",
        "screen_no": "100 Mesh (#40251-00)",
        "screen": "100/Green",
        "pre_orf": "R015",
    },
    {
        "classification": 0,
        "ang": "110",
        "600_b": "100-630.75*Math.pow(pt_b,(-1.0527))",
        "pre-orf_no": "40285-02",
        "part_no": "40286-02",
        "200_b": "12.626*Math.log(pt_b)-32.937",
        "csscolor": "tip-yellow",
        "cv_tip": "0.032",
        "141_s": "6.5086*Math.log(pt)-17.49",
        "600_s": "100-630.75*Math.pow(pt,(-1.0527))",
        "r_min": "0.158",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "1108.3*Math.pow(pt,-0.49)",
        "vmd_b": "-136.62*Math.log(pt_b)+895.69",
        "tip": "DR110-02",
        "Dv01_b": "1108.3*Math.pow(pt_b,-0.49)",
        "141_b": "6.5086*Math.log(pt_b)-17.49",
        "200_s": "12.626*Math.log(pt)-32.937",
        "color": "Yellow",
        "tip_rate": "0.2",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.283",
        "vmd_s": "-136.62*Math.log(pt)+895.69",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "pre_orf": "R02",
    },
    {
        "classification": 0,
        "ang": "110",
        "600_b": "100-1395.2*Math.pow(pt_b,(-1.248))",
        "pre-orf_no": "40285-025",
        "part_no": "40286-025",
        "200_b": "11.308*Math.log(pt_b)-28.202",
        "csscolor": "tip-purple",
        "cv_tip": "0.040",
        "141_s": "5.8237*Math.log(pt)-14.979",
        "600_s": "100-1395.2*Math.pow(pt,(-1.248))",
        "r_min": "0.198",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "-81.26*Math.log(pt)+486.09",
        "vmd_b": "-124.75*Math.log(pt_b)+857.83",
        "tip": "DR110-025",
        "Dv01_b": "-81.26*Math.log(pt_b)+486.09",
        "141_b": "5.8237*Math.log(pt_b)-14.979",
        "200_s": "11.308*Math.log(pt)-28.202",
        "color": "Purple",
        "tip_rate": "0.25",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.354",
        "vmd_s": "-124.75*Math.log(pt)+857.83",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "pre_orf": "R025",
    },
    {
        "classification": 0,
        "ang": "110",
        "600_b": "100-682.84*Math.pow(pt_b,(-0.9582))",
        "pre-orf_no": "40285-03",
        "part_no": "40286-03",
        "200_b": "8.4398*Math.log(pt_b)-20.918",
        "csscolor": "tip-blue",
        "cv_tip": "0.047",
        "141_s": "4.2793*Math.log(pt)-11.045",
        "600_s": "100-682.84*Math.pow(pt,(-0.9582))",
        "r_min": "0.237",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "-85.24*Math.log(pt)+525.13",
        "vmd_b": "-127.27*Math.log(pt_b)+912.09",
        "tip": "DR110-03",
        "Dv01_b": "-85.24*Math.log(pt_b)+525.13",
        "141_b": "4.2793*Math.log(pt_b)-11.045",
        "200_s": "8.4398*Math.log(pt)-20.918",
        "color": "Blue",
        "tip_rate": "0.3",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.424",
        "vmd_s": "-127.27*Math.log(pt)+912.09",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "pre_orf": "R03",
    },
    {
        "classification": 0,
        "ang": "110",
        "600_b": "100-588.64*Math.pow(pt_b,(-0.8624))",
        "pre-orf_no": "40285-04",
        "part_no": "40286-04",
        "200_b": "7.7754*Math.log(pt_b)-19.615",
        "csscolor": "tip-red",
        "cv_tip": "0.063",
        "141_s": "3.9103*Math.log(pt)-10.253",
        "600_s": "100-588.64*Math.pow(pt,(-0.8624))",
        "r_min": "0.316",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "991.4*Math.pow(pt,-0.412)",
        "vmd_b": "-140.46*Math.log(pt_b)+987.44",
        "tip": "DR110-04",
        "Dv01_b": "991.4*Math.pow(pt_b,-0.412)",
        "141_b": "3.9103*Math.log(pt_b)-10.253",
        "200_s": "7.7754*Math.log(pt)-19.615",
        "color": "Red",
        "tip_rate": "0.4",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.566",
        "vmd_s": "-140.46*Math.log(pt)+987.44",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "pre_orf": "R04",
    },
    {
        "classification": 0,
        "ang": "110",
        "600_b": "100-222.43*Math.pow(pt_b,(-0.5264))",
        "pre-orf_no": "40285-05",
        "part_no": "40286-05",
        "200_b": "3.9931*Math.log(pt_b)-8.3775",
        "csscolor": "tip-brown",
        "cv_tip": "0.079",
        "141_s": "1.8141*Math.log(pt)-3.9502",
        "600_s": "100-222.43*Math.pow(pt,(-0.5264))",
        "r_min": "0.395",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "-64.6*Math.log(pt)+488.2",
        "vmd_b": "-93.568*Math.log(pt_b)+848.48",
        "tip": "DR110-05",
        "Dv01_b": "-64.6*Math.log(pt_b)+488.2",
        "141_b": "1.8141*Math.log(pt_b)-3.9502",
        "200_s": "3.9931*Math.log(pt)-8.3775",
        "color": "Brown",
        "tip_rate": "0.5",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.707",
        "vmd_s": "-93.568*Math.log(pt)+848.48",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "pre_orf": "R05",
    },
    {
        "classification": 0,
        "ang": "110",
        "600_b": "100-294.08*Math.pow(pt_b,(-0.567))",
        "pre-orf_no": "40285-06",
        "part_no": "40286-06",
        "200_b": "4.132*Math.log(pt_b)-9.6535",
        "csscolor": "tip-grey",
        "cv_tip": "0.095",
        "141_s": "1.8936*Math.log(pt)-4.5461",
        "600_s": "100-294.08*Math.pow(pt,(-0.567))",
        "r_min": "0.474",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "-81.24*Math.log(pt)+567.3",
        "vmd_b": "-125.29*Math.log(pt_b)+991.17",
        "tip": "DR110-06",
        "Dv01_b": "-81.24*Math.log(pt_b)+567.3",
        "141_b": "1.8936*Math.log(pt_b)-4.5461",
        "200_s": "4.132*Math.log(pt)-9.6535",
        "color": "Grey",
        "tip_rate": "0.6",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "0.849",
        "vmd_s": "-125.29*Math.log(pt)+991.17",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "R06",
    },
    {
        "classification": 1,
        "ang": "110",
        "600_b": "100-230.17*Math.pow(pt_b,(-0.3971))",
        "pre-orf_no": "40285-08",
        "part_no": "40286-08",
        "200_b": "4.0798*Math.log(pt_b)-8.5953",
        "csscolor": "tip-white",
        "cv_tip": "0.126",
        "141_s": "1.968*Math.log(pt)-3.684",
        "600_s": "100-230.17*Math.pow(pt,(-0.3971))",
        "r_min": "0.632",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "-33.16*Math.log(pt)+317.96",
        "vmd_b": "-156.62*Math.log(pt_b)+1147.1",
        "tip": "DR110-08",
        "Dv01_b": "-33.16*Math.log(pt_b)+317.96",
        "141_b": "1.968*Math.log(pt_b)-3.684",
        "200_s": "4.0798*Math.log(pt)-8.5953",
        "color": "White",
        "tip_rate": "0.8",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "1.131",
        "vmd_s": "-156.62*Math.log(pt)+1147.1",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "R08",
    },
    {
        "classification": 1,
        "ang": "110",
        "600_b": "100-155.28*Math.pow(pt_b,(-0.2433))",
        "pre-orf_no": "40285-10",
        "part_no": "40286-10",
        "200_b": "3.837*Math.log(pt_b)-8.9716",
        "csscolor": "tip-lt_blue",
        "cv_tip": "0.158",
        "141_s": "2.3349*Math.log(pt)-5.3296",
        "600_s": "100-155.28*Math.pow(pt,(-0.2433))",
        "r_min": "0.791",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "-31.43*Math.log(pt)+340.6",
        "vmd_b": "-127.97*Math.log(pt_b)+1107",
        "tip": "DR110-10",
        "Dv01_b": "-31.43*Math.log(pt_b)+340.6",
        "141_b": "2.3349*Math.log(pt_b)-5.3296",
        "200_s": "3.837*Math.log(pt)-8.9716",
        "color": "Lt Blue",
        "tip_rate": "1",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "1.414",
        "vmd_s": "-127.97*Math.log(pt)+1107",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "R010",
    },
    {
        "classification": 1,
        "ang": "110",
        "600_b": "100-142.98*Math.pow(pt_b,(-0.2302))",
        "pre-orf_no": "40285-125",
        "part_no": "40286-125",
        "200_b": "3.0398*Math.log(pt_b)-4.4915",
        "csscolor": "tip-teal",
        "cv_tip": "0.198",
        "141_s": "2.1266*Math.log(pt)-3.8655",
        "600_s": "100-142.98*Math.pow(pt,(-0.2302))",
        "r_min": "0.988",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "-58.91*Math.log(pt)+437.35",
        "vmd_b": "-109.11*Math.log(pt_b)+1018.4",
        "tip": "DR110-125",
        "Dv01_b": "-58.91*Math.log(pt_b)+437.35",
        "141_b": "2.1266*Math.log(pt_b)-3.8655",
        "200_s": "3.0398*Math.log(pt)-4.4915",
        "color": "Teal",
        "tip_rate": "1.25",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "1.768",
        "vmd_s": "-109.11*Math.log(pt)+1018.4",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "R12.5",
    },
    {
        "classification": 1,
        "ang": "110",
        "600_b": "100-204.8*Math.pow(pt_b,(-0.3589))",
        "pre-orf_no": "40285-15",
        "part_no": "40286-15",
        "200_b": "4.1475*Math.log(pt_b)-9.4304",
        "csscolor": "tip-lt_green",
        "cv_tip": "0.237",
        "141_s": "1.212*Math.log(pt)-0.7116",
        "600_s": "100-204.8*Math.pow(pt,(-0.3589))",
        "r_min": "1.186",
        "pt": "40",
        "cat_s": "UC",
        "Dv01_s": "-54.06*Math.log(pt)+427.42",
        "vmd_b": "-121.59*Math.log(pt_b)+1072.9",
        "tip": "DR110-15",
        "Dv01_b": "-54.06*Math.log(pt_b)+427.42",
        "141_b": "1.212*Math.log(pt_b)-0.7116",
        "200_s": "4.1475*Math.log(pt)-9.4304",
        "color": "Lt Green",
        "tip_rate": "1.5",
        "pg": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_max": "2.121",
        "vmd_s": "-121.59*Math.log(pt)+1072.9",
        "screen_no": "Not Required",
        "screen": "None",
        "pre_orf": "R15",
    }
];

var tips_fertilizer_table_cj = [
    {
        "tip":"R005 Metering Orifice",
        "part_no":"40285-005",
        "color": "Black", "csscolor": "tip-black",
        "tip_rate":"0.05",
        "screen_no":"100 Mesh Stainless (#40251-00)",
        "screen":"100/Green",
        "r_min":"0.025",
        "r_max":"0.071",
        "caps":["40432-047","40420-05","40422-05","40424-05","40426-05","40435-05","40436-05","40437-05","40273-05","40274-05","40277-05"]
    },
    {
        "tip":"R0067 Metering Orifice",
        "part_no":"40285-007",
        "color": "Pink", "csscolor": "tip-pink",
        "tip_rate":"0.067",
        "screen_no":"100 Mesh Stainless (#40251-00)",
        "screen":"100/Green",
        "r_min":"0.034",
        "r_max":"0.095",
        "caps":["40432-047","40420-05","40422-05","40424-05","40426-05","40435-05","40436-05","40437-05","40273-05","40274-05","40277-05"]
    },
    {
        "tip":"R01 Metering Orifice",
        "part_no":"40285-01",
        "color": "Orange", "csscolor": "tip-orange",
        "tip_rate":"0.1",
        "screen_no":"100 Mesh Stainless (#40251-00)",
        "screen":"100/Green",
        "r_min":"0.050",
        "r_max":"0.141",
        "caps":["40432-047","40420-05","40422-05","40424-05","40426-05","40435-05","40436-05","40437-05","40273-05","40274-05","40277-05"]
    },
    {
        "tip":"R015 Metering Orifice",
        "part_no":"40285-015",
        "color": "Green", "csscolor": "tip-green",
        "tip_rate":"0.15",
        "screen_no":"100 Mesh Stainless (#40251-00)",
        "screen":"100/Green",
        "r_min":"0.075",
        "r_max":"0.212",
        "caps":["40432-047","40432-086","40433-047","40420-05","40422-05","40424-05","40426-05","40435-05","40436-05","40437-05","40273-05","40274-05","40277-05"]
    },
    {
        "tip":"R02 Metering Orifice",
        "part_no":"40285-02",
        "color": "Yellow", "csscolor": "tip-yellow",
        "tip_rate":"0.2",
        "screen_no":"50 Mesh Slotted Strainer (#40249-00)",
        "screen":"50/Red Slotted",
        "r_min":"0.100",
        "r_max":"0.283",
        "caps":["40432-047","40432-086","40433-047","40433-067","40420-05","40422-05","40424-05","40426-05","40435-05","40436-05","40437-05","40273-05","40274-05","40277-05"]
    },
    {
        "tip":"R025 Metering Orifice",
        "part_no":"40285-025",
        "color": "Purple", "csscolor": "tip-purple",
        "tip_rate":"0.25",
        "screen_no":"50 Mesh Slotted Strainer (#40249-00)",
        "screen":"50/Red Slotted",
        "r_min":"0.125",
        "r_max":"0.354",
        "caps":["40432-047","40432-086","40433-047","40433-067","40420-05","40422-05","40424-05","40426-05","40435-05","40436-05","40437-05","40273-05","40274-05","40277-05"]
    },
    {
        "tip":"R03 Metering Orifice",
        "part_no":"40285-03",
        "color": "Blue", "csscolor": "tip-blue",
        "tip_rate":"0.3",
        "screen_no":"50 Mesh Slotted Strainer (#40249-00)",
        "screen":"50/Red Slotted",
        "r_min":"0.150",
        "r_max":"0.424",
        "caps":["40432-047","40432-086","40433-047","40433-067","40420-05","40422-05","40424-05","40426-05","40435-05","40436-05","40437-05","40273-05","40274-05","40277-05"]
    },
    {
        "tip":"R04 Metering Orifice",
        "part_no":"40285-04",
        "color": "Red", "csscolor": "tip-red",
        "tip_rate":"0.4",
        "screen_no":"50 Mesh Slotted Strainer (#40249-00)",
        "screen":"50/Red Slotted",
        "r_min":"0.200",
        "r_max":"0.566",
        "caps":["40432-047","40432-086","40432-104","40433-047","40433-067","40420-05","40422-05","40424-05","40426-05","40435-05","40436-05","40437-05","40273-05","40274-05"]
    },
    {
        "tip":"R05 Metering Orifice",
        "part_no":"40285-05",
        "color": "Brown", "csscolor": "tip-brown",
        "tip_rate":"0.5",
        "screen_no":"50 Mesh Slotted Strainer (#40249-00)",
        "screen":"50/Red Slotted",
        "r_min":"0.250",
        "r_max":"0.707",
        "caps":["40432-086","40432-104","40433-067","40420-05","40422-05","40424-05","40426-05","40435-05","40436-05","40437-05","40273-05","40274-05"]
    },
    {
        "tip":"R06 Metering Orifice",
        "part_no":"40285-06",
        "color": "Grey", "csscolor": "tip-grey",
        "tip_rate":"0.6",
        "screen_no":"Not Required",
        "screen":"None",
        "r_min":"0.300",
        "r_max":"0.849",
        "caps":["40432-086","40432-104","40433-067","40433-104","40420-05","40422-05","40424-05","40426-05","40435-05","40436-05","40437-05","40273-05","40274-05"]
    },
    {
        "tip":"R08 Metering Orifice",
        "part_no":"40285-08",
        "color": "White", "csscolor": "tip-white",
        "tip_rate":"0.8",
        "screen_no":"Not Required",
        "screen":"None",
        "r_min":"0.400",
        "r_max":"1.131",
        "caps":["40432-086","40432-104","40433-067","40433-104","40420-05","40422-05","40424-05","40426-05","40435-05","40436-05","40437-05","40273-05","40274-05"]
    },
    {
        "tip":"R10 Metering Orifice",
        "part_no":"40285-10",
        "color": "Lt Blue", "csscolor": "tip-lt_blue",
        "tip_rate":"1",
        "screen_no":"Not Required",
        "screen":"None",
        "r_min":"0.500",
        "r_max":"1.414",
        "caps":["40432-086","40432-104","40433-067","40433-104","40420-05","40422-05","40424-05","40426-05","40435-05","40436-05","40437-05","40273-05","40274-05"]
    },
    {
        "tip":"R125 Metering Orifice",
        "part_no":"40285-125",
        "color": "Teal", "csscolor": "tip-teal",
        "tip_rate":"1.25",
        "screen_no":"Not Required",
        "screen":"None",
        "r_min":"0.625",
        "r_max":"1.768",
        "caps":["40432-104","40433-104","40422-05","40424-05","40426-05","40436-05","40437-05"]
    },
    {
        "tip":"R15 Metering Orifice",
        "part_no":"40285-15",
        "color": "Lt Green", "csscolor": "tip-lt_green",
        "tip_rate":"1.5",
        "screen_no":"Not Required",
        "screen":"None",
        "r_min":"0.750",
        "r_max":"2.121",
        "caps":["40432-104","40433-104","40422-05","40424-05","40426-05","40436-05","40437-05"]
    },
    {
        "tip":"R20 Metering Orifice",
        "part_no":"40285-20",
        "color": "Tan", "csscolor": "tip-tan",
        "tip_rate":"2",
        "screen_no":"Not Required",
        "screen":"None",
        "r_min":"1.000",
        "r_max":"2.828",
        "caps":["40433-104","40422-05","40424-05","40426-05","40436-05","40437-05"]
    },
    {
        "tip":"R25 Metering Orifice",
        "part_no":"40285-25",
        "color": "Black", "csscolor": "tip-black",
        "tip_rate":"2.5",
        "screen_no":"Not Required",
        "screen":"None",
        "r_min":"1.250",
        "r_max":"3.536",
        "caps":["40433-104","40424-05","40426-05","40437-05"]
    },
    {
        "tip":"R40 Metering Orifice",
        "part_no":"40285-30",
        "color": "Black", "csscolor": "tip-black",
        "tip_rate":"3",
        "screen_no":"Not Required",
        "screen":"None",
        "r_min":"1.500",
        "r_max":"4.243",
        "caps":["40433-104","40424-05","40426-05"]
    },
    {
        "tip":"R40 Metering Orifice",
        "part_no":"40285-40",
        "color": "Black", "csscolor": "tip-black",
        "tip_rate":"4",
        "screen_no":"Not Required",
        "screen":"None",
        "r_min":"2.000",
        "r_max":"5.657",
        "caps":["40426-05"]
    },
    {
        "tip":"R50 Metering Orifice",
        "part_no":"40285-50",
        "color": "Black", "csscolor": "tip-black",
        "tip_rate":"5",
        "screen_no":"Not Required",
        "screen":"None",
        "r_min":"2.5",
        "r_max":"7.071",
        "caps":["40426-05"]
    }
];

var tips_fertilizer_table_ors = [
  {
    "tip":"ORS 003 Metering Orifice",
    "part_no": "21500-V003",
    "color": "Natural",
    "csscolor": "tip-white",
    "tip_rate":"0.03",
    "r_min":"0.015",
    "r_max":"0.042",
    "caps": [
      "20500-00","20501-00","20511-00","20502-00","20512-00","20503-00","20513-00","20504-00","20506-00","20516-00","20507-00","20517-00","20508-00","20528-00","20519-00","20518-00"
    ]
  },
  {
    "tip":"ORS 005 Metering Orifice",
    "part_no": "21500-V005",
    "color": "Black",
    "csscolor": "tip-black",
    "tip_rate": "0.05",
    "r_min": "0.025",
    "r_max": "0.071",
    "caps": [
      "20500-00","20501-00","20511-00","20502-00","20512-00","20503-00","20513-00","20504-00","20506-00","20516-00","20507-00","20517-00","20508-00","20528-00","20519-00","20518-00"
    ]
  },
  {
    "tip":"ORS 0067 Metering Orifice",
    "part_no": "21500-V007",
    "color": "Pink",
    "csscolor": "tip-pink",
    "tip_rate": "0.067",
    "r_min": "0.034",
    "r_max": "0.095",
    "caps": [
      "20500-00","20501-00","20511-00","20502-00","20512-00","20503-00","20513-00","20504-00","20506-00","20516-00","20507-00","20517-00","20508-00","20528-00","20519-00","20518-00"
    ]
  },
  {
    "tip":"ORS 01 Metering Orifice",
    "part_no": "21500-V01",
    "color": "Orange",
    "csscolor": "tip-orange",
    "tip_rate": "0.1",
    "r_min": "0.050",
    "r_max": "0.141",
    "caps": [
      "20500-00","20501-00","20511-00","20502-00","20512-00","20503-00","20513-00","20504-00","20506-00","20516-00","20507-00","20517-00","20508-00","20528-00","20519-00","20518-00"
    ]
  },
  {
    "tip":"ORS 015 Metering Orifice",
    "part_no": "21500-V015",
    "color": "Green",
    "csscolor": "tip-green",
    "tip_rate": "0.15",
    "r_min": "0.075",
    "r_max": "0.212",
    "caps": [
      "20500-00","20501-00","20511-00","20502-00","20512-00","20503-00","20513-00","20504-00","20506-00","20516-00","20507-00","20517-00","20508-00","20528-00","20519-00","20518-00"
    ]
  },
  {
    "tip":"ORS 02 Metering Orifice",
    "part_no": "21500-V02",
    "color": "Yellow",
    "csscolor": "tip-yellow",
    "tip_rate": "0.2",
    "r_min": "0.100",
    "r_max": "0.283",
    "caps": [
      "20500-00","20501-00","20511-00","20502-00","20512-00","20503-00","20513-00","20504-00","20506-00","20516-00","20507-00","20517-00","20508-00","20528-00","20519-00","20518-00"
    ]
  },
  {
    "tip":"ORS 025 Metering Orifice",
    "part_no": "21500-V025",
    "color": "Purple",
    "csscolor": "tip-purple",
    "tip_rate": "0.25",
    "r_min": "0.125",
    "r_max": "0.354",
    "caps": [
      "20500-00","20501-00","20511-00","20502-00","20512-00","20503-00","20513-00","20504-00","20506-00","20516-00","20507-00","20517-00","20508-00","20528-00","20519-00","20518-00"
    ]
  },
  {
    "tip":"ORS 03 Metering Orifice",
    "part_no": "21500-V03",
    "color": "Blue",
    "csscolor": "tip-blue",
    "tip_rate": "0.3",
    "r_min": "0.150",
    "r_max": "0.424",
    "caps": [
      "20500-00","20501-00","20511-00","20502-00","20512-00","20503-00","20513-00","20504-00","20506-00","20516-00","20507-00","20517-00","20508-00","20528-00","20519-00","20518-00"
    ]
  },
  {
    "tip":"ORS 04 Metering Orifice",
    "part_no": "21500-V04",
    "color": "Red",
    "csscolor": "tip-red",
    "tip_rate": "0.4",
    "r_min": "0.200",
    "r_max": "0.566",
    "caps": [
      "20500-00","20501-00","20511-00","20502-00","20512-00","20503-00","20513-00","20504-00","20506-00","20516-00","20507-00","20517-00","20508-00","20528-00","20519-00","20518-00"
    ]
  },
  {
    "tip":"ORS 05 Metering Orifice",
    "part_no": "21500-V05",
    "color": "Brown",
    "csscolor": "tip-brown",
    "tip_rate": "0.5",
    "r_min": "0.250",
    "r_max": "0.707",
    "caps": [
      "20500-00","20501-00","20511-00","20502-00","20512-00","20503-00","20513-00","20504-00","20506-00","20516-00","20507-00","20517-00","20508-00","20528-00","20519-00","20518-00"
    ]
  },
  {
    "tip":"ORS 06 Metering Orifice",
    "part_no": "21500-V06",
    "color": "Grey",
    "csscolor": "tip-grey",
    "tip_rate": "0.6",
    "r_min": "0.300",
    "r_max": "0.849",
    "caps": [
      "20500-00","20501-00","20511-00","20502-00","20512-00","20503-00","20513-00","20504-00","20506-00","20516-00","20507-00","20517-00","20508-00","20528-00","20519-00","20518-00"
    ]
  },
  {
    "tip":"ORS 08 Metering Orifice",
    "part_no": "21500-V08",
    "color": "White",
    "csscolor": "tip-white",
    "tip_rate": "0.8",
    "r_min": "0.400",
    "r_max": "1.131",
    "caps": [
      "20500-00","20501-00","20511-00","20502-00","20512-00","20503-00","20513-00","20504-00","20506-00","20516-00","20507-00","20517-00","20508-00","20528-00","20519-00","20518-00"
    ]
  },
  {
    "tip":"ORS 10 Metering Orifice",
    "part_no": "21500-V10",
    "color": "Lt Blue",
    "csscolor": "tip-lt_blue",
    "tip_rate": "1",
    "r_min": "0.500",
    "r_max": "1.414",
    "caps": [
      "20500-00","20501-00","20511-00","20502-00","20512-00","20503-00","20513-00","20504-00","20506-00","20516-00","20507-00","20517-00","20508-00","20528-00","20519-00","20518-00"
    ]
  },
  {
    "tip":"ORS 125 Metering Orifice",
    "part_no": "21500-V125",
    "color": "Teal",
    "csscolor": "tip-teal",
    "tip_rate": "1.25",
    "r_min": "0.625",
    "r_max": "1.768",
    "caps": [
      "20501-00","20511-00","20502-00","20512-00","20503-00","20513-00","20504-00","20507-00","20517-00","20508-00","20528-00"
    ]
  },
  {
    "tip":"ORS 15 Metering Orifice",
    "part_no": "21500-V15",
    "color": "Lt Green",
    "csscolor": "tip-lt_green",
    "tip_rate": "1.5",
    "r_min": "0.750",
    "r_max": "2.121",
    "caps": [
      "20501-00","20511-00","20502-00","20512-00","20503-00","20513-00","20504-00","20507-00","20517-00","20508-00","20528-00"
    ]
  },
  {
    "tip":"ORS 20 Metering Orifice",
    "part_no": "21500-V20",
    "color": "Tan",
    "csscolor": "tip-tan",
    "tip_rate": "2",
    "r_min": "1.000",
    "r_max": "2.828",
    "caps": [
      "20501-00","20511-00","20502-00","20512-00","20503-00","20513-00","20504-00","20503-00","20513-00","20504-00","20507-00","20517-00","20508-00","20528-00"
    ]
  },
  {
    "tip":"ORS 0.009\" Drilled Metering Orifice",
    "part_no": "21009-XX",
    "color": "Black",
    "csscolor": "tip-black",
    "tip_rate_30": "0.009",
    "tip_rate": "tip_rate_30*Math.sqrt(40.0/30.0)",
    "r_min": "tip_rate_30*Math.sqrt(10.0/30.0)",
    "r_max": "tip_rate_30*Math.sqrt(60.0/30.0)",
    "caps": [
      "20500-00","20501-00","20511-00","20502-00","20512-00","20503-00","20513-00","20504-00","20506-00","20516-00","20507-00","20517-00","20508-00","20528-00","20519-00","20518-00"
    ]
  },
  {
    "tip":"ORS 0.011\" Drilled Metering Orifice",
    "part_no": "21011-XX",
    "color": "Black",
    "csscolor": "tip-black",
    "tip_rate_30": "0.014",
    "tip_rate": "tip_rate_30*Math.sqrt(40.0/30.0)",
    "r_min": "tip_rate_30*Math.sqrt(10.0/30.0)",
    "r_max": "tip_rate_30*Math.sqrt(60.0/30.0)",
    "caps": [
      "20500-00","20501-00","20511-00","20502-00","20512-00","20503-00","20513-00","20504-00","20506-00","20516-00","20507-00","20517-00","20508-00","20528-00","20519-00","20518-00"
    ]
  },
  {
    "tip":"ORS 0.013\" Drilled Metering Orifice",
    "part_no": "21013-XX",
    "color": "Black",
    "csscolor": "tip-black",
    "tip_rate_30": "0.019",
    "tip_rate": "tip_rate_30*Math.sqrt(40.0/30.0)",
    "r_min": "tip_rate_30*Math.sqrt(10.0/30.0)",
    "r_max": "tip_rate_30*Math.sqrt(60.0/30.0)",
    "caps": [
      "20500-00","20501-00","20511-00","20502-00","20512-00","20503-00","20513-00","20504-00","20506-00","20516-00","20507-00","20517-00","20508-00","20528-00","20519-00","20518-00"
    ]
  },
  {
    "tip":"ORS 0.015\" Drilled Metering Orifice",
    "part_no": "21015-XX",
    "color": "Black",
    "csscolor": "tip-black",
    "tip_rate_30": "0.025",
    "tip_rate": "tip_rate_30*Math.sqrt(40.0/30.0)",
    "r_min": "tip_rate_30*Math.sqrt(10.0/30.0)",
    "r_max": "tip_rate_30*Math.sqrt(60.0/30.0)",
    "caps": [
      "20500-00","20501-00","20511-00","20502-00","20512-00","20503-00","20513-00","20504-00","20506-00","20516-00","20507-00","20517-00","20508-00","20528-00","20519-00","20518-00"
    ]
  },
  {
    "tip":"ORS 0.018\" Drilled Metering Orifice",
    "part_no": "21018-XX",
    "color": "Black",
    "csscolor": "tip-black",
    "tip_rate_30": "0.036",
    "tip_rate": "tip_rate_30*Math.sqrt(40.0/30.0)",
    "r_min": "tip_rate_30*Math.sqrt(10.0/30.0)",
    "r_max": "tip_rate_30*Math.sqrt(60.0/30.0)",
    "caps": [
      "20500-00","20501-00","20511-00","20502-00","20512-00","20503-00","20513-00","20504-00","20506-00","20516-00","20507-00","20517-00","20508-00","20528-00","20519-00","20518-00"
    ]
  },
  {
    "tip":"ORS 0.020\" Drilled Metering Orifice",
    "part_no": "21020-XX",
    "color": "Black",
    "csscolor": "tip-black",
    "tip_rate_30": "0.045",
    "tip_rate": "tip_rate_30*Math.sqrt(40.0/30.0)",
    "r_min": "tip_rate_30*Math.sqrt(10.0/30.0)",
    "r_max": "tip_rate_30*Math.sqrt(60.0/30.0)",
    "caps": [
      "20500-00","20501-00","20511-00","20502-00","20512-00","20503-00","20513-00","20504-00","20506-00","20516-00","20507-00","20517-00","20508-00","20528-00","20519-00","20518-00"
    ]
  },
  {
    "tip":"ORS 0.022\" Drilled Metering Orifice",
    "part_no": "21022-XX",
    "color": "Black",
    "csscolor": "tip-black",
    "tip_rate_30": "0.053",
    "tip_rate": "tip_rate_30*Math.sqrt(40.0/30.0)",
    "r_min": "tip_rate_30*Math.sqrt(10.0/30.0)",
    "r_max": "tip_rate_30*Math.sqrt(60.0/30.0)",
    "caps": [
      "20500-00","20501-00","20511-00","20502-00","20512-00","20503-00","20513-00","20504-00","20506-00","20516-00","20507-00","20517-00","20508-00","20528-00","20519-00","20518-00"
    ]
  },
  {
    "tip":"ORS 0.025\" Drilled Metering Orifice",
    "part_no": "21025-XX",
    "color": "Black",
    "csscolor": "tip-black",
    "tip_rate_30": "0.068",
    "tip_rate": "tip_rate_30*Math.sqrt(40.0/30.0)",
    "r_min": "tip_rate_30*Math.sqrt(10.0/30.0)",
    "r_max": "tip_rate_30*Math.sqrt(60.0/30.0)",
    "caps": [
      "20500-00","20501-00","20511-00","20502-00","20512-00","20503-00","20513-00","20504-00","20506-00","20516-00","20507-00","20517-00","20508-00","20528-00","20519-00","20518-00"
    ]
  },
  {
    "tip":"ORS 0.028\" Drilled Metering Orifice",
    "part_no": "21028-XX",
    "color": "Black",
    "csscolor": "tip-black",
    "tip_rate_30": "0.085",
    "tip_rate": "tip_rate_30*Math.sqrt(40.0/30.0)",
    "r_min": "tip_rate_30*Math.sqrt(10.0/30.0)",
    "r_max": "tip_rate_30*Math.sqrt(60.0/30.0)",
    "caps": [
      "20500-00","20501-00","20511-00","20502-00","20512-00","20503-00","20513-00","20504-00","20506-00","20516-00","20507-00","20517-00","20508-00","20528-00","20519-00","20518-00"
    ]
  },
  {
    "tip":"ORS 0.031\" Drilled Metering Orifice",
    "part_no": "21031-XX",
    "color": "Black",
    "csscolor": "tip-black",
    "tip_rate_30": "0.11",
    "tip_rate": "tip_rate_30*Math.sqrt(40.0/30.0)",
    "r_min": "tip_rate_30*Math.sqrt(10.0/30.0)",
    "r_max": "tip_rate_30*Math.sqrt(60.0/30.0)",
    "caps": [
      "20500-00","20501-00","20511-00","20502-00","20512-00","20503-00","20513-00","20504-00","20506-00","20516-00","20507-00","20517-00","20508-00","20528-00","20519-00","20518-00"
    ]
  },
  {
    "tip":"ORS 0.034\" Drilled Metering Orifice",
    "part_no": "21034-XX",
    "color": "Black",
    "csscolor": "tip-black",
    "tip_rate_30": "0.13",
    "tip_rate": "tip_rate_30*Math.sqrt(40.0/30.0)",
    "r_min": "tip_rate_30*Math.sqrt(10.0/30.0)",
    "r_max": "tip_rate_30*Math.sqrt(60.0/30.0)",
    "caps": [
      "20500-00","20501-00","20511-00","20502-00","20512-00","20503-00","20513-00","20504-00","20506-00","20516-00","20507-00","20517-00","20508-00","20528-00","20519-00","20518-00"
    ]
  },
  {
    "tip":"ORS 0.037\" Drilled Metering Orifice",
    "part_no": "21037-XX",
    "color": "Black",
    "csscolor": "tip-black",
    "tip_rate_30": "0.15",
    "tip_rate": "tip_rate_30*Math.sqrt(40.0/30.0)",
    "r_min": "tip_rate_30*Math.sqrt(10.0/30.0)",
    "r_max": "tip_rate_30*Math.sqrt(60.0/30.0)",
    "caps": [
      "20500-00","20501-00","20511-00","20502-00","20512-00","20503-00","20513-00","20504-00","20506-00","20516-00","20507-00","20517-00","20508-00","20528-00","20519-00","20518-00"
    ]
  },
  {
    "tip":"ORS 0.040\" Drilled Metering Orifice",
    "part_no": "21040-XX",
    "color": "Black",
    "csscolor": "tip-black",
    "tip_rate_30": "0.18",
    "tip_rate": "tip_rate_30*Math.sqrt(40.0/30.0)",
    "r_min": "tip_rate_30*Math.sqrt(10.0/30.0)",
    "r_max": "tip_rate_30*Math.sqrt(60.0/30.0)",
    "caps": [
      "20500-00","20501-00","20511-00","20502-00","20512-00","20503-00","20513-00","20504-00","20506-00","20516-00","20507-00","20517-00","20508-00","20528-00","20519-00","20518-00"
    ]
  },
  {
    "tip":"ORS 0.043\" Drilled Metering Orifice",
    "part_no": "21043-XX",
    "color": "Black",
    "csscolor": "tip-black",
    "tip_rate_30": "0.20",
    "tip_rate": "tip_rate_30*Math.sqrt(40.0/30.0)",
    "r_min": "tip_rate_30*Math.sqrt(10.0/30.0)",
    "r_max": "tip_rate_30*Math.sqrt(60.0/30.0)",
    "caps": [
      "20500-00","20501-00","20511-00","20502-00","20512-00","20503-00","20513-00","20504-00","20506-00","20516-00","20507-00","20517-00","20508-00","20528-00","20519-00","20518-00"
    ]
  },
  {
    "tip":"ORS 0.046\" Drilled Metering Orifice",
    "part_no": "21046-XX",
    "color": "Black",
    "csscolor": "tip-black",
    "tip_rate_30": "0.23",
    "tip_rate": "tip_rate_30*Math.sqrt(40.0/30.0)",
    "r_min": "tip_rate_30*Math.sqrt(10.0/30.0)",
    "r_max": "tip_rate_30*Math.sqrt(60.0/30.0)",
    "caps": [
      "20500-00","20501-00","20511-00","20502-00","20512-00","20503-00","20513-00","20504-00","20506-00","20516-00","20507-00","20517-00","20508-00","20528-00","20519-00","20518-00"
    ]
  },
  {
    "tip":"ORS 0.049\" Drilled Metering Orifice",
    "part_no": "21049-XX",
    "color": "Black",
    "csscolor": "tip-black",
    "tip_rate_30": "0.26",
    "tip_rate": "tip_rate_30*Math.sqrt(40.0/30.0)",
    "r_min": "tip_rate_30*Math.sqrt(10.0/30.0)",
    "r_max": "tip_rate_30*Math.sqrt(60.0/30.0)",
    "caps": [
      "20500-00","20501-00","20511-00","20502-00","20512-00","20503-00","20513-00","20504-00","20506-00","20516-00","20507-00","20517-00","20508-00","20528-00","20519-00","20518-00"
    ]
  },
  {
    "tip":"ORS 0.052\" Drilled Metering Orifice",
    "part_no": "21052-XX",
    "color": "Black",
    "csscolor": "tip-black",
    "tip_rate_30": "0.29",
    "tip_rate": "tip_rate_30*Math.sqrt(40.0/30.0)",
    "r_min": "tip_rate_30*Math.sqrt(10.0/30.0)",
    "r_max": "tip_rate_30*Math.sqrt(60.0/30.0)",
    "caps": [
      "20500-00","20501-00","20511-00","20502-00","20512-00","20503-00","20513-00","20504-00","20506-00","20516-00","20507-00","20517-00","20508-00","20528-00","20519-00","20518-00"
    ]
  },
  {
    "tip":"ORS 0.055\" Drilled Metering Orifice",
    "part_no": "21055-XX",
    "color": "Black",
    "csscolor": "tip-black",
    "tip_rate_30": "0.33",
    "tip_rate": "tip_rate_30*Math.sqrt(40.0/30.0)",
    "r_min": "tip_rate_30*Math.sqrt(10.0/30.0)",
    "r_max": "tip_rate_30*Math.sqrt(60.0/30.0)",
    "caps": [
      "20500-00","20501-00","20511-00","20502-00","20512-00","20503-00","20513-00","20504-00","20506-00","20516-00","20507-00","20517-00","20508-00","20528-00","20519-00","20518-00"
    ]
  },
  {
    "tip":"ORS 0.057\" Drilled Metering Orifice",
    "part_no": "21057-XX",
    "color": "Black",
    "csscolor": "tip-black",
    "tip_rate_30": "0.35",
    "tip_rate": "tip_rate_30*Math.sqrt(40.0/30.0)",
    "r_min": "tip_rate_30*Math.sqrt(10.0/30.0)",
    "r_max": "tip_rate_30*Math.sqrt(60.0/30.0)",
    "caps": [
      "20500-00","20501-00","20511-00","20502-00","20512-00","20503-00","20513-00","20504-00","20506-00","20516-00","20507-00","20517-00","20508-00","20528-00","20519-00","20518-00"
    ]
  },
  {
    "tip":"ORS 0.060\" Drilled Metering Orifice",
    "part_no": "21060-XX",
    "color": "Black",
    "csscolor": "tip-black",
    "tip_rate_30": "0.39",
    "tip_rate": "tip_rate_30*Math.sqrt(40.0/30.0)",
    "r_min": "tip_rate_30*Math.sqrt(10.0/30.0)",
    "r_max": "tip_rate_30*Math.sqrt(60.0/30.0)",
    "caps": [
      "20500-00","20501-00","20511-00","20502-00","20512-00","20503-00","20513-00","20504-00","20506-00","20516-00","20507-00","20517-00","20508-00","20528-00","20519-00","20518-00"
    ]
  },
  {
    "tip":"ORS 0.063\" Drilled Metering Orifice",
    "part_no": "21063-XX",
    "color": "Black",
    "csscolor": "tip-black",
    "tip_rate_30": "0.43",
    "tip_rate": "tip_rate_30*Math.sqrt(40.0/30.0)",
    "r_min": "tip_rate_30*Math.sqrt(10.0/30.0)",
    "r_max": "tip_rate_30*Math.sqrt(60.0/30.0)",
    "caps": [
      "20500-00","20501-00","20511-00","20502-00","20512-00","20503-00","20513-00","20504-00","20506-00","20516-00","20507-00","20517-00","20508-00","20528-00","20519-00","20518-00"
    ]
  },
  {
    "tip":"ORS 0.067\" Drilled Metering Orifice",
    "part_no": "21067-XX",
    "color": "Black",
    "csscolor": "tip-black",
    "tip_rate_30": "0.48",
    "tip_rate": "tip_rate_30*Math.sqrt(40.0/30.0)",
    "r_min": "tip_rate_30*Math.sqrt(10.0/30.0)",
    "r_max": "tip_rate_30*Math.sqrt(60.0/30.0)",
    "caps": [
      "20500-00","20501-00","20511-00","20502-00","20512-00","20503-00","20513-00","20504-00","20506-00","20516-00","20507-00","20517-00","20508-00","20528-00","20519-00","20518-00"
    ]
  },
  {
    "tip":"ORS 0.070\" Drilled Metering Orifice",
    "part_no": "21070-XX",
    "color": "Black",
    "csscolor": "tip-black",
    "tip_rate_30": "0.53",
    "tip_rate": "tip_rate_30*Math.sqrt(40.0/30.0)",
    "r_min": "tip_rate_30*Math.sqrt(10.0/30.0)",
    "r_max": "tip_rate_30*Math.sqrt(60.0/30.0)",
    "caps": [
      "20500-00","20501-00","20511-00","20502-00","20512-00","20503-00","20513-00","20504-00","20506-00","20516-00","20507-00","20517-00","20508-00","20528-00","20519-00","20518-00"
    ]
  },
  {
    "tip":"ORS 0.073\" Drilled Metering Orifice",
    "part_no": "21073-XX",
    "color": "Black",
    "csscolor": "tip-black",
    "tip_rate_30": "0.57",
    "tip_rate": "tip_rate_30*Math.sqrt(40.0/30.0)",
    "r_min": "tip_rate_30*Math.sqrt(10.0/30.0)",
    "r_max": "tip_rate_30*Math.sqrt(60.0/30.0)",
    "caps": [
      "20500-00","20501-00","20511-00","20502-00","20512-00","20503-00","20513-00","20504-00","20506-00","20516-00","20507-00","20517-00","20508-00","20528-00","20519-00","20518-00"
    ]
  },
  {
    "tip":"ORS 0.075\" Drilled Metering Orifice",
    "part_no": "21075-XX",
    "color": "Black",
    "csscolor": "tip-black",
    "tip_rate_30": "0.60",
    "tip_rate": "tip_rate_30*Math.sqrt(40.0/30.0)",
    "r_min": "tip_rate_30*Math.sqrt(10.0/30.0)",
    "r_max": "tip_rate_30*Math.sqrt(60.0/30.0)",
    "caps": [
      "20500-00","20501-00","20511-00","20502-00","20512-00","20503-00","20513-00","20504-00","20506-00","20516-00","20507-00","20517-00","20508-00","20528-00","20519-00","20518-00"
    ]
  },
  {
    "tip":"ORS 0.078\" Drilled Metering Orifice",
    "part_no": "21078-XX",
    "color": "Black",
    "csscolor": "tip-black",
    "tip_rate_30": "0.67",
    "tip_rate": "tip_rate_30*Math.sqrt(40.0/30.0)",
    "r_min": "tip_rate_30*Math.sqrt(10.0/30.0)",
    "r_max": "tip_rate_30*Math.sqrt(60.0/30.0)",
    "caps": [
      "20500-00","20501-00","20511-00","20502-00","20512-00","20503-00","20513-00","20504-00","20506-00","20516-00","20507-00","20517-00","20508-00","20528-00","20519-00","20518-00"
    ]
  },
  {
    "tip":"ORS 0.081\" Drilled Metering Orifice",
    "part_no": "21081-XX",
    "color": "Black",
    "csscolor": "tip-black",
    "tip_rate_30": "0.71",
    "tip_rate": "tip_rate_30*Math.sqrt(40.0/30.0)",
    "r_min": "tip_rate_30*Math.sqrt(10.0/30.0)",
    "r_max": "tip_rate_30*Math.sqrt(60.0/30.0)",
    "caps": [
      "20500-00","20501-00","20511-00","20502-00","20512-00","20503-00","20513-00","20504-00","20506-00","20516-00","20507-00","20517-00","20508-00","20528-00","20519-00","20518-00"
    ]
  },
  {
    "tip":"ORS 0.086\" Drilled Metering Orifice",
    "part_no": "21086-XX",
    "color": "Black",
    "csscolor": "tip-black",
    "tip_rate_30": "0.81",
    "tip_rate": "tip_rate_30*Math.sqrt(40.0/30.0)",
    "r_min": "tip_rate_30*Math.sqrt(10.0/30.0)",
    "r_max": "tip_rate_30*Math.sqrt(60.0/30.0)",
    "caps": [
      "20500-00","20501-00","20511-00","20502-00","20512-00","20503-00","20513-00","20504-00","20506-00","20516-00","20507-00","20517-00","20508-00","20528-00","20519-00","20518-00"
    ]
  },
  {
    "tip":"ORS 0.089\" Drilled Metering Orifice",
    "part_no": "21089-XX",
    "color": "Black",
    "csscolor": "tip-black",
    "tip_rate_30": "0.85",
    "tip_rate": "tip_rate_30*Math.sqrt(40.0/30.0)",
    "r_min": "tip_rate_30*Math.sqrt(10.0/30.0)",
    "r_max": "tip_rate_30*Math.sqrt(60.0/30.0)",
    "caps": [
      "20500-00","20501-00","20511-00","20502-00","20512-00","20503-00","20513-00","20504-00","20506-00","20516-00","20507-00","20517-00","20508-00","20528-00","20519-00","20518-00"
    ]
  },
  {
    "tip":"ORS 0.091\" Drilled Metering Orifice",
    "part_no": "21091-XX",
    "color": "Black",
    "csscolor": "tip-black",
    "tip_rate_30": "0.91",
    "tip_rate": "tip_rate_30*Math.sqrt(40.0/30.0)",
    "r_min": "tip_rate_30*Math.sqrt(10.0/30.0)",
    "r_max": "tip_rate_30*Math.sqrt(60.0/30.0)",
    "caps": [
      "20500-00","20501-00","20511-00","20502-00","20512-00","20503-00","20513-00","20504-00","20506-00","20516-00","20507-00","20517-00","20508-00","20528-00","20519-00","20518-00"
    ]
  },
  {
    "tip":"ORS 0.093\" Drilled Metering Orifice",
    "part_no": "21093-XX",
    "color": "Black",
    "csscolor": "tip-black",
    "tip_rate_30": "0.95",
    "tip_rate": "tip_rate_30*Math.sqrt(40.0/30.0)",
    "r_min": "tip_rate_30*Math.sqrt(10.0/30.0)",
    "r_max": "tip_rate_30*Math.sqrt(60.0/30.0)",
    "caps": [
      "20500-00","20501-00","20511-00","20502-00","20512-00","20503-00","20513-00","20504-00","20506-00","20516-00","20507-00","20517-00","20508-00","20528-00","20519-00","20518-00"
    ]
  },
  {
    "tip":"ORS 0.104\" Drilled Metering Orifice",
    "part_no": "21104-XX",
    "color": "Black",
    "csscolor": "tip-black",
    "tip_rate_30": "1.15",
    "tip_rate": "tip_rate_30*Math.sqrt(40.0/30.0)",
    "r_min": "tip_rate_30*Math.sqrt(10.0/30.0)",
    "r_max": "tip_rate_30*Math.sqrt(60.0/30.0)",
    "caps": [
      "20500-00","20501-00","20511-00","20502-00","20512-00","20503-00","20513-00","20504-00","20506-00","20516-00","20507-00","20517-00","20508-00","20528-00","20519-00","20518-00"
    ]
  },
  {
    "tip":"ORS 0.107\" Drilled Metering Orifice",
    "part_no": "21107-XX",
    "color": "Black",
    "csscolor": "tip-black",
    "tip_rate_30": "1.25",
    "tip_rate": "tip_rate_30*Math.sqrt(40.0/30.0)",
    "r_min": "tip_rate_30*Math.sqrt(10.0/30.0)",
    "r_max": "tip_rate_30*Math.sqrt(60.0/30.0)",
    "caps": [
      "20500-00","20501-00","20511-00","20502-00","20512-00","20503-00","20513-00","20504-00","20506-00","20516-00","20507-00","20517-00","20508-00","20528-00","20519-00","20518-00"
    ]
  },
  {
    "tip":"ORS 0.110\" Drilled Metering Orifice",
    "part_no": "21110-XX",
    "color": "Black",
    "csscolor": "tip-black",
    "tip_rate_30": "1.35",
    "tip_rate": "tip_rate_30*Math.sqrt(40.0/30.0)",
    "r_min": "tip_rate_30*Math.sqrt(10.0/30.0)",
    "r_max": "tip_rate_30*Math.sqrt(60.0/30.0)",
    "caps": [
      "20501-00","20511-00","20502-00","20512-00","20503-00","20513-00","20504-00","20507-00","20517-00","20508-00","20528-00","20519-00","20518-00"
    ]
  },
  {
    "tip":"ORS 0.113\" Drilled Metering Orifice",
    "part_no": "21113-XX",
    "color": "Black",
    "csscolor": "tip-black",
    "tip_rate_30": "1.40",
    "tip_rate": "tip_rate_30*Math.sqrt(40.0/30.0)",
    "r_min": "tip_rate_30*Math.sqrt(10.0/30.0)",
    "r_max": "tip_rate_30*Math.sqrt(60.0/30.0)",
    "caps": [
      "20501-00","20511-00","20502-00","20512-00","20503-00","20513-00","20504-00","20507-00","20517-00","20508-00","20528-00","20519-00","20518-00"
    ]
  },
  {
    "tip":"ORS 0.116\" Drilled Metering Orifice",
    "part_no": "21116-XX",
    "color": "Black",
    "csscolor": "tip-black",
    "tip_rate_30": "1.50",
    "tip_rate": "tip_rate_30*Math.sqrt(40.0/30.0)",
    "r_min": "tip_rate_30*Math.sqrt(10.0/30.0)",
    "r_max": "tip_rate_30*Math.sqrt(60.0/30.0)",
    "caps": [
      "20501-00","20511-00","20502-00","20512-00","20503-00","20513-00","20504-00","20507-00","20517-00","20508-00","20528-00","20519-00","20518-00"
    ]
  },
  {
    "tip":"ORS 0.120\" Drilled Metering Orifice",
    "part_no": "21120-XX",
    "color": "Black",
    "csscolor": "tip-black",
    "tip_rate_30": "1.55",
    "tip_rate": "tip_rate_30*Math.sqrt(40.0/30.0)",
    "r_min": "tip_rate_30*Math.sqrt(10.0/30.0)",
    "r_max": "tip_rate_30*Math.sqrt(60.0/30.0)",
    "caps": [
      "20501-00","20511-00","20502-00","20512-00","20503-00","20513-00","20504-00","20507-00","20517-00","20508-00","20528-00","20519-00","20518-00"
    ]
  },
  {
    "tip":"ORS 0.125\" Drilled Metering Orifice",
    "part_no": "21125-XX",
    "color": "Black",
    "csscolor": "tip-black",
    "tip_rate_30": "1.70",
    "tip_rate": "tip_rate_30*Math.sqrt(40.0/30.0)",
    "r_min": "tip_rate_30*Math.sqrt(10.0/30.0)",
    "r_max": "tip_rate_30*Math.sqrt(60.0/30.0)",
    "caps": [
      "20501-00","20511-00","20502-00","20512-00","20503-00","20513-00","20504-00","20507-00","20517-00","20508-00","20528-00","20519-00","20518-00"
    ]
  },
  {
    "tip":"ORS 0.128\" Drilled Metering Orifice",
    "part_no": "21128-XX",
    "color": "Black",
    "csscolor": "tip-black",
    "tip_rate_30": "1.75",
    "tip_rate": "tip_rate_30*Math.sqrt(40.0/30.0)",
    "r_min": "tip_rate_30*Math.sqrt(10.0/30.0)",
    "r_max": "tip_rate_30*Math.sqrt(60.0/30.0)",
    "caps": [
      "20501-00","20511-00","20502-00","20512-00","20503-00","20513-00","20504-00","20507-00","20517-00","20508-00","20528-00","20519-00","20518-00"
    ]
  },
  {
    "tip":"ORS 0.136\" Drilled Metering Orifice",
    "part_no": "21136-XX",
    "color": "Black",
    "csscolor": "tip-black",
    "tip_rate_30": "2.05",
    "tip_rate": "tip_rate_30*Math.sqrt(40.0/30.0)",
    "r_min": "tip_rate_30*Math.sqrt(10.0/30.0)",
    "r_max": "tip_rate_30*Math.sqrt(60.0/30.0)",
    "caps": [
      "20502-00","20512-00","20503-00","20513-00","20504-00","20519-00","20518-00"
    ]
  },
  {
    "tip":"ORS 0.140\" Drilled Metering Orifice",
    "part_no": "21140-XX",
    "color": "Black",
    "csscolor": "tip-black",
    "tip_rate_30": "2.20",
    "tip_rate": "tip_rate_30*Math.sqrt(40.0/30.0)",
    "r_min": "tip_rate_30*Math.sqrt(10.0/30.0)",
    "r_max": "tip_rate_30*Math.sqrt(60.0/30.0)",
    "caps": [
      "20502-00","20512-00","20503-00","20513-00","20504-00","20519-00","20518-00"
    ]
  },
  {
    "tip":"ORS 0.144\" Drilled Metering Orifice",
    "part_no": "21144-XX",
    "color": "Black",
    "csscolor": "tip-black",
    "tip_rate_30": "2.25",
    "tip_rate": "tip_rate_30*Math.sqrt(40.0/30.0)",
    "r_min": "tip_rate_30*Math.sqrt(10.0/30.0)",
    "r_max": "tip_rate_30*Math.sqrt(60.0/30.0)",
    "caps": [
      "20502-00","20512-00","20503-00","20513-00","20504-00","20519-00","20518-00"
    ]
  },
  {
    "tip":"ORS 0.147\" Drilled Metering Orifice",
    "part_no": "21147-XX",
    "color": "Black",
    "csscolor": "tip-black",
    "tip_rate_30": "2.35",
    "tip_rate": "tip_rate_30*Math.sqrt(40.0/30.0)",
    "r_min": "tip_rate_30*Math.sqrt(10.0/30.0)",
    "r_max": "tip_rate_30*Math.sqrt(60.0/30.0)",
    "caps": [
      "20502-00","20512-00","20503-00","20513-00","20504-00","20519-00","20518-00"
    ]
  },
  {
    "tip":"ORS 0.150\" Drilled Metering Orifice",
    "part_no": "21150-XX",
    "color": "Black",
    "csscolor": "tip-black",
    "tip_rate_30": "2.50",
    "tip_rate": "tip_rate_30*Math.sqrt(40.0/30.0)",
    "r_min": "tip_rate_30*Math.sqrt(10.0/30.0)",
    "r_max": "tip_rate_30*Math.sqrt(60.0/30.0)",
    "caps": [
      "20502-00","20512-00","20503-00","20513-00","20504-00","20519-00","20518-00"
    ]
  },
  {
    "tip":"ORS 0.152\" Drilled Metering Orifice",
    "part_no": "21152-XX",
    "color": "Black",
    "csscolor": "tip-black",
    "tip_rate_30": "2.60",
    "tip_rate": "tip_rate_30*Math.sqrt(40.0/30.0)",
    "r_min": "tip_rate_30*Math.sqrt(10.0/30.0)",
    "r_max": "tip_rate_30*Math.sqrt(60.0/30.0)",
    "caps": [
      "20502-00","20512-00","20503-00","20513-00","20504-00","20519-00","20518-00"
    ]
  },
  {
    "tip":"ORS 0.156\" Drilled Metering Orifice",
    "part_no": "21156-XX",
    "color": "Black",
    "csscolor": "tip-black",
    "tip_rate_30": "2.70",
    "tip_rate": "tip_rate_30*Math.sqrt(40.0/30.0)",
    "r_min": "tip_rate_30*Math.sqrt(10.0/30.0)",
    "r_max": "tip_rate_30*Math.sqrt(60.0/30.0)",
    "caps": [
      "20503-00","20513-00","20504-00"
    ]
  },
  {
    "tip":"ORS 0.161\" Drilled Metering Orifice",
    "part_no": "21161-XX",
    "color": "Black",
    "csscolor": "tip-black",
    "tip_rate_30": "2.85",
    "tip_rate": "tip_rate_30*Math.sqrt(40.0/30.0)",
    "r_min": "tip_rate_30*Math.sqrt(10.0/30.0)",
    "r_max": "tip_rate_30*Math.sqrt(60.0/30.0)",
    "caps": [
      "20503-00","20513-00","20504-00"
    ]
  },
  {
    "tip":"ORS 0.166\" Drilled Metering Orifice",
    "part_no": "21166-XX",
    "color": "Black",
    "csscolor": "tip-black",
    "tip_rate_30": "2.95",
    "tip_rate": "tip_rate_30*Math.sqrt(40.0/30.0)",
    "r_min": "tip_rate_30*Math.sqrt(10.0/30.0)",
    "r_max": "tip_rate_30*Math.sqrt(60.0/30.0)",
    "caps": [
      "20503-00","20513-00","20504-00"
    ]
  },
  {
    "tip":"ORS 0.171\" Drilled Metering Orifice",
    "part_no": "21171-XX",
    "color": "Black",
    "csscolor": "tip-black",
    "tip_rate_30": "3.25",
    "tip_rate": "tip_rate_30*Math.sqrt(40.0/30.0)",
    "r_min": "tip_rate_30*Math.sqrt(10.0/30.0)",
    "r_max": "tip_rate_30*Math.sqrt(60.0/30.0)",
    "caps": [
      "20503-00","20513-00","20504-00"
    ]
  },
  {
    "tip":"ORS 0.177\" Drilled Metering Orifice",
    "part_no": "21177-XX",
    "color": "Black",
    "csscolor": "tip-black",
    "tip_rate_30": "3.45",
    "tip_rate": "tip_rate_30*Math.sqrt(40.0/30.0)",
    "r_min": "tip_rate_30*Math.sqrt(10.0/30.0)",
    "r_max": "tip_rate_30*Math.sqrt(60.0/30.0)",
    "caps": [
      "20503-00","20513-00","20504-00"
    ]
  },
  {
    "tip":"ORS 0.182\" Drilled Metering Orifice",
    "part_no": "21182-XX",
    "color": "Black",
    "csscolor": "tip-black",
    "tip_rate_30": "3.60",
    "tip_rate": "tip_rate_30*Math.sqrt(40.0/30.0)",
    "r_min": "tip_rate_30*Math.sqrt(10.0/30.0)",
    "r_max": "tip_rate_30*Math.sqrt(60.0/30.0)",
    "caps": [
      "20503-00","20513-00","20504-00"
    ]
  },
  {
    "tip":"ORS 0.187\" Drilled Metering Orifice",
    "part_no": "21187-XX",
    "color": "Black",
    "csscolor": "tip-black",
    "tip_rate_30": "3.80",
    "tip_rate": "tip_rate_30*Math.sqrt(40.0/30.0)",
    "r_min": "tip_rate_30*Math.sqrt(10.0/30.0)",
    "r_max": "tip_rate_30*Math.sqrt(60.0/30.0)",
    "caps": [
      "20503-00","20513-00","20504-00"
    ]
  },
  {
    "tip":"ORS 0.196\" Drilled Metering Orifice",
    "part_no": "21196-XX",
    "color": "Black",
    "csscolor": "tip-black",
    "tip_rate_30": "4.25",
    "tip_rate": "tip_rate_30*Math.sqrt(40.0/30.0)",
    "r_min": "tip_rate_30*Math.sqrt(10.0/30.0)",
    "r_max": "tip_rate_30*Math.sqrt(60.0/30.0)",
    "caps": [
      "20503-00","20513-00","20504-00"
    ]
  },
  {
    "tip":"ORS 0.205\" Drilled Metering Orifice",
    "part_no": "21205-XX",
    "color": "Black",
    "csscolor": "tip-black",
    "tip_rate_30": "4.60",
    "tip_rate": "tip_rate_30*Math.sqrt(40.0/30.0)",
    "r_min": "tip_rate_30*Math.sqrt(10.0/30.0)",
    "r_max": "tip_rate_30*Math.sqrt(60.0/30.0)",
    "caps": [
      "20503-00","20513-00","20504-00"
    ]
  },
  {
    "tip":"ORS 0.213\" Drilled Metering Orifice",
    "part_no": "21213-XX",
    "color": "Black",
    "csscolor": "tip-black",
    "tip_rate_30": "4.95",
    "tip_rate": "tip_rate_30*Math.sqrt(40.0/30.0)",
    "r_min": "tip_rate_30*Math.sqrt(10.0/30.0)",
    "r_max": "tip_rate_30*Math.sqrt(60.0/30.0)",
    "caps": [
      "20500-00","20501-00","20511-00","20502-00","20512-00","20503-00","20513-00","20504-00","20506-00","20516-00","20507-00","20517-00","20508-00","20528-00","20519-00","20518-00"
    ]
  },
  {
    "tip":"ORS 0.218\" Drilled Metering Orifice",
    "part_no": "21218-XX",
    "color": "Black",
    "csscolor": "tip-black",
    "tip_rate_30": "5.20",
    "tip_rate": "tip_rate_30*Math.sqrt(40.0/30.0)",
    "r_min": "tip_rate_30*Math.sqrt(10.0/30.0)",
    "r_max": "tip_rate_30*Math.sqrt(60.0/30.0)",
    "caps": [
      "20503-00","20513-00","20504-00"
    ]
  },
  {
    "tip":"ORS 0.234\" Drilled Metering Orifice",
    "part_no": "21234-XX",
    "color": "Black",
    "csscolor": "tip-black",
    "tip_rate_30": "6.0",
    "tip_rate": "tip_rate_30*Math.sqrt(40.0/30.0)",
    "r_min": "tip_rate_30*Math.sqrt(10.0/30.0)",
    "r_max": "tip_rate_30*Math.sqrt(60.0/30.0)",
    "caps": [
      "20503-00","20513-00","20504-00"
    ]
  },
  {
    "tip":"ORS 0.250\" Drilled Metering Orifice",
    "part_no": "21250-XX",
    "color": "Black",
    "csscolor": "tip-black",
    "tip_rate_30": "6.90",
    "tip_rate": "tip_rate_30*Math.sqrt(40.0/30.0)",
    "r_min": "tip_rate_30*Math.sqrt(10.0/30.0)",
    "r_max": "tip_rate_30*Math.sqrt(60.0/30.0)",
    "caps": [
      "20503-00","20513-00","20504-00"
    ]
  }
];

var cap_descriptions = {
  "20500-00": "1/4\" Hosebarb, Straight",
  "20501-00": "3/8\" Hosebarb, Straight",
  "20511-00": "3/8\" Hosebarb, 90",
  "20502-00": "1/2\" Hosebarb, Straight",
  "20512-00": "1/2\" Hosebarb, 90",
  "20503-00": "3/4\" Hosebarb, Straight",
  "20504-00": "1\" Hosebarb, Straight",
  "20513-00": "3/4\" Hosebarb, 90",
  "20514-00": "5/16\" Hosebarb, 90",
  "20506-00": "1/4\" Push-in tube, Straight",
  "20516-00": "1/4\" Push-in tube, 90",
  "20507-00": "3/8\" Push-in tube, Straight",
  "20517-00": "3/8\" Push-in tube, 90",
  "20508-00": "5/16\" Push-in tube, Straight",
  "20528-00": "5/16\" Push-in tube, 90",
  "20518-00": "1/4\" NPT, 90",
  "20519-00": "1/4\" NPT, Straight",
  
  "40420-05" : "1/8\" Hosebarb",
  "40422-05" : "1/4\" Hosebarb",
  "40424-05" : "3/8\" Hosebarb",
  "40426-05" : "1/2\" Hosebarb",
  "40432-047" : "2-hole Fert cap - S",
  "40432-086" : "2-hole Fert cap - M",
  "40432-104" : "2-hole Fert cap -L",
  "40433-047" : "3-hole Fert cap -S",
  "40433-067" : "3-hole Fert cap - M",
  "40433-104" : "3-hole Fert cap -L",
  "40435-05" : "1/4\" Push-in tube",
  "40436-05" : "3/8\" Push-in tube",
  "40437-05" : "5/16\" Push-in tube",
  "40273-05" : "1/4\" NPTF",
  "40274-05" : "1/4\" NPTF - 45°",
  "40277-05" : "1/8\" NPTF"
};

// Initialize unique tip list
var tips = [];
// Initialize extra info in tips
for (var tip = 0; tip < tips_table.length; ++tip) {
    tips.push(tips_table[tip]["tip"].substring(2));
}

tips = tips.sort();
tips = array_unique(tips);

//----------------------------------------------------------------------------------------
//----------------------------------------------------------------------------------------

function vmd_to_css (chart_item)
{
    if (chart_item.highlight)
        return 'results-table-selected-text';
    return '';
}

function vmd_class_to_css (chart_item)
{        
    var classification = vmd_to_classification(chart_item);
    
    if (classification == 'XF')  return 'vmd-extremely_fine';
    else if (classification == 'VF')  return 'vmd-very_fine';
    else if (classification == 'F')  return 'vmd-fine';
    else if (classification == 'M')  return 'vmd-medium';
    else if (classification == 'C')  return 'vmd-coarse';
    else if (classification == 'VC')  return 'vmd-very_coarse';
    else if (classification == 'XC')  return 'vmd-extremely_coarse';
    else if (classification == 'UC')  return 'vmd-ultra_coarse';

}

function vmd_to_classification (chart_item)
{
    var vmd_class;
    var dv01_class;

    if (chart_item.classification == 0) {
        if (chart_item.vmd < 50)          vmd_class = 0;
        else if (chart_item.vmd <= 113)   vmd_class = 1;
        else if (chart_item.vmd <= 216)   vmd_class = 2;
        else if (chart_item.vmd <= 271)   vmd_class = 3;
        else if (chart_item.vmd <= 391)   vmd_class = 4;
        else if (chart_item.vmd <= 450)   vmd_class = 5;
        else if (chart_item.vmd <= 622)   vmd_class = 6;
        else                    vmd_class = 7;

        if (chart_item.dv01 < 25)          dv01_class = 0;
        else if (chart_item.dv01 <= 62)    dv01_class = 1;
        else if (chart_item.dv01 <= 98)    dv01_class = 2;
        else if (chart_item.dv01 <= 116)   dv01_class = 3;
        else if (chart_item.dv01 <= 181)   dv01_class = 4;
        else if (chart_item.dv01 <= 218)   dv01_class = 5;
        else if (chart_item.dv01 <= 300)   dv01_class = 6;
        else                    dv01_class = 7;
        
    } else {
        if (chart_item.vmd < 50)          vmd_class = 0;
        else if (chart_item.vmd <= 112)   vmd_class = 1;
        else if (chart_item.vmd <= 163)   vmd_class = 2;
        else if (chart_item.vmd <= 235)   vmd_class = 3;
        else if (chart_item.vmd <= 355)   vmd_class = 4;
        else if (chart_item.vmd <= 376)   vmd_class = 5;
        else if (chart_item.vmd <= 479)   vmd_class = 6;
        else                    vmd_class = 7;

        if (chart_item.dv01 < 25)          dv01_class = 0;
        else if (chart_item.dv01 <= 45)    dv01_class = 1;
        else if (chart_item.dv01 <= 71)    dv01_class = 2;
        else if (chart_item.dv01 <= 87)    dv01_class = 3;
        else if (chart_item.dv01 <= 105)   dv01_class = 4;
        else if (chart_item.dv01 <= 112)   dv01_class = 5;
        else if (chart_item.dv01 <= 140)   dv01_class = 6;
        else                    dv01_class = 7;
    }

    var classification = Math.min(vmd_class, dv01_class);
    
    if (classification == 0)  return 'XF';
    else if (classification == 1)  return 'VF';
    else if (classification == 2)  return 'F';
    else if (classification == 3)  return 'M';
    else if (classification == 4)  return 'C';
    else if (classification == 5)  return 'VC';
    else if (classification == 6)  return 'XC';
    else if (classification == 7)  return 'UC';
    return "?";
}

//----------------------------------------------------------------------------------------
//----------------------------------------------------------------------------------------

function cv_ac_from_string(cv_ac)
{
  if (cv_ac == "Capstan PinPoint")                    return 0.245;
  if (cv_ac == "Capstan PinPoint (24 series valve)")  return 0.380;
  if (cv_ac == "Capstan Sharpshooter")                return 0.245;
  if (cv_ac == "Case AimCommand")                     return 0.245;
  if (cv_ac == "Case AimCommand FLEX")                return 0.245;
  if (cv_ac == "Case AimCommand FLEX HD")             return 0.245;
  if (cv_ac == "Case AimCommand PRO")                 return 0.245;
  if (cv_ac == "John Deere ExactApply")               return 0.322;
  if (cv_ac == "Raven Hawkeye")                       return 0.245;
  return null;
}

//----------------------------------------------------------------------------------------
//----------------------------------------------------------------------------------------

function pt_from_vmd (tip, vmd)
{
    var p_min = 20.0;
    var p_max = 70.0;

    var pt_b = 0.0;

    for (var i = 0; i < 20; ++i) {
        pt_b = p_min;
        var vmd_p_min = eval(tip["vmd_b"]);

        pt_b = p_max;
        var vmd_p_max = eval(tip["vmd_b"]);

        pt_b = (p_max + p_min)*0.5;
        var vmd_p_mid = eval(tip["vmd_b"]);

        if ((vmd >= vmd_p_min && vmd <= vmd_p_mid) || (vmd >= vmd_p_mid && vmd <= vmd_p_min) ) {
            p_max = pt_b;
        } else if ( (vmd >= vmd_p_mid && vmd <= vmd_p_max) || (vmd >= vmd_p_max && vmd <= vmd_p_mid) ) {
            p_min = pt_b;
        } else {
            return 0.0;
        }
    }

    // console.log("Look at me: " + tip["tip"] + " should get " + pt_b + "psi");
    // for (var i = 20; i < 200; i+=5) {
    //     pt_b = i;
    //     var vmd_p_max = eval(tip["vmd_b"]);
    //
    //     console.log(pt_b + " " + vmd_p_max);
    // }

    return pt_b;
}

//----------------------------------------------------------------------------------------
//----------------------------------------------------------------------------------------

// A - Application (gal/acre)
// S - Average Sprayer Speed (mph)
// N - Nozzle Spacing (in)
// An - Spray Tip Angle (80 or 110)
// T – Target Droplet Size

function get_standard_tips (A, S, N, An, T_string, speed_conv, press_conv, press_decimals)
{
    
    // Math to figure out calculated rate
    var R = (A * S * N) / 5940.0

    // Copy all of the tips_table into a new array
    var filtered = tips_table.slice();
    var left_over = [];

    //
    // 1. Use spray tip angle to reduce available tips
    //

    filtered = filtered.filter(function (el) {
        return el["ang"] == An;
    });

    //
    // 2. Using calculated rate (R) find tips fit within this range for min and max
    // flows (2 new columns added to spreadsheet)
    //

    filtered = filtered.filter(function (el) {
        return R >= el["r_min"] && R <= el["r_max"];
    });


    if (!isNaN(T_string)) {
        T = parseFloat(T_string);
        
        //
        // 3. Using Droplet Size input, compare to calculated VMD (using VMD formula) for
        // all tips above to pick tips within +/-25 of input value.  If not at least 4 tips
        // shown, then increase +/- repeatedly to include more tips.
        //
        // Alternative would be to do a percentage of input value. Say start within +/- 5%
        // and increase by 5 from there
        //

        filtered = filtered.sort(function (ela, elb) {

            var pt = ela["pt"];
            var VMD_a = eval(ela["vmd_s"]);

            var pt = elb["pt"];
            var VMD_b = eval(elb["vmd_s"]);

            var diff_a = Math.abs(T - VMD_a);
            var diff_b = Math.abs(T - VMD_b);

            if (diff_a < diff_b) {
                return -1;
            } else if (diff_a > diff_b) {
                return 1;
            } else {
                return 0;
            }
        });

        // Truncate to 5 items
        left_over = filtered.slice(5);
        filtered = filtered.slice(0,5);

    } else if (T_string && T_string!="SEE ALL"){
      // Is string
      var s = T_string.split('(');
      if (s.length > 1)
        s = s[1].split(')')[0];
      else
        s = T_string;
      
      // Build the charts for the tips so we can count classification
      build_charts_standard (filtered, A, S, N, speed_conv, press_conv, press_decimals);      

      filtered = filtered.filter(function (el) {
        var count = 0;
        for(var i = 0; i < el.chart.length; ++i){
            if(vmd_to_classification(el.chart[i]) == s)
                count++;
        }
        return count > 0;
      });

      filtered = filtered.sort(function (ela, elb) {
          var count_a = 0;
          for(var i = 0; i < ela.chart.length; ++i){
              if(vmd_to_classification(ela.chart[i]) == s)
                  count_a++;
          }

          var count_b = 0;
          for(var i = 0; i < elb.chart.length; ++i){
              if(vmd_to_classification(elb.chart[i]) == s)
                  count_b++;
          }
          
          if (count_b < count_a) {
              return -1;
          } else if (count_b > count_a) {
              return 1;
          } else {
              return 0;
          }
      });

      // Truncate to 5 items
      left_over = filtered.slice(5);
      filtered = filtered.slice(0,5);

    } else {
        //
        // 4. If no droplet size is inputted, then show all tips
        //

        // Do nothing, array of tips stays the same
    }

    // 5. Sorting
    filtered = sort_tips(filtered);
    left_over = sort_tips(left_over);

    return [filtered, left_over];
}

// A - Application (gal/acre)
// S - Average Sprayer Speed (mph)
// N - Nozzle Spacing (in)
// An - Spray Tip Angle (80 or 110)
// T – Target Droplet Size
// cv_ac – CV

function get_pulsed_tips (A, S, N, An, T_string, cv_ac_string, speed_conv, press_conv, press_decimals)
{
    var cv_ac = cv_ac_from_string(cv_ac_string);
    
    // Math to figure out calculated rate
    var R = (A * S * N) / 5940.0

    // Copy all of the tips_table into a new array
    var filtered = tips_table.slice();
    var left_over = [];

    //
    // 1. Use spray tip angle to reduce available tips
    //

    filtered = filtered.filter(function (el) {
        return el["ang"] == An;
    });

    //
    // 2. Using calculated rate (R) find tips that fit within this range for min and max
    // flows for blended pulse (2 new columns added to spreadsheet)
    //

    filtered = filtered.filter(function (el) {
        var cv_eff = 1.0 / (Math.sqrt( 1.0/Math.pow(el["cv_tip"],2.0) + 1.0/Math.pow(cv_ac,2.0) ));
        var r_min_b	= cv_eff * Math.sqrt(25.0) * 0.25;
        var r_max_b	= cv_eff * Math.sqrt(80.0) * 0.8;
        return R >= r_min_b && R <= r_max_b;
    });

    if (!isNaN(T_string)) {
        T = parseFloat(T_string);

        //
        // Speed Fix
        //

        filtered = filtered.filter(function (el) {

            var pg = pt_from_vmd (el, T);
            if (pg == 0.0)
                return false;

            var cv_eff = 1.0 / (Math.sqrt( 1.0/Math.pow(el["cv_tip"],2.0) + 1.0/Math.pow(cv_ac,2.0) ));
            var R2 = cv_eff * Math.sqrt(pg);

            var Smax = (R2 * 5940)/(A*N);
            var speed_max = Smax*speed_conv;

//             console.log(el["tip"] + ' = ' + speed_max + " S=" + S + " (" + speed_max*0.4 + " - " + speed_max*1.1 + ")");

            return S >= (speed_max*0.4) && S <= (speed_max*1.1);
        });

        //
        // 3. Using Droplet Size input, compare to calculated VMD (using VMD formula) for
        // all tips above to pick tips within +/-25 of input value.  If not at least 4 tips
        // shown, then increase +/- repeatedly to include more tips.
        //
        // Alternative would be to do a percentage of input value. Say start within +/- 5%
        // and increase by 5 from there
        //

        filtered = filtered.sort(function (ela, elb) {
            var pwm_fac = 1.0 + Math.exp(ela["tip_rate"]/cv_ac,2.0) / 40.0;
            var pg = ela["pg"];
            var pt_b = eval(ela["pt_b"]);
            var VMD_a = eval(ela["vmd_b"]);

            var pwm_fac = 1.0 + Math.exp(elb["tip_rate"]/cv_ac,2.0) / 40.0;
            var pg = elb["pg"];
            var pt_b = eval(elb["pt_b"]);
            var VMD_b = eval(elb["vmd_b"]);

            var diff_a = Math.abs(T - VMD_a);
            var diff_b = Math.abs(T - VMD_b);

            if (diff_a < diff_b) {
                return -1;
            } else if (diff_a > diff_b) {
                return 1;
            } else {
                return 0;
            }
        });

        // Truncate to 8 items
        filtered = filtered.slice(0,8);

    } else if (T_string && T_string!="SEE ALL"){
      // Is string
      var s = T_string.split('(');
      if (s.length > 1)
        s = s[1].split(')')[0];
      else
        s = T_string;
      
      // Build the charts for the tips so we can count classification
      build_charts_pulsed (filtered, A, S, N, null, cv_ac_string, speed_conv, press_conv, press_decimals);      

      filtered = filtered.filter(function (el) {
        var count = 0;
        for(var i = 0; i < el.chart.length; ++i){
            if(vmd_to_classification(el.chart[i]) == s)
                count++;
        }
        return count > 0;
      });

      filtered = filtered.filter(function (el) {        
        min_duty_cycle = el.chart[el.chart.length-1].duty;
        if (min_duty_cycle == ">100")
          min_duty_cycle = 100.0;
        max_duty_cycle = el.chart[0].duty;
        if (max_duty_cycle == ">100")
          max_duty_cycle = 100.0;

        return (65 >= min_duty_cycle) && (max_duty_cycle >= 65);
      });

      filtered = filtered.sort(function (ela, elb) {
          var count_a = 0;
          for(var i = 0; i < ela.chart.length; ++i){
              if(vmd_to_classification(ela.chart[i]) == s)
                  count_a++;
          }

          var count_b = 0;
          for(var i = 0; i < elb.chart.length; ++i){
              if(vmd_to_classification(elb.chart[i]) == s)
                  count_b++;
          }
          
          if (count_b < count_a) {
              return -1;
          } else if (count_b > count_a) {
              return 1;
          } else {
              return 0;
          }
      });

      // Truncate to 8 items
      //filtered = filtered.slice(0,8);

    } else {
        //
        // 4. If no droplet size is inputted, then show all tips
        //

        // Do nothing, array of tips stays the same
    }

    // 5. Sorting
    filtered = sort_tips(filtered);

    return [filtered, left_over];
}

function get_specific_tips (N)
{

    // Copy all of the tips_table into a new array
    var filtered = tips_table.slice();
    var left_over = [];

    filtered = filtered.filter(function (el) {
        return el["tip"].substring(2) == N;
    });

    filtered = sort_tips(filtered);
    left_over = sort_tips(left_over);

    return [filtered, left_over];
}

//----------------------------------------------------------------------------------------
//----------------------------------------------------------------------------------------

function build_charts_standard (tips, A, S, N, speed_conv, press_conv, press_decimals)
{

    for (var r = 0; r < tips.length; ++r) {

        // Empty the current chart
        tips[r].chart = [];

        // Get style and size
        var style = tips[r]["tip"].substring(0,2);
        var size = tips[r]["tip"].substring(2);

        var min_pressure = 0;
        var max_pressure = 0;

        if (style == "ER") {
            min_pressure = 20;
            max_pressure = 100;
        } else {
            min_pressure = 25;
            max_pressure = 100;
        }

        // For each pressure
        for (var pt = min_pressure; pt <= max_pressure; pt += 5) {

            var R2 = Math.sqrt(pt/tips[r]["pt"]) * tips[r]["tip_rate"];
            var SS = (R2 * 5940)/(A*N);

            var chart = {};
            chart.speed = format_number(SS*speed_conv);
            chart.pressure = (pt*press_conv).toFixed(press_decimals);
            chart.vmd = (style == "UR") ? "---" : Math.round(eval(tips[r]["vmd_s"]));
            chart.dv01 = (style == "UR") ? "---" : Math.round(eval(tips[r]["Dv01_s"]));
            chart.lt141 = (style == "UR") ? "---" : Math.round(eval(tips[r]["141_s"]));
            chart.lt200 = (style == "UR") ? "---" : Math.round(eval(tips[r]["200_s"]));
            chart.lt600 = (style == "UR") ? "---" : Math.round(eval(tips[r]["600_s"]));
            chart.highlight = false;
            chart.csscolor = tips[r].csscolor;
            chart.classification = tips[r].classification;

            tips[r].chart.push(chart);
        }

        // Calculate target
        var R = (A * S * N) / 5940.0
        var pt = tips[r]["pt"] * Math.pow(R/tips[r]["tip_rate"], 2.0);
        var R2 = Math.sqrt(pt/tips[r]["pt"]) * tips[r]["tip_rate"];
        var S = (R2 * 5940)/(A*N);

        var chart = {};
        chart.speed = format_number(S*speed_conv);
        chart.pressure = (pt*press_conv).toFixed(press_decimals);
        chart.vmd = (style == "UR") ? "---" : Math.round(eval(tips[r]["vmd_s"]));
        chart.dv01 = (style == "UR") ? "---" : Math.round(eval(tips[r]["Dv01_s"]));
        chart.lt141 = (style == "UR") ? "---" : Math.round(eval(tips[r]["141_s"]));
        chart.lt200 = (style == "UR") ? "---" : Math.round(eval(tips[r]["200_s"]));
        chart.lt600 = (style == "UR") ? "---" : Math.round(eval(tips[r]["600_s"]));
        chart.highlight = true;
        chart.csscolor = tips[r].csscolor;
        chart.classification = tips[r].classification;

        tips[r].chart.push(chart);

        // Sort final results
        tips[r].chart = tips[r].chart.sort(function (ela, elb) {
            if (parseFloat(ela.pressure) < parseFloat(elb.pressure)) {
                return -1;
            } else if (parseFloat(ela.pressure) > parseFloat(elb.pressure)) {
                return 1;
            } else {
                return 0;
            }
        });
    }
}

function build_charts_pulsed (tips, A, S, N, T, cv_ac_string, speed_conv, press_conv, press_decimals)
{
    var cv_ac = cv_ac_from_string(cv_ac_string);

    for (var r = 0; r < tips.length; ++r) {

        // Empty the current chart
        tips[r].chart = [];

        // Get style and size
        var style = tips[r]["tip"].substring(0,2);
        var size = tips[r]["tip"].substring(2);

        var min_pressure = 0;
        var max_pressure = 0;

        if (style == "ER") {
            min_pressure = 20;
            max_pressure = 90;
        } else {
            min_pressure = 25;
            max_pressure = 90;
        }

        for (var pg = min_pressure; pg <= max_pressure; pg += 5) {

            var cv_eff = 1.0 / (Math.sqrt( 1.0/Math.pow(tips[r]["cv_tip"],2.0) + 1.0/Math.pow(cv_ac,2.0) ));
            var orf_eff = cv_eff * Math.sqrt(40.0);

            var R2max = Math.sqrt(pg/40.0)*orf_eff;
            var Smax = (R2max * 5940)/(A*N);

            //var R2min = Math.sqrt(pg/tips[r]["pt"]) * tips[r]["r_min_b"];
            var Smin = Smax * 0.25; //(R2min * 5940)/(A*N);

            var chart = {};
            chart.speed_max = format_number(Smax*speed_conv); //S;
            chart.speed_min = format_number(Smin*speed_conv); //S;
            chart.duty = Math.round((S*speed_conv/chart.speed_max)*100.0);
            if (chart.duty > 100) {
                chart.duty = ">100";
            }

            chart.pressure = (pg*press_conv).toFixed(press_decimals);

            var rb = cv_eff * Math.sqrt(pg);
            var pt_b = Math.pow(rb/tips[r]["cv_tip"], 2.0);
            
            chart.vmd = (style == "UR") ? "---" : Math.round(eval(tips[r]["vmd_b"]));
            chart.dv01 = (style == "UR") ? "---" : Math.round(eval(tips[r]["Dv01_b"]));
            chart.lt141 = (style == "UR") ? "---" : Math.round(eval(tips[r]["141_b"]));
            chart.lt600 = (style == "UR") ? "---" : Math.round(eval(tips[r]["600_b"]));
            chart.csscolor = tips[r].csscolor;
            chart.classification = tips[r].classification;

            chart.highlight = false;

            tips[r].chart.push(chart);
        }

        // For each calculated result, find the closest vmd and highlight it
        var closest_vmd = 0;

        if (T && !isNaN(parseFloat(T))) {
          for (var i = 1; i < tips[r].chart.length; ++i) {
              if (Math.abs(tips[r].chart[i].vmd - T) < Math.abs(tips[r].chart[closest_vmd].vmd - T)) {
                  closest_vmd = i;
              }
          }
          
          tips[r].chart[closest_vmd].highlight = true;
        }


    }
}

function build_charts_specific_standard (tips, A, S, N, speed_conv, press_conv, rate_conv, press_decimals)
{

    // Calculate with constant speed
    for (var r = 0; r < tips.length; ++r) {

        // Empty the current chart
        tips[r].chart_rate = [];

        // Get style and size
        var style = tips[r]["tip"].substring(0,2);
        var size = tips[r]["tip"].substring(2);

        var min_pressure = 0;
        var max_pressure = 0;

        if (style == "ER") {
            min_pressure = 20;
            max_pressure = 100;
        } else {
            min_pressure = 25;
            max_pressure = 100;
        }

        // For each pressure
        for (var pt = min_pressure; pt <= max_pressure; pt += 5) {
            //var S = (R * 5940)/(A*N)

            var R2 = Math.sqrt(pt/tips[r]["pt"]) * tips[r]["tip_rate"];
            var SS = (R2 * 5940)/(A*N);

            var chart = {};
            chart.speed = format_number(SS*speed_conv);
            chart.pressure = (pt*press_conv).toFixed(press_decimals);
            chart.application_rate = (A*rate_conv).toFixed(1);
            chart.vmd = (style == "UR") ? "---" : Math.round(eval(tips[r]["vmd_s"]));
            chart.dv01 = (style == "UR") ? "---" : Math.round(eval(tips[r]["Dv01_s"]));
            chart.lt141 = (style == "UR") ? "---" : Math.round(eval(tips[r]["141_s"]));
            chart.lt200 = (style == "UR") ? "---" : Math.round(eval(tips[r]["200_s"]));
            chart.lt600 = (style == "UR") ? "---" : Math.round(eval(tips[r]["600_s"]));
            chart.csscolor = tips[r].csscolor;
            chart.classification = tips[r].classification;

            tips[r].chart_rate.push(chart);
        }

    }

    // Calculate with constant application rate
    for (var r = 0; r < tips.length; ++r) {

        // Empty the current chart
        tips[r].chart_speed = [];

        // Get style and size
        var style = tips[r]["tip"].substring(0,2);
        var size = tips[r]["tip"].substring(2);

        var min_pressure = 0;
        var max_pressure = 0;

        if (style == "ER") {
            min_pressure = 20;
            max_pressure = 100;
        } else {
            min_pressure = 25;
            max_pressure = 100;
        }

        // For each pressure
        for (var pt = min_pressure; pt <= max_pressure; pt += 5) {
            //var S = (R * 5940)/(A*N)

            var A40 = tips[r]["tip_rate"]*5940/(S*N);
            var A2 = A40 * Math.sqrt(pt/tips[r]["pt"]);

            var chart = {};
            chart.speed = format_number(S*speed_conv);
            chart.pressure = (pt*press_conv).toFixed(press_decimals);
            chart.application_rate = (A2*rate_conv).toFixed(1);
            chart.vmd = (style == "UR") ? "---" : Math.round(eval(tips[r]["vmd_s"]));
            chart.dv01 = (style == "UR") ? "---" : Math.round(eval(tips[r]["Dv01_s"]));
            chart.lt141 = (style == "UR") ? "---" : Math.round(eval(tips[r]["141_s"]));
            chart.lt200 = (style == "UR") ? "---" : Math.round(eval(tips[r]["200_s"]));
            chart.lt600 = (style == "UR") ? "---" : Math.round(eval(tips[r]["600_s"]));
            chart.csscolor = tips[r].csscolor;
            chart.classification = tips[r].classification;

            tips[r].chart_speed.push(chart);
        }

    }


    // Combine chart
    for (var r = 0; r < tips.length; ++r) {

        // Empty the current chart
        tips[r].chart_combined = [];

        for (var i = 0; i < tips[r].chart_speed.length; ++i) {
            var chart = {};

            chart.speed_cs = tips[r].chart_speed[i].speed;
            chart.application_rate_cs = tips[r].chart_speed[i].application_rate;

            chart.speed_cr = tips[r].chart_rate[i].speed;
            chart.application_rate_cr = tips[r].chart_rate[i].application_rate;

            chart.pressure = tips[r].chart_speed[i].pressure;
            chart.vmd = (style == "UR") ? "---" : tips[r].chart_speed[i].vmd;
            chart.dv01 = (style == "UR") ? "---" : tips[r].chart_speed[i].dv01;
            chart.lt141 = (style == "UR") ? "---" : tips[r].chart_speed[i].lt141;
            chart.lt200 = (style == "UR") ? "---" : tips[r].chart_speed[i].lt200;
            chart.lt600 = (style == "UR") ? "---" : tips[r].chart_speed[i].lt600;
            chart.csscolor = tips[r].csscolor;
            chart.classification = tips[r].classification;

            tips[r].chart_combined.push(chart);
        }
    }
}

function build_charts_specific_pulsed (tips, A1, A2, N, cv_ac_string, speed_conv, press_conv, press_decimals)
{
    var cv_ac = cv_ac_from_string(cv_ac_string);

    // Calculate with constant speed
    for (var r = 0; r < tips.length; ++r) {

        // Empty the current chart
        tips[r].chart_rate = [];

        // Get style and size
        var style = tips[r]["tip"].substring(0,2);
        var size = tips[r]["tip"].substring(2);

        var min_pressure = 0;
        var max_pressure = 0;

        if (style == "ER") {
            min_pressure = 20;
            max_pressure = 90;
        } else {
            min_pressure = 25;
            max_pressure = 90;
        }

        // For each pressure
        for (var pg = min_pressure; pg <= max_pressure; pg += 5) {

            var cv_eff = 1.0 / (Math.sqrt( 1.0/Math.pow(tips[r]["cv_tip"],2.0) + 1.0/Math.pow(cv_ac,2.0) ));
            var orf_eff = cv_eff * Math.sqrt(40.0);

            var R2max = Math.sqrt(pg/40)*orf_eff
            var S1_100 = (R2max * 5940)/(A1*N);
            var S1_25 = S1_100 * 0.25; //(R2min * 5940)/(A1*N);
            var S1_50 = S1_100 * 0.50; //(R2min * 5940)/(A1*N);
            var S1_75 = S1_100 * 0.75; //(R2min * 5940)/(A1*N);

            var R2max = Math.sqrt(pg/40)*orf_eff
            var S2_100 = (R2max * 5940)/(A2*N);
            var S2_25 = S2_100 * 0.25; //(R2min * 5940)/(A1*N);
            var S2_50 = S2_100 * 0.50; //(R2min * 5940)/(A1*N);
            var S2_75 = S2_100 * 0.75; //(R2min * 5940)/(A1*N);

            var chart = {};
            chart.speed_25_1 = format_number(S1_25 * speed_conv);
            chart.speed_50_1 = format_number(S1_50 * speed_conv);
            chart.speed_75_1 = format_number(S1_75 * speed_conv);
            chart.speed_100_1 = format_number(S1_100 * speed_conv);

            chart.speed_25_2 = format_number(S2_25 * speed_conv);
            chart.speed_50_2 = format_number(S2_50 * speed_conv);
            chart.speed_75_2 = format_number(S2_75 * speed_conv);
            chart.speed_100_2 = format_number(S2_100 * speed_conv);

            chart.pressure = (pg*press_conv).toFixed(press_decimals);

            var rb = cv_eff * Math.sqrt(pg);
            var pt_b = Math.pow(rb/tips[r]["cv_tip"], 2.0);

            chart.vmd = (style == "UR") ? "---" : Math.round(eval(tips[r]["vmd_b"]));
            chart.dv01 = (style == "UR") ? "---" : Math.round(eval(tips[r]["Dv01_b"]));
            chart.lt141 = (style == "UR") ? "---" : Math.round(eval(tips[r]["141_b"]));
            chart.lt200 = (style == "UR") ? "---" : Math.round(eval(tips[r]["200_b"]));
            chart.lt600 = (style == "UR") ? "---" : Math.round(eval(tips[r]["600_b"]));
            chart.csscolor = tips[r].csscolor;
            chart.classification = tips[r].classification;

            tips[r].chart_rate.push(chart);
        }

    }

}

//----------------------------------------------------------------------------------------
//----------------------------------------------------------------------------------------

function get_fertilizer_tips (AA, AB, S, N, C, NO, OR, P_preferred)
{
    var N_equiv = N * NO;

    var RA = (AA*S*N_equiv)/5940.0*C;
    var RB = (AB*S*N_equiv)/5940.0*C;

    // Copy all of the tips_table into a new array
    var filtered;
    if (OR == "cj")
      filtered = tips_fertilizer_table_cj.slice();
    else
      filtered = tips_fertilizer_table_ors.slice();

    //
    // 1. Using calculated rate (RA) find pre-orifice within this range for min
    // and max flows (2 columns in spreadsheet).
    //

    filtered = filtered.filter(function (el) {    
        var tip_rate_30 = el["tip_rate_30"];
        var r_min = eval(el["r_min"]);
        var r_max = eval(el["r_max"]);
        return RA >= r_min && RA <= r_max;
    });
    
    //
    // 2. Filter by pressures if available
    //
    
    if (P_preferred) {
      
      filtered = filtered.sort(function (ela, elb) {

          var RA = (AA * S * N_equiv * C) / 5940.0;
          var SA = S;
          var SB = (RA * 5940)/(AB*N_equiv*C);
          
          var tip_rate_30 = ela["tip_rate_30"]
          var pta = 40.0 * Math.pow(RA/eval(ela["tip_rate"]), 2.0);

          var tip_rate_30 = elb["tip_rate_30"]
          var ptb = 40.0 * Math.pow(RA/eval(elb["tip_rate"]), 2.0);

          var diff_a = Math.abs(P_preferred - pta);
          var diff_b = Math.abs(P_preferred - ptb);

          if (diff_a < diff_b) {
              return -1;
          } else if (diff_a > diff_b) {
              return 1;
          } else {
              return 0;
          }
      });

      // Truncate to 6 items
      filtered = filtered.slice(0,6);
    
    }

    // 2. Sorting
    filtered = sort_fertilizer_tips(filtered);

    return filtered;
}

function build_charts_fertilizer (tips, AA, AB, S, N, NO, OR, C, speed_conv, press_conv, press_decimals)
{
    var N_equiv = N * NO;

    for (var r = 0; r < tips.length; ++r) {

        // Empty the current chart
        tips[r].chart = [];

        for (var pt = 10; pt <= 80; pt += 5) {

            var chart = {};
            chart.pressure = (pt*press_conv).toFixed(press_decimals);

            var tip_rate_30 = tips[r]["tip_rate_30"]
            var RA = Math.sqrt(pt/40.0) * eval(tips[r]["tip_rate"]);
            var SA = (RA * 5940)/(AA*N_equiv*C);
            chart.speed_a = format_number(SA*speed_conv);

            if (AB > 0.0) {
                var tip_rate_30 = tips[r]["tip_rate_30"]
                var RB = Math.sqrt(pt/40.0) * eval(tips[r]["tip_rate"]);
                var SB = (RA * 5940)/(AB*N_equiv*C);
                chart.speed_b = format_number(SB*speed_conv);
            } else {
                chart.speed_b = "-";
            }

            chart.highlight_1 = false;
            chart.highlight_2 = false;
            chart.csscolor = tips[r].csscolor;
            chart.classification = tips[r].classification;

            tips[r].chart.push(chart);
        }

        // Calculate target
        var RA = (AA * S * N_equiv * C) / 5940.0;
        var SA = S;
        var SB = (RA * 5940)/(AB*N_equiv*C);
        var tip_rate_30 = tips[r]["tip_rate_30"]
        var pta = 40.0 * Math.pow(RA/eval(tips[r]["tip_rate"]), 2.0);

        var chart = {};
        chart.pressure = (pta*press_conv).toFixed(press_decimals);
        chart.speed_a = format_number(SA*speed_conv);

        if (AB > 0.0) {
            chart.speed_b = format_number(SB*speed_conv);
        } else {
            chart.speed_b = "-";
        }
        chart.highlight_1 = true;
        chart.csscolor = tips[r].csscolor;
        chart.classification = tips[r].classification;

        tips[r].chart.push(chart);


        if (AB > 0.0) {
            var RB = (AB * S * N_equiv * C) / 5940.0;
            var SA = (RB * 5940)/(AA*N_equiv*C);
            var SB = S;
            var tip_rate_30 = tips[r]["tip_rate_30"]
            var ptb = 40.0 * Math.pow(RB/eval(tips[r]["tip_rate"]), 2.0);

            var chart = {};
            chart.pressure = (ptb*press_conv).toFixed(press_decimals);
            chart.speed_a = format_number(SA*speed_conv);

            chart.speed_b = format_number(SB*speed_conv);

            chart.highlight_2 = true;
            chart.csscolor = tips[r].csscolor;
            chart.classification = tips[r].classification;

            tips[r].chart.push(chart);
        }

        // Sort final results
        tips[r].chart = tips[r].chart.sort(function (ela, elb) {
            if (parseFloat(ela.pressure) < parseFloat(elb.pressure)) {
                return -1;
            } else if (parseFloat(ela.pressure) > parseFloat(elb.pressure)) {
                return 1;
            } else {
                return 0;
            }
        });

        // Descriptions
        tips[r].cap_descriptions = [];
        for (var cap = 0; cap < tips[r].caps.length; ++cap) {
            d = {
                "name": tips[r].caps[cap],
                "descrp": cap_descriptions[tips[r].caps[cap]]
            };
            tips[r].cap_descriptions.push(d);
        }

    }


}

//----------------------------------------------------------------------------------------
//----------------------------------------------------------------------------------------

function build_charts_flow_indicator (AA, AB, S, N, NO, C, flow_conv, flow_decimals)
{
    var N_equiv = N * NO;
    
    var flow_charts = [];
        
    for (var i = 0; i < 4; ++i) {
      var r_col_min, r_col_max, r_col_step;
      
      var pp_balls = null;
      var cel_balls = null;
      var rg_balls = null;
      var ss_half_balls = null;
      var ss_seven_sixteenths = null;
      
      var jet_green = null;
      var jet_red = null;
      var jet_lt_blue = null;
      var jet_black = null;
      
      var name = "";
      var subtitle_1 = "";
      var subtitle_2 = "";
    
      if (i == 0) { // Ultra Low Flow
        name = "Ultra Low Flow Column";
        subtitle_1 = "#20475-01 (Manifold Feed)";
        subtitle_2 = "";

        r_col_min = 0.01; 
        r_col_max = 0.25; 
        r_col_step = 0.02; 
        
        pp_balls = [0.01, 0.04];
        cel_balls = [0.02, 0.06];
        rg_balls = [0.06, 0.13];
        ss_half_balls = [0.13, 0.24];

      } else if (i == 1) { // Low Flow
        name = "Low Flow Column";
        subtitle_1 = "#20470-01 (Manifold Feed)";
        subtitle_2 = "#20490-01 (Isolated Feed)";
        
        r_col_min = 0.05; 
        r_col_max = 0.65; 
        r_col_step = 0.05; 
        
        pp_balls = [0.05, 0.12];
        cel_balls = [0.06, 0.16];
        rg_balls = [0.12, 0.26];
        ss_half_balls = [0.18, 0.65];

      } else if (i == 2) { // Standard
        name = "Standard Flow Column";
        subtitle_1 = "#20460-01 (Manifold Feed)";
        subtitle_2 = "#20480-01 (Isolated Feed)";
        
        r_col_min = 0.07; 
        r_col_max = 1.7; 
        r_col_step = 0.1; 
        
        pp_balls = [0.07, 0.25];
        cel_balls = [0.10, 0.35];
        rg_balls = [0.21, 0.72];
        ss_half_balls = [0.4, 1.7];
        ss_seven_sixteenths = [1.0,1.71];

      } else if (i == 3) { // EFM
        name = "Electronic Flowmeter";
        subtitle_1 = "#20580-00 (Assembly kit w/ 4 Jets)";
        subtitle_2 = "";
        
        r_col_min = 0.01; 
        r_col_max = 1.5; 
        r_col_step = 0.05;
        
        jet_green = [0.04, 0.12];
        jet_red = [0.10, 0.31];
        jet_lt_blue = [0.18, 0.98];
        jet_black = [0.57, 1.53];
      }   
      
      var has_pp_balls = false;
      var has_cel_balls = false;
      var has_rg_balls = false;
      var has_ss_half_balls = false;
      var has_ss_seven_sixteenths = false;
      
      var has_jet_green = false;
      var has_jet_red = false;
      var has_jet_lt_blue = false;
      var has_jet_black = false;
      
      var make_entry = function (r, highlight, highlight2) {
          chart = {
            r: r,
            flow_rate: (r * flow_conv).toFixed(flow_decimals),
            highlight: highlight,
            highlight2: highlight2,
          };
          if (pp_balls) {
            chart.pp_balls = (r >= pp_balls[0] && r <= pp_balls[1]); 
            has_pp_balls |= chart.pp_balls;
          }
          
          if (cel_balls) {
            chart.cel_balls = (r >= cel_balls[0] && r <= cel_balls[1]);
            has_cel_balls |= chart.cel_balls;
          }
        
          if (rg_balls) {
            chart.rg_balls = (r >= rg_balls[0] && r <= rg_balls[1]);
            has_rg_balls |= chart.rg_balls;
          }
        
          if (ss_half_balls) {
            chart.ss_half_balls = (r >= ss_half_balls[0] && r <= ss_half_balls[1]);
            has_ss_half_balls |= chart.ss_half_balls;
          }
        
          if (ss_seven_sixteenths) {
            chart.ss_seven_sixteenths = (r >= ss_seven_sixteenths[0] && r <= ss_seven_sixteenths[1]);
            has_ss_seven_sixteenths |= chart.ss_seven_sixteenths;
          }
        
          if (jet_green) {
            chart.jet_green = (r >= jet_green[0] && r <= jet_green[1]);
            has_jet_green |= chart.jet_green;
          }
        
          if (jet_red) {
            chart.jet_red = (r >= jet_red[0] && r <= jet_red[1]);
            has_jet_red |= chart.jet_red;
          }
        
          if (jet_lt_blue) {
            chart.jet_lt_blue = (r >= jet_lt_blue[0] && r <= jet_lt_blue[1]);
            has_jet_lt_blue |= chart.jet_lt_blue;
          }
        
          if (jet_black) {
            chart.jet_black = (r >= jet_black[0] && r <= jet_black[1]);
            has_jet_black |= chart.jet_black;
          }
          
          return chart;
      }

// i.      From 0.010 to 0.024, increasing in 0.001 increments
// ii.      From 0.025 to 0.060 increasing in 0.002 increments
// iii.      From 0.060 to 0.13, increasing in 0.005 increments
// iv.      From 0.13 to 0.64, increasing in 0.015 increments
// v.      From 0.64 to 1.0, increasing in 0.03 increments
// vi.      From 1.0 to 1.7, increasing in 0.05 increments
// vii.      From 1.7 to 2.7, increasing in 0.1 increments

      var step_size = function(r) {
          if (r <= 0.024)  return 0.001*4;
          if (r <= 0.060)  return 0.002*4;
          if (r <= 0.130)  return 0.005*4;
          if (r <= 0.640)  return 0.015*4;
          if (r <= 1.000)  return 0.03*4;
          if (r <= 1.700)  return 0.05*4;
          return 0.1*4;
      }
    
      chart_items = [];
      for (var r = r_col_min; r <= r_col_max; r += step_size(r)) {
        
        var chart = make_entry(r, false, false);
        chart_items.push(chart);
      }
      
      // One more entry for user parameters
      var RA = (AA * S * N_equiv * C) / 5940.0;
      var chart = make_entry(RA, true, false);
      chart_items.push(chart);
      
      if (AB > 0.0) {
        var RB = (AB * S * N_equiv * C) / 5940.0;
        var chart = make_entry(RB, false, true);
        chart_items.push(chart);
      }

      // Sort final results
      chart_items = chart_items.sort(function (ela, elb) {
          if (ela.r < elb.r) {
              return -1;
          } else if (ela.r > elb.r) {
              return 1;
          } else {
              return 0;
          }
      });
      
      if (RA >= r_col_min && RA <= r_col_max) {
          flow_charts.push({
              name: name,
              subtitle_1: subtitle_1,
              subtitle_2: subtitle_2,
              chart: chart_items,
          
              has_pp_balls: has_pp_balls,
              has_cel_balls: has_cel_balls,
              has_rg_balls: has_rg_balls,
              has_ss_half_balls: has_ss_half_balls,
              has_ss_seven_sixteenths: has_ss_seven_sixteenths,
              has_jet_green: has_jet_green,
              has_jet_red: has_jet_red,
              has_jet_lt_blue: has_jet_lt_blue,
              has_jet_black: has_jet_black
          });
      }
      
    }
    
    return flow_charts;
}

//----------------------------------------------------------------------------------------
//----------------------------------------------------------------------------------------
